@@ -32,13 +32,13 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_ASYNC_NAME_RESOLVER_H_
-#define _D_ASYNC_NAME_RESOLVER_H_
+#ifndef D_ASYNC_NAME_RESOLVER_H
+#define D_ASYNC_NAME_RESOLVER_H
 
 #include "common.h"
 
 #include <string>
-#include <deque>
+#include <vector>
 
 #include <ares.h>
 
@@ -62,32 +62,33 @@ public:
     STATUS_ERROR,
   };
 private:
-  STATUS status;
-  ares_channel channel;
+  STATUS status_;
+  int family_;
+  ares_channel channel_;
 
-  std::deque<std::string> _resolvedAddresses;
-  std::string error;
-  std::string _hostname;
+  std::vector<std::string> resolvedAddresses_;
+  std::string error_;
+  std::string hostname_;
 public:
-  AsyncNameResolver();
+  AsyncNameResolver(int family);
 
   ~AsyncNameResolver();
 
   void resolve(const std::string& name);
 
-  const std::deque<std::string>& getResolvedAddresses() const
+  const std::vector<std::string>& getResolvedAddresses() const
   {
-    return _resolvedAddresses;
+    return resolvedAddresses_;
   }
 
   const std::string& getError() const
   {
-    return error;
+    return error_;
   }
 
   STATUS getStatus() const
   {
-    return status;
+    return status_;
   }
 
   int getFds(fd_set* rfdsPtr, fd_set* wfdsPtr) const;
@@ -110,11 +111,11 @@ public:
 
   const std::string& getHostname() const
   {
-    return _hostname;
+    return hostname_;
   }
 
 };
 
 } // namespace aria2
 
-#endif // _D_ASYNC_NAME_RESOLVER_H_
+#endif // D_ASYNC_NAME_RESOLVER_H
