@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_BITFIELD_MESSAGE_H_
-#define _D_BT_BITFIELD_MESSAGE_H_
+#ifndef D_BT_BITFIELD_MESSAGE_H
+#define D_BT_BITFIELD_MESSAGE_H
 
 #include "SimpleBtMessage.h"
 
@@ -45,29 +45,14 @@ typedef SharedHandle<BtBitfieldMessage> BtBitfieldMessageHandle;
 
 class BtBitfieldMessage : public SimpleBtMessage {
 private:
-  unsigned char* bitfield;
-  size_t bitfieldLength;
-
-  void init() {
-    bitfield = 0;
-    bitfieldLength = 0;
-  }
+  unsigned char* bitfield_;
+  size_t bitfieldLength_;
 public:
-  BtBitfieldMessage():SimpleBtMessage(ID, NAME)
-  {
-    init();
-  }
+  BtBitfieldMessage();
 
-  BtBitfieldMessage(const unsigned char* bitfield,
-                    size_t bitfieldLength):SimpleBtMessage(ID, NAME)
-  {
-    init();
-    setBitfield(bitfield, bitfieldLength);
-  }
+  BtBitfieldMessage(const unsigned char* bitfield, size_t bitfieldLength);
 
-  virtual ~BtBitfieldMessage() {
-    delete [] bitfield;
-  }
+  virtual ~BtBitfieldMessage();
 
   static const uint8_t ID = 5;
 
@@ -75,11 +60,12 @@ public:
 
   void setBitfield(const unsigned char* bitfield, size_t bitfieldLength);
 
-  const unsigned char* getBitfield() const { return bitfield; }
+  const unsigned char* getBitfield() const { return bitfield_; }
 
-  size_t getBitfieldLength() const { return bitfieldLength; }
+  size_t getBitfieldLength() const { return bitfieldLength_; }
 
-  static BtBitfieldMessageHandle create(const unsigned char* data, size_t dataLength);
+  static BtBitfieldMessageHandle create
+  (const unsigned char* data, size_t dataLength);
 
   virtual void doReceivedAction();
 
@@ -92,4 +78,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_BT_BITFIELD_MESSAGE_H_
+#endif // D_BT_BITFIELD_MESSAGE_H
