@@ -40,6 +40,10 @@ namespace aria2 {
 
 const std::string BtInterestedMessage::NAME("interested");
 
+BtInterestedMessage::BtInterestedMessage():ZeroBtMessage(ID, NAME) {}
+
+BtInterestedMessage::~BtInterestedMessage() {}
+
 SharedHandle<BtInterestedMessage> BtInterestedMessage::create
 (const unsigned char* data, size_t dataLength)
 {
@@ -48,28 +52,28 @@ SharedHandle<BtInterestedMessage> BtInterestedMessage::create
 
 void BtInterestedMessage::doReceivedAction()
 {
-  if(_metadataGetMode) {
+  if(isMetadataGetMode()) {
     return;
   }
-  peer->peerInterested(true);
-  if(!peer->amChoking()) {
-    _peerStorage->executeChoke();
+  getPeer()->peerInterested(true);
+  if(!getPeer()->amChoking()) {
+    peerStorage_->executeChoke();
   }
 }
 
 bool BtInterestedMessage::sendPredicate() const
 {
-  return !peer->amInterested();
+  return !getPeer()->amInterested();
 }
 
 void BtInterestedMessage::onSendComplete() {
-  peer->amInterested(true);
+  getPeer()->amInterested(true);
 }
 
 void BtInterestedMessage::setPeerStorage
 (const SharedHandle<PeerStorage>& peerStorage)
 {
-  _peerStorage = peerStorage;
+  peerStorage_ = peerStorage;
 }
 
 } // namespace aria2
