@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -35,31 +35,34 @@
 #include "BtPortMessage.h"
 #include "bittorrent_helper.h"
 #include "DlAbortEx.h"
-#include "Util.h"
+#include "util.h"
 #include "message.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "Peer.h"
 #include "DHTNode.h"
 #include "DHTRoutingTable.h"
 #include "DHTTaskQueue.h"
 #include "DHTTaskFactory.h"
 #include "DHTTask.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "a2functional.h"
 
 namespace aria2 {
 
 const std::string BtPortMessage::NAME("port");
 
-BtPortMessage::BtPortMessage(uint16_t port):
-  SimpleBtMessage(ID, NAME), _port(port), _msg(0) {}
+BtPortMessage::BtPortMessage(uint16_t port)
+  : SimpleBtMessage(ID, NAME),
+    port_(port),
+    localNode_(0),
+    routingTable_(0),
+    taskQueue_(0),
+    taskFactory_(0)
+{}
 
-BtPortMessage::~BtPortMessage()
-{
-  delete [] _msg;
-}
-
-SharedHandle<BtPortMessage> BtPortMessage::create(const unsigned char* data, size_t dataLength)
+SharedHandle<BtPortMessage> BtPortMessage::create
+(const unsigned char* data, size_t dataLength)
 {
   bittorrent::assertPayloadLengthEqual(3, dataLength, NAME);
   bittorrent::assertID(ID, data, NAME);
@@ -70,39 +73,44 @@ SharedHandle<BtPortMessage> BtPortMessage::create(const unsigned char* data, siz
 
 void BtPortMessage::doReceivedAction()
 {
-  if(!_taskFactory.isNull() && !_taskQueue.isNull()) {
+  if(taskFactory_ && taskQueue_) {
+    if(port_ == 0) {
+      A2_LOG_DEBUG("Ignored port 0.");
+      return;
+    }
     // node id is random at this point. When ping reply received, new DHTNode
     // instance created with proper node ID and is added to a routing table.
     SharedHandle<DHTNode> node(new DHTNode());
-    node->setIPAddress(peer->ipaddr);
-    node->setPort(_port);
+    node->setIPAddress(getPeer()->getIPAddress());
+    node->setPort(port_);
     {
-      SharedHandle<DHTTask> task = _taskFactory->createPingTask(node);
-      _taskQueue->addImmediateTask(task);
+      SharedHandle<DHTTask> task = taskFactory_->createPingTask(node);
+      taskQueue_->addImmediateTask(task);
     }
-    if(_routingTable->countBucket() == 1) {
+    if(routingTable_->countBucket() == 1) {
       // initiate bootstrap
-      logger->info("Dispatch node_lookup since too few buckets.");
-      _taskQueue->addImmediateTask(_taskFactory->createNodeLookupTask(_localNode->getID()));
+      A2_LOG_INFO("Dispatch node_lookup since too few buckets.");
+      taskQueue_->addImmediateTask
+        (taskFactory_->createNodeLookupTask(localNode_->getID()));
     }
   } else {
-    logger->info("DHT port message received while localhost didn't declare support it.");
+    A2_LOG_INFO
+      ("DHT port message received while localhost didn't declare support it.");
   }
 }
 
-const unsigned char* BtPortMessage::getMessage() {
-  if(!_msg) {
-    /**
-     * len --- 5, 4bytes
-     * id --- 4, 1byte
-     * port --- port number, 2bytes
-     * total: 7bytes
-     */
-    _msg = new unsigned char[MESSAGE_LENGTH];
-    bittorrent::createPeerMessageString(_msg, MESSAGE_LENGTH, 3, ID);
-    bittorrent::setShortIntParam(&_msg[5], _port);
-  }
-  return _msg;
+unsigned char* BtPortMessage::createMessage()
+{
+  /**
+   * len --- 5, 4bytes
+   * id --- 4, 1byte
+   * port --- port number, 2bytes
+   * total: 7bytes
+   */
+  unsigned char* msg = new unsigned char[MESSAGE_LENGTH];
+  bittorrent::createPeerMessageString(msg, MESSAGE_LENGTH, 3, ID);
+  bittorrent::setShortIntParam(&msg[5], port_);
+  return msg;
 }
 
 size_t BtPortMessage::getMessageLength() {
@@ -110,27 +118,27 @@ size_t BtPortMessage::getMessageLength() {
 }
 
 std::string BtPortMessage::toString() const {
-  return strconcat(NAME, " port=", Util::uitos(_port));
+  return strconcat(NAME, " port=", util::uitos(port_));
 }
 
-void BtPortMessage::setLocalNode(const WeakHandle<DHTNode>& localNode)
+void BtPortMessage::setLocalNode(DHTNode* localNode)
 {
-  _localNode = localNode;
+  localNode_ = localNode;
 }
 
-void BtPortMessage::setRoutingTable(const WeakHandle<DHTRoutingTable>& routingTable)
+void BtPortMessage::setRoutingTable(DHTRoutingTable* routingTable)
 {
-  _routingTable = routingTable;
+  routingTable_ = routingTable;
 }
 
-void BtPortMessage::setTaskQueue(const WeakHandle<DHTTaskQueue>& taskQueue)
+void BtPortMessage::setTaskQueue(DHTTaskQueue* taskQueue)
 {
-  _taskQueue = taskQueue;
+  taskQueue_ = taskQueue;
 }
 
-void BtPortMessage::setTaskFactory(const WeakHandle<DHTTaskFactory>& taskFactory)
+void BtPortMessage::setTaskFactory(DHTTaskFactory* taskFactory)
 {
-  _taskFactory = taskFactory;
+  taskFactory_ = taskFactory;
 }
 
 } // namespace aria2
