@@ -45,49 +45,99 @@
 namespace aria2 {
 
 SharedHandle<DownloadContext>
-BtRegistry::getDownloadContext(int32_t gid) const
+BtRegistry::getDownloadContext(gid_t gid) const
 {
-  return get(gid)._downloadContext;
+  return get(gid).downloadContext_;
 }
 
 SharedHandle<DownloadContext>
 BtRegistry::getDownloadContext(const std::string& infoHash) const
 {
   SharedHandle<DownloadContext> dctx;
-  for(std::map<int32_t, BtObject>::const_iterator i = _pool.begin();
-      i != _pool.end(); ++i) {
-    const BDE& attrs =
-      (*i).second._downloadContext->getAttribute(bittorrent::BITTORRENT);
-    if(attrs[bittorrent::INFO_HASH].s() == infoHash) {
-      dctx = (*i).second._downloadContext;
+  for(std::map<gid_t, BtObject>::const_iterator i = pool_.begin(),
+        eoi = pool_.end(); i != eoi; ++i) {
+    if(bittorrent::getTorrentAttrs((*i).second.downloadContext_)->infoHash ==
+       infoHash) {
+      dctx = (*i).second.downloadContext_;
       break;
     }
-  }
+  }      
   return dctx;
 }
 
-void BtRegistry::put(int32_t gid, const BtObject& obj)
+void BtRegistry::put(gid_t gid, const BtObject& obj)
 {
-  _pool[gid] = obj;
+  pool_[gid] = obj;
 }
 
-BtObject BtRegistry::get(int32_t gid) const
+BtObject BtRegistry::get(gid_t gid) const
 {
-  std::map<int32_t, BtObject>::const_iterator i = _pool.find(gid);
-  if(i == _pool.end()) {
+  std::map<gid_t, BtObject>::const_iterator i = pool_.find(gid);
+  if(i == pool_.end()) {
     return BtObject();
   } else {
     return (*i).second;
   }
 }
 
-bool BtRegistry::remove(int32_t gid)
+bool BtRegistry::remove(gid_t gid)
 {
-  return _pool.erase(gid);
+  return pool_.erase(gid);
 }
 
 void BtRegistry::removeAll() {
-  _pool.clear();
+  pool_.clear();
+}
+
+BtObject::BtObject
+(const SharedHandle<DownloadContext>& downloadContext,
+ const SharedHandle<PieceStorage>& pieceStorage,
+ const SharedHandle<PeerStorage>& peerStorage,
+ const SharedHandle<BtAnnounce>& btAnnounce,
+ const SharedHandle<BtRuntime>& btRuntime,
+ const SharedHandle<BtProgressInfoFile>& btProgressInfoFile)
+  : downloadContext_(downloadContext),
+    pieceStorage_(pieceStorage),
+    peerStorage_(peerStorage),
+    btAnnounce_(btAnnounce),
+    btRuntime_(btRuntime),
+    btProgressInfoFile_(btProgressInfoFile)
+{}
+
+BtObject::BtObject() {}
+
+BtObject::BtObject(const BtObject& c)
+  : downloadContext_(c.downloadContext_),
+    pieceStorage_(c.pieceStorage_),
+    peerStorage_(c.peerStorage_),
+    btAnnounce_(c.btAnnounce_),
+    btRuntime_(c.btRuntime_),
+    btProgressInfoFile_(c.btProgressInfoFile_)
+{}
+
+BtObject::~BtObject() {}
+
+BtObject& BtObject::operator=(const BtObject& c)
+{
+  if(this != &c) {
+    downloadContext_ = c.downloadContext_;
+    pieceStorage_ = c.pieceStorage_;
+    peerStorage_ = c.peerStorage_;
+    btAnnounce_ = c.btAnnounce_;
+    btRuntime_ = c.btRuntime_;
+    btProgressInfoFile_ = c.btProgressInfoFile_;
+  }
+  return *this;
+}
+
+bool BtObject::isNull() const
+{
+  return !downloadContext_ &&
+    !pieceStorage_ &&
+    !peerStorage_ &&
+    !btAnnounce_ &&
+    !btRuntime_ &&
+    !btProgressInfoFile_;
 }
 
 } // namespace aria2
