@@ -47,12 +47,11 @@
 #include "Logger.h"
 #include "DlAbortEx.h"
 #include "DHTConstants.h"
-#include "StringFormat.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-DHTMessageTracker::DHTMessageTracker():
-  logger_(LogFactory::getInstance()) {}
+DHTMessageTracker::DHTMessageTracker() {}
 
 DHTMessageTracker::~DHTMessageTracker() {}
 
@@ -68,74 +67,83 @@ DHTMessageTracker::messageArrived
 {
   const String* tid = asString(dict->get(DHTMessage::T));
   if(!tid) {
-    throw DL_ABORT_EX(StringFormat("Malformed DHT message. From:%s:%u",
-                                   ipaddr.c_str(), port).str());
-  }
-  if(logger_->debug()) {
-    logger_->debug("Searching tracker entry for TransactionID=%s, Remote=%s:%u",
-                   util::toHex(tid->s()).c_str(), ipaddr.c_str(), port);
+    throw DL_ABORT_EX(fmt("Malformed DHT message. From:%s:%u",
+                          ipaddr.c_str(), port));
   }
+  A2_LOG_DEBUG(fmt("Searching tracker entry for TransactionID=%s, Remote=%s:%u",
+                   util::toHex(tid->s()).c_str(),
+                   ipaddr.c_str(), port));
   for(std::deque<SharedHandle<DHTMessageTrackerEntry> >::iterator i =
         entries_.begin(), eoi = entries_.end(); i != eoi; ++i) {
     if((*i)->match(tid->s(), ipaddr, port)) {
       SharedHandle<DHTMessageTrackerEntry> entry = *i;
       entries_.erase(i);
-      if(logger_->debug()) {
-        logger_->debug("Tracker entry found.");
-      }
+      A2_LOG_DEBUG("Tracker entry found.");
       SharedHandle<DHTNode> targetNode = entry->getTargetNode();
+      try {
+        SharedHandle<DHTResponseMessage> message =
+          factory_->createResponseMessage(entry->getMessageType(), dict,
+                                          targetNode->getIPAddress(),
+                                          targetNode->getPort());
 
-      SharedHandle<DHTResponseMessage> message =
-        factory_->createResponseMessage(entry->getMessageType(), dict,
-                                        targetNode->getIPAddress(),
-                                        targetNode->getPort());
-
-      int64_t rtt = entry->getElapsedMillis();
-      if(logger_->debug()) {
-        logger_->debug("RTT is %s", util::itos(rtt).c_str());
+        int64_t rtt = entry->getElapsedMillis();
+        A2_LOG_DEBUG(fmt("RTT is %s", util::itos(rtt).c_str()));
+        message->getRemoteNode()->updateRTT(rtt);
+        SharedHandle<DHTMessageCallback> callback = entry->getCallback();
+        if(!(*targetNode == *message->getRemoteNode())) {
+          // Node ID has changed. Drop previous node ID from
+          // DHTRoutingTable
+          A2_LOG_DEBUG
+            (fmt("Node ID has changed: old:%s, new:%s",
+                 util::toHex(targetNode->getID(), DHT_ID_LENGTH).c_str(),
+                 util::toHex(message->getRemoteNode()->getID(),
+                             DHT_ID_LENGTH).c_str()));
+          routingTable_->dropNode(targetNode);
+        }
+        return std::make_pair(message, callback);
+      } catch(RecoverableException& e) {
+        handleTimeoutEntry(entry);
+        throw;
       }
-      message->getRemoteNode()->updateRTT(rtt);
-      SharedHandle<DHTMessageCallback> callback = entry->getCallback();
-      return std::make_pair(message, callback);
     }
   }
-  if(logger_->debug()) {
-    logger_->debug("Tracker entry not found.");
-  }
+  A2_LOG_DEBUG("Tracker entry not found.");
   return std::pair<SharedHandle<DHTResponseMessage>,
                    SharedHandle<DHTMessageCallback> >();
 }
 
+void DHTMessageTracker::handleTimeoutEntry
+(const SharedHandle<DHTMessageTrackerEntry>& entry)
+{
+  try {
+    SharedHandle<DHTNode> node = entry->getTargetNode();
+    A2_LOG_DEBUG(fmt("Message timeout: To:%s:%u",
+                     node->getIPAddress().c_str(), node->getPort()));
+    node->updateRTT(entry->getElapsedMillis());
+    node->timeout();
+    if(node->isBad()) {
+      A2_LOG_DEBUG(fmt("Marked bad: %s:%u",
+                       node->getIPAddress().c_str(), node->getPort()));
+      routingTable_->dropNode(node);
+    }
+    SharedHandle<DHTMessageCallback> callback = entry->getCallback();
+    if(callback) {
+      callback->onTimeout(node);
+    }
+  } catch(RecoverableException& e) {
+    A2_LOG_INFO_EX("Exception thrown while handling timeouts.", e);
+  }
+}
+
 void DHTMessageTracker::handleTimeout()
 {
   for(std::deque<SharedHandle<DHTMessageTrackerEntry> >::iterator i =
         entries_.begin(), eoi = entries_.end(); i != eoi;) {
     if((*i)->isTimeout()) {
-      try {
         SharedHandle<DHTMessageTrackerEntry> entry = *i;
         i = entries_.erase(i);
         eoi = entries_.end();
-        SharedHandle<DHTNode> node = entry->getTargetNode();
-        if(logger_->debug()) {
-          logger_->debug("Message timeout: To:%s:%u",
-                         node->getIPAddress().c_str(), node->getPort());
-        }
-        node->updateRTT(entry->getElapsedMillis());
-        node->timeout();
-        if(node->isBad()) {
-          if(logger_->debug()) {
-            logger_->debug("Marked bad: %s:%u",
-                           node->getIPAddress().c_str(), node->getPort());
-          }
-          routingTable_->dropNode(node);
-        }
-        SharedHandle<DHTMessageCallback> callback = entry->getCallback();
-        if(!callback.isNull()) {
-          callback->onTimeout(node);
-        }
-      } catch(RecoverableException& e) {
-        logger_->info("Exception thrown while handling timeouts.", e);
-      }
+        handleTimeoutEntry(entry);
     } else {
       ++i;
     }
