@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_PEER_LOOKUP_TASK_H_
-#define _D_DHT_PEER_LOOKUP_TASK_H_
+#ifndef D_DHT_PEER_LOOKUP_TASK_H
+#define D_DHT_PEER_LOOKUP_TASK_H
 
 #include "DHTAbstractNodeLookupTask.h"
 #include <map>
@@ -44,31 +44,37 @@ class DownloadContext;
 class Peer;
 class PeerStorage;
 class BtRuntime;
+class DHTGetPeersReplyMessage;
 
-class DHTPeerLookupTask:public DHTAbstractNodeLookupTask {
+class DHTPeerLookupTask:
+    public DHTAbstractNodeLookupTask<DHTGetPeersReplyMessage> {
 private:
-  std::map<std::string, std::string> _tokenStorage;
+  std::map<std::string, std::string> tokenStorage_;
 
-  std::vector<SharedHandle<Peer> > _peers;
+  std::vector<SharedHandle<Peer> > peers_;
 
-  SharedHandle<PeerStorage> _peerStorage;
+  SharedHandle<PeerStorage> peerStorage_;
 
-  SharedHandle<BtRuntime> _btRuntime;
+  SharedHandle<BtRuntime> btRuntime_;
 public:
   DHTPeerLookupTask(const SharedHandle<DownloadContext>& downloadContext);
 
-  virtual void getNodesFromMessage(std::vector<SharedHandle<DHTNode> >& nodes,
-                                   const SharedHandle<DHTMessage>& message);
+  virtual void getNodesFromMessage
+  (std::vector<SharedHandle<DHTNode> >& nodes,
+   const DHTGetPeersReplyMessage* message);
   
-  virtual void onReceivedInternal(const SharedHandle<DHTMessage>& message);
+  virtual void onReceivedInternal(const DHTGetPeersReplyMessage* message);
   
-  virtual SharedHandle<DHTMessage> createMessage(const SharedHandle<DHTNode>& remoteNode);
+  virtual SharedHandle<DHTMessage> createMessage
+  (const SharedHandle<DHTNode>& remoteNode);
+
+  virtual SharedHandle<DHTMessageCallback> createCallback();
 
   virtual void onFinish();
   
   const std::vector<SharedHandle<Peer> >& getPeers() const
   {
-    return _peers;
+    return peers_;
   }
 
   void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);
@@ -78,4 +84,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_DHT_PEER_LOOKUP_TASK_H_
+#endif // D_DHT_PEER_LOOKUP_TASK_H
