@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_ROUTING_TABLE_SERIALIZER_H_
-#define _D_DHT_ROUTING_TABLE_SERIALIZER_H_
+#ifndef D_DHT_ROUTING_TABLE_SERIALIZER_H
+#define D_DHT_ROUTING_TABLE_SERIALIZER_H
 
 #include "common.h"
 
@@ -48,11 +48,13 @@ class DHTNode;
 
 class DHTRoutingTableSerializer {
 private:
-  SharedHandle<DHTNode> _localNode;
+  int family_;
 
-  std::vector<SharedHandle<DHTNode> > _nodes;
+  SharedHandle<DHTNode> localNode_;
+
+  std::vector<SharedHandle<DHTNode> > nodes_;
 public:
-  DHTRoutingTableSerializer();
+  DHTRoutingTableSerializer(int family);
 
   ~DHTRoutingTableSerializer();
 
@@ -65,4 +67,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_DHT_ROUTING_TABLE_SERIALIZER_H_
+#endif // D_DHT_ROUTING_TABLE_SERIALIZER_H
