@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DEFAULT_PEER_STORAGE_H_
-#define _D_DEFAULT_PEER_STORAGE_H_
+#ifndef D_DEFAULT_PEER_STORAGE_H
+#define D_DEFAULT_PEER_STORAGE_H
 
 #include "PeerStorage.h"
 
@@ -43,8 +43,6 @@
 
 namespace aria2 {
 
-class Option;
-class Logger;
 class BtRuntime;
 class BtSeederStateChoke;
 class BtLeecherStateChoke;
@@ -52,26 +50,27 @@ class PieceStorage;
 
 class DefaultPeerStorage : public PeerStorage {
 private:
-  SharedHandle<BtRuntime> _btRuntime;
-  SharedHandle<PieceStorage> _pieceStorage;
-  const Option* option;
-  std::deque<SharedHandle<Peer> > peers;
-  Logger* logger;
-  uint64_t removedPeerSessionDownloadLength;
-  uint64_t removedPeerSessionUploadLength;
+  SharedHandle<BtRuntime> btRuntime_;
+  SharedHandle<PieceStorage> pieceStorage_;
+  std::deque<SharedHandle<Peer> > peers_;
+  std::deque<SharedHandle<Peer> > droppedPeers_;
+  uint64_t removedPeerSessionDownloadLength_;
+  uint64_t removedPeerSessionUploadLength_;
 
-  BtSeederStateChoke* _seederStateChoke;
-  BtLeecherStateChoke* _leecherStateChoke;
+  BtSeederStateChoke* seederStateChoke_;
+  BtLeecherStateChoke* leecherStateChoke_;
 
-  std::map<std::string, TransferStat> _peerTransferStatMap;
+  std::map<std::string, TransferStat> peerTransferStatMap_;
 
-  Timer _lastTransferStatMapUpdated;
+  Timer lastTransferStatMapUpdated_;
 
-  TransferStat _cachedTransferStat;
+  TransferStat cachedTransferStat_;
 
   bool isPeerAlreadyAdded(const SharedHandle<Peer>& peer);
+
+  void addDroppedPeer(const SharedHandle<Peer>& peer);
 public:
-  DefaultPeerStorage(const Option* option);
+  DefaultPeerStorage();
 
   virtual ~DefaultPeerStorage();
 
@@ -87,6 +86,8 @@ public:
 
   virtual const std::deque<SharedHandle<Peer> >& getPeers();
 
+  virtual const std::deque<SharedHandle<Peer> >& getDroppedPeers();
+
   virtual bool isPeerAvailable();
 
   virtual void getActivePeers(std::vector<SharedHandle<Peer> >& peers);
@@ -116,4 +117,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_DEFAULT_PEER_STORAGE_H_
+#endif // D_DEFAULT_PEER_STORAGE_H
