@@ -36,16 +36,14 @@
 
 #include <algorithm>
 
-#include "LogFactory.h"
-#include "Logger.h"
 #include "Option.h"
 #include "RequestGroup.h"
 #include "DownloadEngine.h"
 #include "RequestGroupMan.h"
 #include "FileAllocationMan.h"
+#include "CheckIntegrityMan.h"
+#include "CheckIntegrityEntry.h"
 #ifdef ENABLE_MESSAGE_DIGEST
-# include "CheckIntegrityMan.h"
-# include "CheckIntegrityEntry.h"
 # include "CheckIntegrityDispatcherCommand.h"
 #endif // ENABLE_MESSAGE_DIGEST
 #include "prefs.h"
@@ -58,6 +56,7 @@
 #include "ServerStatMan.h"
 #include "a2io.h"
 #include "DownloadContext.h"
+#include "array_fun.h"
 #ifdef HAVE_EPOLL
 # include "EpollEventPoll.h"
 #endif // HAVE_EPOLL
@@ -79,8 +78,7 @@
 
 namespace aria2 {
 
-DownloadEngineFactory::DownloadEngineFactory():
-  _logger(LogFactory::getInstance()) {}
+DownloadEngineFactory::DownloadEngineFactory() {}
 
 DownloadEngineHandle
 DownloadEngineFactory::newDownloadEngine
@@ -134,22 +132,24 @@ DownloadEngineFactory::newDownloadEngine
             abort();
           }
   DownloadEngineHandle e(new DownloadEngine(eventPoll));
-  e->option = op;
+  e->setOption(op);
 
   RequestGroupManHandle
     requestGroupMan(new RequestGroupMan(requestGroups, MAX_CONCURRENT_DOWNLOADS,
                                         op));
-  e->_requestGroupMan = requestGroupMan;
-  e->_fileAllocationMan.reset(new FileAllocationMan());
+  e->setRequestGroupMan(requestGroupMan);
+  e->setFileAllocationMan
+    (SharedHandle<FileAllocationMan>(new FileAllocationMan()));
 #ifdef ENABLE_MESSAGE_DIGEST
-  e->_checkIntegrityMan.reset(new CheckIntegrityMan());
+  e->setCheckIntegrityMan
+    (SharedHandle<CheckIntegrityMan>(new CheckIntegrityMan()));
 #endif // ENABLE_MESSAGE_DIGEST
   e->addRoutineCommand(new FillRequestGroupCommand(e->newCUID(), e.get()));
   e->addRoutineCommand(new FileAllocationDispatcherCommand
-                       (e->newCUID(), e->_fileAllocationMan, e.get()));
+                       (e->newCUID(), e->getFileAllocationMan(), e.get()));
 #ifdef ENABLE_MESSAGE_DIGEST
   e->addRoutineCommand(new CheckIntegrityDispatcherCommand
-                       (e->newCUID(), e->_checkIntegrityMan, e.get()));
+                       (e->newCUID(), e->getCheckIntegrityMan(), e.get()));
 #endif // ENABLE_MESSAGE_DIGEST
 
   if(op->getAsInt(PREF_AUTO_SAVE_INTERVAL) > 0) {
@@ -167,12 +167,16 @@ DownloadEngineFactory::newDownloadEngine
   }
 #ifdef ENABLE_XML_RPC
   if(op->getAsBool(PREF_ENABLE_XML_RPC)) {
-    HttpListenCommand* httpListenCommand =
-      new HttpListenCommand(e->newCUID(), e.get());
-    if(httpListenCommand->bindPort(op->getAsInt(PREF_XML_RPC_LISTEN_PORT))){
-      e->addRoutineCommand(httpListenCommand);
-    } else {
-      delete httpListenCommand;
+    static int families[] = { AF_INET, AF_INET6 };
+    size_t familiesLength = op->getAsBool(PREF_DISABLE_IPV6)?1:2;
+    for(size_t i = 0; i < familiesLength; ++i) {
+      HttpListenCommand* httpListenCommand =
+        new HttpListenCommand(e->newCUID(), e.get(), families[i]);
+      if(httpListenCommand->bindPort(op->getAsInt(PREF_XML_RPC_LISTEN_PORT))){
+        e->addRoutineCommand(httpListenCommand);
+      } else {
+        delete httpListenCommand;
+      }
     }
   }
 #endif // ENABLE_XML_RPC
