@@ -48,8 +48,6 @@
 
 namespace aria2 {
 
-class Logger;
-
 class EpollEventPoll : public EventPoll {
 private:
   class KSocketEntry;
@@ -84,8 +82,6 @@ private:
 
   static const size_t EPOLL_EVENTS_MAX = 1024;
 
-  Logger* logger_;
-
   bool addEvents(sock_t socket, const KEvent& event);
 
   bool deleteEvents(sock_t socket, const KEvent& event);
