@@ -46,6 +46,7 @@
 #include "DlAbortEx.h"
 #include "MetalinkParserState.h"
 #include "A2STR.h"
+#include "error_code.h"
 
 namespace aria2 {
 
@@ -58,9 +59,10 @@ public:
 
   SessionData(const SharedHandle<MetalinkParserStateMachine>& stm):stm_(stm) {}
 };
-}
+} // namespace
 
-static void splitNsName
+namespace {
+void splitNsName
 (std::string& localname, std::string& prefix, std::string& nsUri,
  const std::string& nsName)
 {
@@ -73,8 +75,10 @@ static void splitNsName
     localname = nsNamePair.second;
   }
 }
+} // namespace
 
-static void mlStartElement(void* userData, const char* nsName, const char** attrs)
+namespace {
+void mlStartElement(void* userData, const char* nsName, const char** attrs)
 {
   SessionData* sd = reinterpret_cast<SessionData*>(userData);
 
@@ -110,8 +114,10 @@ static void mlStartElement(void* userData, const char* nsName, const char** attr
     sd->charactersStack_.push_front(A2STR::NIL);
   }
 }
+} // namespace
 
-static void mlEndElement(void* userData, const char* nsName)
+namespace {
+void mlEndElement(void* userData, const char* nsName)
 {
   std::string localname;
   std::string prefix;
@@ -126,16 +132,20 @@ static void mlEndElement(void* userData, const char* nsName)
   }
   sd->stm_->endElement(localname, prefix, nsUri, characters);
 }
+} // namespace
 
-static void mlCharacters(void* userData, const char* ch, int len)
+namespace {
+void mlCharacters(void* userData, const char* ch, int len)
 {
   SessionData* sd = reinterpret_cast<SessionData*>(userData);
   if(sd->stm_->needsCharactersBuffering()) {
     sd->charactersStack_.front() += std::string(&ch[0], &ch[len]);
   }
 }
+} // namespace
 
-static XML_Parser createParser(const SharedHandle<SessionData>& sessionData)
+namespace {
+XML_Parser createParser(const SharedHandle<SessionData>& sessionData)
 {
   XML_Parser parser = XML_ParserCreateNS(0, static_cast<const XML_Char>('\t'));
   XML_SetUserData(parser, sessionData.get());
@@ -143,22 +153,28 @@ static XML_Parser createParser(const SharedHandle<SessionData>& sessionData)
   XML_SetCharacterDataHandler(parser, &mlCharacters);
   return parser;
 }
+} // namespace
 
-static void checkError(XML_Parser parser)
+namespace {
+void checkError(XML_Parser parser)
 {
   if(XML_Parse(parser, 0, 0, 1) == XML_STATUS_ERROR) {
-    throw DL_ABORT_EX(MSG_CANNOT_PARSE_METALINK);
+    throw DL_ABORT_EX2(MSG_CANNOT_PARSE_METALINK,
+                       error_code::METALINK_PARSE_ERROR);
   }
   SessionData* sessionData =
     reinterpret_cast<SessionData*>(XML_GetUserData(parser));
   const SharedHandle<MetalinkParserStateMachine>& stm = sessionData->stm_;
   if(!stm->finished()) {
-    throw DL_ABORT_EX(MSG_CANNOT_PARSE_METALINK);
+    throw DL_ABORT_EX2(MSG_CANNOT_PARSE_METALINK,
+                       error_code::METALINK_PARSE_ERROR);
   }
   if(!stm->getErrors().empty()) {
-    throw DL_ABORT_EX(stm->getErrorString());
+    throw DL_ABORT_EX2(stm->getErrorString(),
+                       error_code::METALINK_PARSE_ERROR);
   }
 }
+} // namespace
 
 SharedHandle<Metalinker>
 MetalinkProcessor::parseFile(const std::string& filename)
@@ -183,11 +199,13 @@ MetalinkProcessor::parseFile(std::istream& stream)
   while(stream) {
     stream.read(buf, sizeof(buf));
     if(XML_Parse(parser, buf, stream.gcount(), 0) == XML_STATUS_ERROR) {
-      throw DL_ABORT_EX(MSG_CANNOT_PARSE_METALINK);
+      throw DL_ABORT_EX2(MSG_CANNOT_PARSE_METALINK,
+                         error_code::METALINK_PARSE_ERROR);
     }
   }
   if(stream.bad()) {
-    throw DL_ABORT_EX(MSG_CANNOT_PARSE_METALINK);
+    throw DL_ABORT_EX2(MSG_CANNOT_PARSE_METALINK,
+                       error_code::METALINK_PARSE_ERROR);
   }
   checkError(parser);
   return stm_->getResult();
@@ -202,6 +220,7 @@ MetalinkProcessor::parseFromBinaryStream(const SharedHandle<BinaryStream>& binar
 
   SharedHandle<SessionData> sessionData(new SessionData(stm_));
   XML_Parser parser = createParser(sessionData);
+  auto_delete<XML_Parser> deleter(parser, XML_ParserFree);
   off_t readOffset = 0;
   while(1) {
     ssize_t res = binaryStream->readData(buf, bufSize, readOffset);
@@ -210,7 +229,8 @@ MetalinkProcessor::parseFromBinaryStream(const SharedHandle<BinaryStream>& binar
     }
     if(XML_Parse(parser, reinterpret_cast<const char*>(buf), res, 0) ==
        XML_STATUS_ERROR) {
-      throw DL_ABORT_EX(MSG_CANNOT_PARSE_METALINK);
+      throw DL_ABORT_EX2(MSG_CANNOT_PARSE_METALINK,
+                         error_code::METALINK_PARSE_ERROR);
     }
     readOffset += res;
   }
