@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_EXPAT_XML_RPC_REQUEST_PROCESSOR_H_
-#define _D_EXPAT_XML_RPC_REQUEST_PROCESSOR_H_
+#ifndef D_EXPAT_XML_RPC_REQUEST_PROCESSOR_H
+#define D_EXPAT_XML_RPC_REQUEST_PROCESSOR_H
 
 #include "common.h"
 
@@ -50,7 +50,7 @@ class XmlRpcRequestParserStateMachine;
 
 class XmlRpcRequestProcessor {
 private:
-  SharedHandle<XmlRpcRequestParserStateMachine> _stm;
+  SharedHandle<XmlRpcRequestParserStateMachine> stm_;
 public:
   XmlRpcRequest parseMemory(const std::string& xml);
 };
@@ -59,4 +59,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_EXPAT_XML_RPC_REQUEST_PROCESSOR_H_
+#endif // D_EXPAT_XML_RPC_REQUEST_PROCESSOR_H
