@@ -46,18 +46,15 @@
 #include "FtpTunnelRequestCommand.h"
 #include "DlAbortEx.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "message.h"
 #include "prefs.h"
 #include "HttpConnection.h"
 #include "Socket.h"
-#include "DownloadContext.h"
 #include "util.h"
 #include "AuthConfigFactory.h"
 #include "AuthConfig.h"
-#include "RequestGroupMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
-#include "ServerStatMan.h"
+#include "fmt.h"
 
 namespace aria2 {
 
@@ -77,7 +74,7 @@ Command* FtpInitiateConnectionCommand::createNextCommand
  const SharedHandle<Request>& proxyRequest)
 {
   Command* command;
-  if(!proxyRequest.isNull()) {
+  if(proxyRequest) {
     std::map<std::string, std::string> options;
     SharedHandle<SocketCore> pooledSocket;
     std::string proxyMethod = resolveProxyMethod(getRequest()->getProtocol());
@@ -92,14 +89,13 @@ Command* FtpInitiateConnectionCommand::createNextCommand
          (getRequest(), getOption().get())->getUser(),
          proxyRequest->getHost(), proxyRequest->getPort());
     }
-    if(pooledSocket.isNull()) {
-      if(getLogger()->info()) {
-        getLogger()->info(MSG_CONNECTING_TO_SERVER,
-                          util::itos(getCuid()).c_str(), addr.c_str(), port);
-      }
+    if(!pooledSocket) {
+      A2_LOG_INFO(fmt(MSG_CONNECTING_TO_SERVER,
+                      getCuid(), addr.c_str(), port));
       createSocket();
       getSocket()->establishConnection(addr, port);
       
+      getRequest()->setConnectedAddrInfo(hostname, addr, port);
       if(proxyMethod == V_GET) {
         // Use GET for FTP via HTTP proxy.
         getRequest()->setMethod(Request::METHOD_GET);
@@ -110,7 +106,6 @@ Command* FtpInitiateConnectionCommand::createNextCommand
           new HttpRequestCommand(getCuid(), getRequest(), getFileEntry(),
                                  getRequestGroup(), hc, getDownloadEngine(),
                                  getSocket());
-        c->setConnectedAddr(hostname, addr, port);
         c->setProxyRequest(proxyRequest);
         command = c;
       } else if(proxyMethod == V_TUNNEL) {
@@ -118,13 +113,13 @@ Command* FtpInitiateConnectionCommand::createNextCommand
           new FtpTunnelRequestCommand(getCuid(), getRequest(), getFileEntry(),
                                       getRequestGroup(), getDownloadEngine(),
                                       proxyRequest, getSocket());
-        c->setConnectedAddr(hostname, addr, port);
         command = c;
       } else {
         // TODO
         throw DL_ABORT_EX("ERROR");
       }
     } else {
+      setConnectedAddrInfo(getRequest(), hostname, pooledSocket);
       if(proxyMethod == V_TUNNEL) {
         command =
           new FtpNegotiationCommand(getCuid(), getRequest(), getFileEntry(),
@@ -157,18 +152,16 @@ Command* FtpInitiateConnectionCommand::createNextCommand
        getRequest()->getPort(),
        getDownloadEngine()->getAuthConfigFactory()->createAuthConfig
        (getRequest(), getOption().get())->getUser());
-    if(pooledSocket.isNull()) {
-      if(getLogger()->info()) {
-        getLogger()->info(MSG_CONNECTING_TO_SERVER,
-                          util::itos(getCuid()).c_str(), addr.c_str(), port);
-      }
+    if(!pooledSocket) {
+      A2_LOG_INFO(fmt(MSG_CONNECTING_TO_SERVER,
+                      getCuid(), addr.c_str(), port));
       createSocket();
       getSocket()->establishConnection(addr, port);
       FtpNegotiationCommand* c =
         new FtpNegotiationCommand(getCuid(), getRequest(), getFileEntry(),
                                   getRequestGroup(), getDownloadEngine(),
                                   getSocket());
-      c->setConnectedAddr(hostname, addr, port);
+      getRequest()->setConnectedAddrInfo(hostname, addr, port);
       command = c;
     } else {
       command =
@@ -177,6 +170,7 @@ Command* FtpInitiateConnectionCommand::createNextCommand
                                   pooledSocket,
                                   FtpNegotiationCommand::SEQ_SEND_CWD_PREP,
                                   options["baseWorkingDir"]);
+      setConnectedAddrInfo(getRequest(), hostname, pooledSocket);
     }
   }
   return command;
