@@ -58,7 +58,8 @@ FtpTunnelRequestCommand::~FtpTunnelRequestCommand() {}
 Command* FtpTunnelRequestCommand::getNextCommand()
 {
   return new FtpTunnelResponseCommand
-    (cuid, req, _fileEntry, _requestGroup, httpConnection, e, socket);
+    (getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
+     getHttpConnection(), getDownloadEngine(), getSocket());
 }
 
 } // namespace aria2
