@@ -53,13 +53,11 @@
 #include "AuthConfigFactory.h"
 #include "AuthConfig.h"
 #include "DownloadContext.h"
-#include "RequestGroupMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
-#include "ServerStatMan.h"
 #include "PieceStorage.h"
 #include "DefaultBtProgressInfoFile.h"
 #include "Logger.h"
+#include "LogFactory.h"
+#include "fmt.h"
 
 namespace aria2 {
 
@@ -71,8 +69,8 @@ HttpRequestCommand::HttpRequestCommand
  const HttpConnectionHandle& httpConnection,
  DownloadEngine* e,
  const SocketHandle& s)
-  :AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
-   httpConnection_(httpConnection)
+  : AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
+    httpConnection_(httpConnection)
 {
   setTimeout(getOption()->getAsInt(PREF_CONNECT_TIMEOUT));
   disableReadCheckSocket();
@@ -154,15 +152,13 @@ bool HttpRequestCommand::executeInternal() {
           getRequest()->getProtocol() == Request::PROTO_HTTPS)) {
         if(getFileEntry()->getPath().empty() &&
            getRequest()->getFile().empty()) {
-          if(getLogger()->debug()) {
-            getLogger()->debug("conditional-get is disabled because file name"
-                               "is not available.");
-          }
+          A2_LOG_DEBUG("Conditional-Get is disabled because file name"
+                       " is not available.");
         } else {
           if(getFileEntry()->getPath().empty()) {
             getFileEntry()->setPath
               (util::createSafePath
-               (getDownloadContext()->getDir(),
+               (getOption()->get(PREF_DIR),
                 util::percentDecode(getRequest()->getFile())));
           }
           File ctrlfile(getFileEntry()->getPath()+
@@ -183,7 +179,7 @@ bool HttpRequestCommand::executeInternal() {
         if(!httpConnection_->isIssued(segment)) {
           off_t endOffset = 0;
           if(getRequestGroup()->getTotalLength() > 0 &&
-             !getPieceStorage().isNull()) {
+             getPieceStorage()) {
             size_t nextIndex =
               getPieceStorage()->getNextUsedIndex(segment->getIndex());
             endOffset = std::min
