@@ -57,7 +57,7 @@
 #include "Socket.h"
 #include "message.h"
 #include "prefs.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "HttpSkipResponseCommand.h"
 #include "HttpHeader.h"
 #include "LogFactory.h"
@@ -66,8 +66,6 @@
 #include "AuthConfig.h"
 #include "a2functional.h"
 #include "URISelector.h"
-#include "ServerStatMan.h"
-#include "FileAllocationEntry.h"
 #include "CheckIntegrityEntry.h"
 #include "StreamFilter.h"
 #include "SinkStreamFilter.h"
@@ -87,15 +85,15 @@ SharedHandle<StreamFilter> getTransferEncodingStreamFilter
   SharedHandle<StreamFilter> filter;
   if(httpResponse->isTransferEncodingSpecified()) {
     filter = httpResponse->getTransferEncodingStreamFilter();
-    if(filter.isNull()) {
+    if(!filter) {
       throw DL_ABORT_EX
-        (StringFormat(EX_TRANSFER_ENCODING_NOT_SUPPORTED,
-                      httpResponse->getTransferEncoding().c_str()).str());
+        (fmt(EX_TRANSFER_ENCODING_NOT_SUPPORTED,
+             httpResponse->getTransferEncoding().c_str()));
     }
     filter->init();
     filter->installDelegate(delegate);
   }
-  if(filter.isNull()) {
+  if(!filter) {
     filter = delegate;
   }
   return filter;
@@ -110,18 +108,18 @@ SharedHandle<StreamFilter> getContentEncodingStreamFilter
   SharedHandle<StreamFilter> filter;
   if(httpResponse->isContentEncodingSpecified()) {
     filter = httpResponse->getContentEncodingStreamFilter();
-    if(filter.isNull()) {
-      LogFactory::getInstance()->info
-        ("Content-Encoding %s is specified, but the current implementation"
-         "doesn't support it. The decoding process is skipped and the"
-         "downloaded content will be still encoded.",
-         httpResponse->getContentEncoding().c_str());
+    if(!filter) {
+      A2_LOG_INFO
+        (fmt("Content-Encoding %s is specified, but the current implementation"
+             "doesn't support it. The decoding process is skipped and the"
+             "downloaded content will be still encoded.",
+             httpResponse->getContentEncoding().c_str()));
     } else {
       filter->init();
       filter->installDelegate(delegate);
     }
   }
-  if(filter.isNull()) {
+  if(!filter) {
     filter = delegate;
   }
   return filter;
@@ -136,8 +134,8 @@ HttpResponseCommand::HttpResponseCommand
  const HttpConnectionHandle& httpConnection,
  DownloadEngine* e,
  const SocketHandle& s)
-  :AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
-   httpConnection_(httpConnection)
+  : AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
+    httpConnection_(httpConnection)
 {}
 
 HttpResponseCommand::~HttpResponseCommand() {}
@@ -146,7 +144,7 @@ bool HttpResponseCommand::executeInternal()
 {
   SharedHandle<HttpRequest> httpRequest =httpConnection_->getFirstHttpRequest();
   SharedHandle<HttpResponse> httpResponse = httpConnection_->receiveResponse();
-  if(httpResponse.isNull()) {
+  if(!httpResponse) {
     // The server has not responded to our request yet.
     // For socket->wantRead() == true, setReadCheckSocket(socket) is already
     // done in the constructor.
@@ -169,29 +167,28 @@ bool HttpResponseCommand::executeInternal()
       (getOption()->getAsInt(PREF_MAX_HTTP_PIPELINING));
   }
 
+  int statusCode = httpResponse->getStatusCode();
   if(!httpResponse->getHttpRequest()->getIfModifiedSinceHeader().empty()) {
-    if(httpResponse->getResponseStatus() == HttpHeader::S304) {
+    if(statusCode == 304) {
       uint64_t totalLength = httpResponse->getEntityLength();
       getFileEntry()->setLength(totalLength);
       getRequestGroup()->initPieceStorage();
       getPieceStorage()->markAllPiecesDone();
       // Just set checksum verification done.
       getDownloadContext()->setChecksumVerified(true);
-      getLogger()->notice(MSG_DOWNLOAD_ALREADY_COMPLETED,
-                          util::itos(getRequestGroup()->getGID()).c_str(),
-                          getRequestGroup()->getFirstFilePath().c_str());
+      A2_LOG_NOTICE(fmt(MSG_DOWNLOAD_ALREADY_COMPLETED,
+                        util::itos(getRequestGroup()->getGID()).c_str(),
+                        getRequestGroup()->getFirstFilePath().c_str()));
       poolConnection();
       getFileEntry()->poolRequest(getRequest());
       return true;
-    } else if(httpResponse->getResponseStatus() == HttpHeader::S200 ||
-              httpResponse->getResponseStatus() == HttpHeader::S206) {
+    } else if(statusCode == 200 || statusCode == 206) {
       // Remote file is newer than local file. We allow overwrite.
       getOption()->put(PREF_ALLOW_OVERWRITE, A2_V_TRUE);
     }
   }
-  if(httpResponse->getResponseStatus() >= HttpHeader::S300 &&
-     httpResponse->getResponseStatus() != HttpHeader::S304) {
-    if(httpResponse->getResponseStatus() == HttpHeader::S404) {
+  if(statusCode != 304 && statusCode >= 300) {
+    if(statusCode == 404) {
       getRequestGroup()->increaseAndValidateFileNotFoundCount();
     }
     return skipResponseBody(httpResponse);
@@ -204,21 +201,22 @@ bool HttpResponseCommand::executeInternal()
       getFileEntry()->removeURIWhoseHostnameIs(us.host);
     }
   }
-  if(getPieceStorage().isNull()) {
+  if(!getPieceStorage()) {
     uint64_t totalLength = httpResponse->getEntityLength();
     getFileEntry()->setLength(totalLength);
     if(getFileEntry()->getPath().empty()) {
       getFileEntry()->setPath
         (util::createSafePath
-         (getDownloadContext()->getDir(), httpResponse->determinFilename()));
+         (getOption()->get(PREF_DIR), httpResponse->determinFilename()));
     }
     getFileEntry()->setContentType(httpResponse->getContentType());
     getRequestGroup()->preDownloadProcessing();
     if(getDownloadEngine()->getRequestGroupMan()->
        isSameFileBeingDownloaded(getRequestGroup())) {
-      throw DOWNLOAD_FAILURE_EXCEPTION
-        (StringFormat(EX_DUPLICATE_FILE_DOWNLOAD,
-                      getRequestGroup()->getFirstFilePath().c_str()).str());
+      throw DOWNLOAD_FAILURE_EXCEPTION2
+        (fmt(EX_DUPLICATE_FILE_DOWNLOAD,
+             getRequestGroup()->getFirstFilePath().c_str()),
+         error_code::DUPLICATE_DOWNLOAD);
     }
     // update last modified time
     updateLastModifiedTime(httpResponse->getLastModifiedTime());
@@ -293,11 +291,10 @@ bool HttpResponseCommand::handleDefaultEncoding
 (const SharedHandle<HttpResponse>& httpResponse)
 {
   SharedHandle<HttpRequest> httpRequest = httpResponse->getHttpRequest();
-  getRequestGroup()->adjustFilename
-    (SharedHandle<BtProgressInfoFile>(new DefaultBtProgressInfoFile
-                                      (getDownloadContext(),
-                                       SharedHandle<PieceStorage>(),
-                                       getOption().get())));
+  SharedHandle<BtProgressInfoFile> progressInfoFile
+    (new DefaultBtProgressInfoFile
+     (getDownloadContext(), SharedHandle<PieceStorage>(), getOption().get()));
+  getRequestGroup()->adjustFilename(progressInfoFile);
   getRequestGroup()->initPieceStorage();
 
   if(getOption()->getAsBool(PREF_DRY_RUN)) {
@@ -307,7 +304,7 @@ bool HttpResponseCommand::handleDefaultEncoding
 
   SharedHandle<CheckIntegrityEntry> checkEntry =
     getRequestGroup()->createCheckIntegrityEntry();
-  if(checkEntry.isNull()) {
+  if(!checkEntry) {
     return true;
   }
   File file(getRequestGroup()->getFirstFilePath());
@@ -323,7 +320,7 @@ bool HttpResponseCommand::handleDefaultEncoding
   // Therefore, we shutdown the socket here if pipelining is enabled.
   DownloadCommand* command = 0;
   if(getRequest()->getMethod() == Request::METHOD_GET &&
-     !segment.isNull() && segment->getPositionToWrite() == 0 &&
+     segment && segment->getPositionToWrite() == 0 &&
      !getRequest()->isPipeliningEnabled()) {
     command = createHttpDownloadCommand
       (httpResponse,
@@ -372,7 +369,7 @@ bool HttpResponseCommand::handleOtherEncoding
      getContentEncodingStreamFilter(httpResponse));
   // If chunked transfer-encoding is specified, we have to read end of
   // chunk markers(0\r\n\r\n, for example).
-  bool chunkedUsed = !streamFilter.isNull() &&
+  bool chunkedUsed = streamFilter &&
     streamFilter->getName() == ChunkedDecodingStreamFilter::NAME;
 
   // For zero-length file, check existing file comparing its size
@@ -386,9 +383,9 @@ bool HttpResponseCommand::handleOtherEncoding
     getRequestGroup()->initPieceStorage();
     getPieceStorage()->markAllPiecesDone();
     getDownloadContext()->setChecksumVerified(true);
-    getLogger()->notice(MSG_DOWNLOAD_ALREADY_COMPLETED,
-                        util::itos(getRequestGroup()->getGID()).c_str(),
-                        getRequestGroup()->getFirstFilePath().c_str());
+    A2_LOG_NOTICE(fmt(MSG_DOWNLOAD_ALREADY_COMPLETED,
+                      util::itos(getRequestGroup()->getGID()).c_str(),
+                      getRequestGroup()->getFirstFilePath().c_str()));
     poolConnection();
     return true;
   }
@@ -449,7 +446,7 @@ bool decideFileAllocation
 (const SharedHandle<StreamFilter>& filter)
 {
 #ifdef HAVE_LIBZ
-  for(SharedHandle<StreamFilter> f = filter; !f.isNull(); f = f->getDelegate()){
+  for(SharedHandle<StreamFilter> f = filter; f; f = f->getDelegate()){
     // Since the compressed file's length are returned in the response header
     // and the decompressed file size is unknown at this point, disable file
     // allocation here.
