@@ -37,59 +37,67 @@
 #include "DownloadEngine.h"
 #include "HttpServer.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "HttpServerCommand.h"
 #include "RequestGroupMan.h"
 #include "RecoverableException.h"
-#include "FileEntry.h"
+#include "wallclock.h"
+#include "util.h"
+#include "fmt.h"
 
 namespace aria2 {
 
 HttpServerResponseCommand::HttpServerResponseCommand
-(int32_t cuid,
+(cuid_t cuid,
  const SharedHandle<HttpServer>& httpServer,
  DownloadEngine* e,
- const SharedHandle<SocketCore>& socket):
-  Command(cuid),
-  _e(e),
-  _socket(socket),
-  _httpServer(httpServer)
+ const SharedHandle<SocketCore>& socket)
+ : Command(cuid),
+   e_(e),
+   socket_(socket),
+   httpServer_(httpServer)
 {
   setStatus(Command::STATUS_ONESHOT_REALTIME); 
-  _e->addSocketForWriteCheck(_socket, this);
+  e_->addSocketForWriteCheck(socket_, this);
 }
 
 HttpServerResponseCommand::~HttpServerResponseCommand()
 {
-  _e->deleteSocketForWriteCheck(_socket, this);
+  e_->deleteSocketForWriteCheck(socket_, this);
 }
 
 bool HttpServerResponseCommand::execute()
 {
-  if(_e->_requestGroupMan->downloadFinished() || _e->isHaltRequested()) {
+  if(e_->getRequestGroupMan()->downloadFinished() || e_->isHaltRequested()) {
     return true;
   }
   try {
-    _httpServer->sendResponse();
+    httpServer_->sendResponse();
   } catch(RecoverableException& e) {
-    logger->info("CUID#%d - Error occurred while transmitting response body.",
-                 e, cuid);
+    A2_LOG_INFO_EX
+      (fmt("CUID#%lld - Error occurred while transmitting response body.",
+           getCuid()),
+       e);
     return true;
   }
-  if(_httpServer->sendBufferIsEmpty()) {
-    logger->info("CUID#%d - HttpServer: all response transmitted.", cuid);
-    if(_httpServer->supportsPersistentConnection()) {
-      logger->info("CUID#%d - Persist connection.", cuid);
-      _e->commands.push_back
-        (new HttpServerCommand(cuid, _httpServer, _e, _socket));
+  if(httpServer_->sendBufferIsEmpty()) {
+    A2_LOG_INFO(fmt("CUID#%lld - HttpServer: all response transmitted.",
+                    getCuid()));
+    if(httpServer_->supportsPersistentConnection()) {
+      A2_LOG_INFO(fmt("CUID#%lld - Persist connection.",
+                      getCuid()));
+      e_->addCommand
+        (new HttpServerCommand(getCuid(), httpServer_, e_, socket_));
     }
     return true;
   } else {
-    if(_timeout.elapsed(10)) {
-      logger->info("CUID#%d - HttpServer: Timeout while trasmitting response.",
-                   cuid);
+    if(timeoutTimer_.difference(global::wallclock) >= 10) {
+      A2_LOG_INFO(fmt("CUID#%lld - HttpServer: Timeout while trasmitting"
+                      " response.",
+                      getCuid()));
       return true;
     } else {
-      _e->commands.push_back(this);
+      e_->addCommand(this);
       return false;
     }
   }
