@@ -32,12 +32,12 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_SERVER_RESPONSE_COMMAND_H_
-#define _D_HTTP_SERVER_RESPONSE_COMMAND_H_
+#ifndef D_HTTP_SERVER_RESPONSE_COMMAND_H
+#define D_HTTP_SERVER_RESPONSE_COMMAND_H
 
 #include "Command.h"
 #include "SharedHandle.h"
-#include "TimeA2.h"
+#include "TimerA2.h"
 
 namespace aria2 {
 
@@ -47,12 +47,12 @@ class HttpServer;
 
 class HttpServerResponseCommand : public Command {
 private:
-  DownloadEngine* _e;
-  SharedHandle<SocketCore> _socket;
-  SharedHandle<HttpServer> _httpServer;
-  Time _timeout;
+  DownloadEngine* e_;
+  SharedHandle<SocketCore> socket_;
+  SharedHandle<HttpServer> httpServer_;
+  Timer timeoutTimer_;
 public:
-  HttpServerResponseCommand(int32_t cuid,
+  HttpServerResponseCommand(cuid_t cuid,
                             const SharedHandle<HttpServer>& httpServer,
                             DownloadEngine* e,
                             const SharedHandle<SocketCore>& socket);
@@ -64,4 +64,4 @@ public:
 
 } // namespace aria2 
 
-#endif // _D_HTTP_SERVER_RESPONSE_COMMAND_H_
+#endif // D_HTTP_SERVER_RESPONSE_COMMAND_H
