@@ -41,10 +41,11 @@
 #include "Request.h"
 #include "DownloadEngine.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "HttpRequest.h"
 #include "Segment.h"
 #include "util.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "DlAbortEx.h"
 #include "HttpHeader.h"
 #include "prefs.h"
@@ -53,14 +54,11 @@
 #include "AuthConfigFactory.h"
 #include "AuthConfig.h"
 #include "DownloadContext.h"
-#include "RequestGroupMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
-#include "ServerStatMan.h"
 #include "StreamFilter.h"
 #include "BinaryStream.h"
 #include "NullSinkStreamFilter.h"
 #include "SinkStreamFilter.h"
+#include "error_code.h"
 
 namespace aria2 {
 
@@ -72,14 +70,14 @@ HttpSkipResponseCommand::HttpSkipResponseCommand
  const SharedHandle<HttpConnection>& httpConnection,
  const SharedHandle<HttpResponse>& httpResponse,
  DownloadEngine* e,
- const SharedHandle<SocketCore>& s):
-  AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
-  httpConnection_(httpConnection),
-  httpResponse_(httpResponse),
-  streamFilter_(new NullSinkStreamFilter()),
-  sinkFilterOnly_(true),
-  totalLength_(httpResponse_->getEntityLength()),
-  receivedBytes_(0)
+ const SharedHandle<SocketCore>& s)
+  : AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
+    httpConnection_(httpConnection),
+    httpResponse_(httpResponse),
+    streamFilter_(new NullSinkStreamFilter()),
+    sinkFilterOnly_(true),
+    totalLength_(httpResponse_->getEntityLength()),
+    receivedBytes_(0)
 {}
 
 HttpSkipResponseCommand::~HttpSkipResponseCommand() {}
@@ -87,7 +85,7 @@ HttpSkipResponseCommand::~HttpSkipResponseCommand() {}
 void HttpSkipResponseCommand::installStreamFilter
 (const SharedHandle<StreamFilter>& streamFilter)
 {
-  if(streamFilter.isNull()) {
+  if(!streamFilter) {
     return;
   }
   streamFilter->installDelegate(streamFilter_);
@@ -137,9 +135,7 @@ bool HttpSkipResponseCommand::executeInternal()
       throw DL_RETRY_EX(EX_GOT_EOF);
     }
   } catch(RecoverableException& e) {
-    if(getLogger()->debug()) {
-      getLogger()->debug(EX_EXCEPTION_CAUGHT, e);
-    }
+    A2_LOG_DEBUG_EX(EX_EXCEPTION_CAUGHT, e)
     return processResponse();
   }
 
@@ -175,33 +171,33 @@ void HttpSkipResponseCommand::poolConnection() const
 
 bool HttpSkipResponseCommand::processResponse()
 {
+  int statusCode;
   if(httpResponse_->isRedirect()) {
     unsigned int rnum =
       httpResponse_->getHttpRequest()->getRequest()->getRedirectCount();
     if(rnum >= Request::MAX_REDIRECT) {
-      throw DL_ABORT_EX
-        (StringFormat("Too many redirects: count=%u", rnum).str());
+      throw DL_ABORT_EX2(fmt("Too many redirects: count=%u", rnum),
+                         error_code::HTTP_TOO_MANY_REDIRECTS);
     }
     httpResponse_->processRedirect();
     return prepareForRetry(0);
-  } else if(httpResponse_->getResponseStatus() >= HttpHeader::S400) {
-    if(httpResponse_->getResponseStatus() == HttpHeader::S401) {
+  } else if((statusCode = httpResponse_->getStatusCode()) >= 400) {
+    if(statusCode == 401) {
       if(getOption()->getAsBool(PREF_HTTP_AUTH_CHALLENGE) &&
          !httpResponse_->getHttpRequest()->authenticationUsed() &&
          getDownloadEngine()->getAuthConfigFactory()->activateBasicCred
          (getRequest()->getHost(), getRequest()->getDir(), getOption().get())) {
         return prepareForRetry(0);
       } else {
-        throw DL_ABORT_EX(EX_AUTH_FAILED);
+        throw DL_ABORT_EX2(EX_AUTH_FAILED,
+                           error_code::HTTP_AUTH_FAILED);
       }
-    }else if(httpResponse_->getResponseStatus() == HttpHeader::S404) {
+    } else if(statusCode == 404) {
       throw DL_ABORT_EX2(MSG_RESOURCE_NOT_FOUND,
-                         downloadresultcode::RESOURCE_NOT_FOUND);
+                         error_code::RESOURCE_NOT_FOUND);
     } else {
-      throw DL_ABORT_EX
-        (StringFormat
-         (EX_BAD_STATUS,
-          util::parseUInt(httpResponse_->getResponseStatus())).str());
+      throw DL_ABORT_EX2(fmt(EX_BAD_STATUS, statusCode),
+                         error_code::HTTP_PROTOCOL_ERROR);
     }
   } else {
     return prepareForRetry(0);
