@@ -41,8 +41,7 @@ namespace aria2 {
 
 class DownloadContext;
 class PieceStorage;
-class Logger;
-class MessageDigestContext;
+class MessageDigest;
 
 class IteratableChecksumValidator:public IteratableValidator
 {
@@ -53,12 +52,9 @@ private:
 
   off_t currentOffset_;
 
-  SharedHandle<MessageDigestContext> ctx_;
-
-  Logger* logger_;
+  SharedHandle<MessageDigest> ctx_;
 
   unsigned char* buffer_;
-
 public:
   IteratableChecksumValidator(const SharedHandle<DownloadContext>& dctx,
                               const SharedHandle<PieceStorage>& pieceStorage);
