@@ -2,7 +2,7 @@
 /*
  * aria2 - The high speed download utility
  *
- * Copyright (C) 2006 Tatsuhiro Tsujikawa
+ * Copyright (C) 2010 Tatsuhiro Tsujikawa
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,20 +32,17 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_LOGGER_H_
-#define _D_LOGGER_H_
+#ifndef D_LOGGER_H
+#define D_LOGGER_H
 
 #include "common.h"
 
-#include <cstdarg>
 #include <string>
 #include <fstream>
-#include <iostream>
 
 namespace aria2 {
 
 class Exception;
-class LogFormatter;
 
 class Logger {
 public:
@@ -56,68 +53,48 @@ public:
     A2_WARN   = 1 << 3,
     A2_ERROR  = 1 << 4,
   };
-
-  static const std::string DEBUG_LABEL;
-
-  static const std::string NOTICE_LABEL;
-
-  static const std::string WARN_LABEL;
-
-  static const std::string ERROR_LABEL;
-
-  static const std::string INFO_LABEL;
 private:
-  LogFormatter* logFormatter_;
-
   LEVEL logLevel_;
-
   std::ofstream file_;
-
   int stdoutField_;
-  
-  bool levelEnabled(LEVEL level)
-  {
-    return (level >= logLevel_ && file_.is_open()) || stdoutField_&level;
-  }
-
-  void writeLog
-  (std::ostream& o, LEVEL logLevel, const std::string& logLevelLabel,
-   const char* msg, va_list ap);
-
-  void writeStackTrace
-  (std::ostream& o, LEVEL logLevel, const std::string& logLevelLabel,
-   const Exception& ex);
+  // Don't allow copying
+  Logger(const Logger&);
+  Logger& operator=(const Logger&);
 public:
   Logger();
 
-  virtual ~Logger();
+  ~Logger();
 
-  void debug(const char* msg, ...);
+  void log
+  (LEVEL level,
+   const char* sourceFile,
+   int lineNum,
+   const char* msg);
 
-  void debug(const char* msg, const Exception& ex, ...);
+  void log
+  (LEVEL level,
+   const char* sourceFile,
+   int lineNum,
+   const std::string& msg);
 
-  void info(const char* msg, ...);
+  void log
+  (LEVEL level,
+   const char* sourceFile,
+   int lineNum,
+   const char* msg,
+   const Exception& ex);
 
-  void info(const char* msg, const Exception& ex, ...);
-
-  void notice(const char* msg, ...);
-
-  void notice(const char* msg, const Exception& ex, ...);
-
-  void warn(const char* msg, ...);
-
-  void warn(const char* msg, const Exception& ex, ...);
-
-  void error(const char*  msg, ...);
-
-  void error(const char* msg, const Exception& ex, ...);
+  void log
+  (LEVEL level,
+   const char* sourceFile,
+   int lineNum,
+   const std::string& msg,
+   const Exception& ex);
 
   void openFile(const std::string& filename);
 
   void closeFile();
 
-  void setLogFormatter(LogFormatter* logFormatter);
-
   void setLogLevel(LEVEL level)
   {
     logLevel_ = level;
@@ -127,17 +104,9 @@ public:
 
   // Returns true if this logger actually writes debug log message to
   // either file or stdout.
-  bool debug()
-  {
-    return levelEnabled(A2_DEBUG);
-  }
-
-  bool info()
-  {
-    return levelEnabled(A2_INFO);
-  }
+  bool levelEnabled(LEVEL level);
 };
 
 } // namespace aria2
 
-#endif // _D_LOGGER_H_
+#endif // D_LOGGER_H
