@@ -36,34 +36,25 @@
 #define D_MESSAGE_DIGEST_HELPER_H
 
 #include "common.h"
-#include "SharedHandle.h"
-#include "messageDigest.h"
+
 #include <string>
 
+#include "SharedHandle.h"
+
 namespace aria2 {
 
 class BinaryStream;
+class MessageDigest;
 
 class MessageDigestHelper {
 private:
-  static MessageDigestContext* sha1Ctx_;
+  static SharedHandle<MessageDigest> sha1Ctx_;
+
+  MessageDigestHelper();
 public:
-  /**
-   * Returns message digest in hexadecimal representation.
-   * Digest algorithm is specified by algo.
-   */
-  static std::string digest(const std::string& algo, const SharedHandle<BinaryStream>& bs, off_t offset, uint64_t length);
-
-  static std::string digest(const std::string& algo, const void* data, size_t length);
-
-  static std::string digestString(const std::string& algo, const std::string& data)
-  {
-    return digest(algo, data.c_str(), data.size());
-  }
-
   /**
    * staticSHA1DigestInit(), staticSHA1DigestFree(), staticSHA1Digest()
-   * use statically declared MessageDigestContext sha1Ctx_.
+   * use statically declared MessageDigest sha1Ctx_.
    */
   /**
    * Initializes sha1Ctx_
@@ -75,29 +66,26 @@ public:
    */
   static void staticSHA1DigestFree();
 
-  static std::string staticSHA1Digest(const SharedHandle<BinaryStream>& bs,
-                                      off_t offset, uint64_t length);
+  static std::string staticSHA1DigestHexDigest
+  (const SharedHandle<BinaryStream>& bs, off_t offset, uint64_t length);
 
   /**
    * ctx must be initialized or reseted before calling this function.
+   * Returns hex digest string, not *raw* digest
    */
-  static std::string digest(MessageDigestContext* ctx,
-                            const SharedHandle<BinaryStream>& bs,
-                            off_t offset, uint64_t length);
-
-  /**
-   * Calculates message digest of file denoted by filename.
-   * Returns message digest in hexadecimal representation.
-   * Digest algorithm is specified by algo.
-   */
-  static std::string digest(const std::string& algo, const std::string& filename);
+  static std::string hexDigest
+  (const SharedHandle<MessageDigest>& ctx,
+   const SharedHandle<BinaryStream>& bs,
+   off_t offset, uint64_t length);
 
   /**
    * Stores *raw* message digest into md.
    * Throws exception when mdLength is less than the size of message digest.
    */
-  static void digest(unsigned char* md, size_t mdLength,
-                     const std::string& algo, const void* data, size_t length);
+  static void digest
+  (unsigned char* md, size_t mdLength,
+   const SharedHandle<MessageDigest>& ctx,
+   const void* data, size_t length);
 };
 
 } // namespace aria2
