@@ -46,15 +46,19 @@
 #include "DefaultDiskWriterFactory.h"
 #include "DlAbortEx.h"
 #include "File.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "SimpleRandomizer.h"
 
 namespace aria2 {
 
-DiskWriterEntry::DiskWriterEntry(const SharedHandle<FileEntry>& fileEntry):
-  fileEntry_(fileEntry), open_(false), directIO_(false),
-  needsFileAllocation_(false) {}
+DiskWriterEntry::DiskWriterEntry(const SharedHandle<FileEntry>& fileEntry)
+  : fileEntry_(fileEntry),
+    open_(false),
+    directIO_(false),
+    needsFileAllocation_(false)
+{}
 
 const std::string& DiskWriterEntry::getFilePath() const
 {
@@ -63,7 +67,7 @@ const std::string& DiskWriterEntry::getFilePath() const
 
 void DiskWriterEntry::initAndOpenFile()
 {
-  if(!diskWriter_.isNull()) {
+  if(diskWriter_) {
     diskWriter_->initAndOpenFile(fileEntry_->getLength());
     if(directIO_) {
       diskWriter_->enableDirectIO();
@@ -74,7 +78,7 @@ void DiskWriterEntry::initAndOpenFile()
 
 void DiskWriterEntry::openFile()
 {
-  if(!diskWriter_.isNull()) {
+  if(diskWriter_) {
     diskWriter_->openFile(fileEntry_->getLength());
     if(directIO_) {
       diskWriter_->enableDirectIO();
@@ -85,7 +89,7 @@ void DiskWriterEntry::openFile()
 
 void DiskWriterEntry::openExistingFile()
 {
-  if(!diskWriter_.isNull()) {
+  if(diskWriter_) {
     diskWriter_->openExistingFile(fileEntry_->getLength());
     if(directIO_) {
       diskWriter_->enableDirectIO();
@@ -119,7 +123,7 @@ void DiskWriterEntry::setDiskWriter(const SharedHandle<DiskWriter>& diskWriter)
 
 bool DiskWriterEntry::operator<(const DiskWriterEntry& entry) const
 {
-  return fileEntry_ < entry.fileEntry_;
+  return *fileEntry_ < *entry.fileEntry_;
 }
 
 void DiskWriterEntry::enableDirectIO()
@@ -138,13 +142,17 @@ void DiskWriterEntry::disableDirectIO()
   directIO_ = false;
 }
 
-MultiDiskAdaptor::MultiDiskAdaptor():
-  pieceLength_(0),
-  maxOpenFiles_(DEFAULT_MAX_OPEN_FILES),
-  directIOAllowed_(false),
-  readOnly_(false) {}
+MultiDiskAdaptor::MultiDiskAdaptor()
+  : pieceLength_(0),
+    maxOpenFiles_(DEFAULT_MAX_OPEN_FILES),
+    directIOAllowed_(false),
+    readOnly_(false)
+{}
 
-static SharedHandle<DiskWriterEntry> createDiskWriterEntry
+MultiDiskAdaptor::~MultiDiskAdaptor() {}
+
+namespace {
+SharedHandle<DiskWriterEntry> createDiskWriterEntry
 (const SharedHandle<FileEntry>& fileEntry,
  bool needsFileAllocation)
 {
@@ -152,6 +160,7 @@ static SharedHandle<DiskWriterEntry> createDiskWriterEntry
   entry->needsFileAllocation(needsFileAllocation);
   return entry;
 } 
+} // namespace
 
 void MultiDiskAdaptor::resetDiskWriterEntries()
 {
@@ -203,29 +212,25 @@ void MultiDiskAdaptor::resetDiskWriterEntries()
         off_t lastPieceStartOffset =
           (fileEntry->getOffset()+fileEntry->getLength()-1)/
           pieceLength_*pieceLength_;
-        if(getLogger()->debug()) {
-          getLogger()->debug("Checking adjacent backward file to %s"
-                             " whose lastPieceStartOffset+pieceLength_=%lld",
-                             fileEntry->getPath().c_str(),
-                             lastPieceStartOffset+pieceLength_);
-        }
+        A2_LOG_DEBUG(fmt("Checking adjacent backward file to %s"
+                         " whose lastPieceStartOffset+pieceLength_=%lld",
+                         fileEntry->getPath().c_str(),
+                         static_cast<long long int>
+                         (lastPieceStartOffset+pieceLength_)));
         ++itr;
         // adjacent backward files are not needed to be allocated. They
         // just requre DiskWriter
         for(; itr != eoi &&
               (!(*itr)->getFileEntry()->isRequested() ||
                (*itr)->getFileEntry()->getLength() == 0); ++itr) {
-          if(getLogger()->debug()) {
-            getLogger()->debug("file=%s, offset=%lld",
-                               (*itr)->getFileEntry()->getPath().c_str(),
-                               (*itr)->getFileEntry()->getOffset());
-          }
+          A2_LOG_DEBUG(fmt("file=%s, offset=%lld",
+                           (*itr)->getFileEntry()->getPath().c_str(),
+                           static_cast<long long int>
+                           ((*itr)->getFileEntry()->getOffset())));
           if((*itr)->getFileEntry()->getOffset() <
              static_cast<off_t>(lastPieceStartOffset+pieceLength_)) {
-            if(getLogger()->debug()) {
-              getLogger()->debug("%s needs diskwriter",
-                                 (*itr)->getFileEntry()->getPath().c_str());
-            }
+            A2_LOG_DEBUG(fmt("%s needs diskwriter",
+                             (*itr)->getFileEntry()->getPath().c_str()));
             dwreq[(*itr)->getFileEntry()->getPath()] = true;
           } else {
             break;
@@ -245,10 +250,8 @@ void MultiDiskAdaptor::resetDiskWriterEntries()
     if((*i)->needsFileAllocation() ||
        dwreq.find((*i)->getFileEntry()->getPath()) != dwreq.end() ||
        (*i)->fileExists()) {
-      if(getLogger()->debug()) {
-        getLogger()->debug("Creating DiskWriter for filename=%s",
-                           (*i)->getFilePath().c_str());
-      }
+      A2_LOG_DEBUG(fmt("Creating DiskWriter for filename=%s",
+                       (*i)->getFilePath().c_str()));
       (*i)->setDiskWriter(dwFactory.newDiskWriter((*i)->getFilePath()));
       if(directIOAllowed_) {
         (*i)->getDiskWriter()->allowDirectIO();
@@ -260,21 +263,12 @@ void MultiDiskAdaptor::resetDiskWriterEntries()
   }
 }
 
-void MultiDiskAdaptor::mkdir() const
-{
-  for(std::vector<SharedHandle<DiskWriterEntry> >::const_iterator i =
-        diskWriterEntries_.begin(), eoi = diskWriterEntries_.end();
-      i != eoi; ++i) {
-    (*i)->getFileEntry()->setupDir();
-  }
-}
-
 void MultiDiskAdaptor::openIfNot
 (const SharedHandle<DiskWriterEntry>& entry, void (DiskWriterEntry::*open)())
 {
   if(!entry->isOpen()) {
-    //     getLogger()->debug("DiskWriterEntry: Cache MISS. offset=%s",
-    //            util::itos(entry->getFileEntry()->getOffset()).c_str());
+    //     A2_LOG_DEBUG(fmt("DiskWriterEntry: Cache MISS. offset=%s",
+    //            util::itos(entry->getFileEntry()->getOffset()).c_str()));
  
     size_t numOpened = openedDiskWriterEntries_.size();
     (entry.get()->*open)();
@@ -292,15 +286,17 @@ void MultiDiskAdaptor::openIfNot
       openedDiskWriterEntries_.push_back(entry);
     } 
   } else {
-    //     getLogger()->debug("DiskWriterEntry: Cache HIT. offset=%s",
-    //            util::itos(entry->getFileEntry()->getOffset()).c_str());
+    //     A2_LOG_DEBUG(fmt("DiskWriterEntry: Cache HIT. offset=%s",
+    //            util::itos(entry->getFileEntry()->getOffset()).c_str()));
   }
 }
 
 void MultiDiskAdaptor::openFile()
 {
   resetDiskWriterEntries();
-  mkdir();
+  // util::mkdir() is called in AbstractDiskWriter::createFile(), so
+  // we don't need to call it here.
+
   // Call DiskWriterEntry::openFile to make sure that zero-length files are
   // created.
   for(DiskWriterEntries::const_iterator itr = diskWriterEntries_.begin(),
@@ -312,7 +308,9 @@ void MultiDiskAdaptor::openFile()
 void MultiDiskAdaptor::initAndOpenFile()
 {
   resetDiskWriterEntries();
-  mkdir();
+  // util::mkdir() is called in AbstractDiskWriter::createFile(), so
+  // we don't need to call it here.
+
   // Call DiskWriterEntry::initAndOpenFile to make files truncated.
   for(DiskWriterEntries::const_iterator itr = diskWriterEntries_.begin(),
         eoi = diskWriterEntries_.end(); itr != eoi; ++itr) {
@@ -332,15 +330,18 @@ void MultiDiskAdaptor::closeFile()
                 mem_fun_sh(&DiskWriterEntry::closeFile));
 }
 
-static bool isInRange(const DiskWriterEntryHandle entry, off_t offset)
+namespace {
+bool isInRange(const DiskWriterEntryHandle entry, off_t offset)
 {
   return entry->getFileEntry()->getOffset() <= offset &&
     (uint64_t)offset <
     entry->getFileEntry()->getOffset()+entry->getFileEntry()->getLength();
 }
+} // namespace
 
-static size_t calculateLength(const DiskWriterEntryHandle entry,
-                              off_t fileOffset, size_t rem)
+namespace {
+size_t calculateLength(const DiskWriterEntryHandle entry,
+                       off_t fileOffset, size_t rem)
 {
   size_t length;
   if(entry->getFileEntry()->getLength() < (uint64_t)fileOffset+rem) {
@@ -350,6 +351,7 @@ static size_t calculateLength(const DiskWriterEntryHandle entry,
   }
   return length;
 }
+} // namespace
 
 namespace {
 class OffsetCompare {
@@ -359,10 +361,10 @@ public:
     return offset < dwe->getFileEntry()->getOffset();
   }
 };
-}
+} // namespace
 
-static DiskWriterEntries::const_iterator
-findFirstDiskWriterEntry
+namespace {
+DiskWriterEntries::const_iterator findFirstDiskWriterEntry
 (const DiskWriterEntries& diskWriterEntries, off_t offset)
 {
   DiskWriterEntries::const_iterator first =
@@ -374,20 +376,23 @@ findFirstDiskWriterEntry
   // In case when offset is out-of-range
   if(!isInRange(*first, offset)) {
     throw DL_ABORT_EX
-      (StringFormat(EX_FILE_OFFSET_OUT_OF_RANGE,
-                    util::itos(offset, true).c_str()).str());
+      (fmt(EX_FILE_OFFSET_OUT_OF_RANGE,
+           util::itos(offset, true).c_str()));
   }
   return first;
 }
+} // namespace
 
-static void throwOnDiskWriterNotOpened(const SharedHandle<DiskWriterEntry>& e,
-                                       off_t offset)
+namespace {
+void throwOnDiskWriterNotOpened(const SharedHandle<DiskWriterEntry>& e,
+                                off_t offset)
 {
   throw DL_ABORT_EX
-    (StringFormat("DiskWriter for offset=%s, filename=%s is not opened.",
-                  util::itos(offset).c_str(),
-                  e->getFilePath().c_str()).str());  
+    (fmt("DiskWriter for offset=%s, filename=%s is not opened.",
+         util::itos(offset).c_str(),
+         e->getFilePath().c_str()));  
 }
+} // namespace
 
 void MultiDiskAdaptor::writeData(const unsigned char* data, size_t len,
                                  off_t offset)
