@@ -54,12 +54,9 @@
 #include "File.h"
 #include "Netrc.h"
 #include "AuthConfigFactory.h"
-#include "DownloadContext.h"
 #include "SessionSerializer.h"
-#include "ServerStatMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
 #include "TimeA2.h"
+#include "fmt.h"
 #ifdef ENABLE_SSL
 # include "SocketCore.h"
 # include "TLSContext.h"
@@ -73,7 +70,8 @@ extern volatile sig_atomic_t globalHaltRequested;
 
 } // namespace global
 
-static void handler(int signal) {
+namespace {
+void handler(int signal) {
   if(
 #ifdef SIGHUP
      signal == SIGHUP ||
@@ -90,18 +88,17 @@ static void handler(int signal) {
     }
   }
 }
+} // namespace
 
 MultiUrlRequestInfo::MultiUrlRequestInfo
 (const std::vector<SharedHandle<RequestGroup> >& requestGroups,
  const SharedHandle<Option>& op,
  const SharedHandle<StatCalc>& statCalc,
  std::ostream& summaryOut)
-  :
-  requestGroups_(requestGroups),
-  option_(op),
-  statCalc_(statCalc),
-  summaryOut_(summaryOut),
-  logger_(LogFactory::getInstance())
+  : requestGroups_(requestGroups),
+    option_(op),
+    statCalc_(statCalc),
+    summaryOut_(summaryOut)
 {}
 
 MultiUrlRequestInfo::~MultiUrlRequestInfo() {}
@@ -115,9 +112,9 @@ void MultiUrlRequestInfo::printMessageForContinue()
               << "\n";
 }
 
-downloadresultcode::RESULT MultiUrlRequestInfo::execute()
+error_code::Value MultiUrlRequestInfo::execute()
 {
-  downloadresultcode::RESULT returnValue = downloadresultcode::FINISHED;
+  error_code::Value returnValue = error_code::FINISHED;
   try {
     DownloadEngineHandle e =
       DownloadEngineFactory().newDownloadEngine(option_.get(), requestGroups_);
@@ -126,10 +123,11 @@ downloadresultcode::RESULT MultiUrlRequestInfo::execute()
       File cookieFile(option_->get(PREF_LOAD_COOKIES));
       if(cookieFile.isFile()) {
         e->getCookieStorage()->load(cookieFile.getPath(), Time().getTime());
-        logger_->info("Loaded cookies from '%s'.",
-                      cookieFile.getPath().c_str());
+        A2_LOG_INFO(fmt("Loaded cookies from '%s'.",
+                        cookieFile.getPath().c_str()));
       } else {
-        logger_->error(MSG_LOADING_COOKIE_FAILED, cookieFile.getPath().c_str());
+        A2_LOG_ERROR(fmt(MSG_LOADING_COOKIE_FAILED,
+                         cookieFile.getPath().c_str()));
       }
     }
 
@@ -138,8 +136,8 @@ downloadresultcode::RESULT MultiUrlRequestInfo::execute()
     if(!option_->getAsBool(PREF_NO_NETRC) && netrccf.isFile()) {
       mode_t mode = netrccf.mode();
       if(mode&(S_IRWXG|S_IRWXO)) {
-        logger_->notice(MSG_INCORRECT_NETRC_PERMISSION,
-                        option_->get(PREF_NETRC_PATH).c_str());
+        A2_LOG_NOTICE(fmt(MSG_INCORRECT_NETRC_PERMISSION,
+                          option_->get(PREF_NETRC_PATH).c_str()));
       } else {
         SharedHandle<Netrc> netrc(new Netrc());
         netrc->parse(option_->get(PREF_NETRC_PATH));
@@ -157,10 +155,10 @@ downloadresultcode::RESULT MultiUrlRequestInfo::execute()
     }
     if(!option_->blank(PREF_CA_CERTIFICATE)) {
       if(!tlsContext->addTrustedCACertFile(option_->get(PREF_CA_CERTIFICATE))) {
-        logger_->info(MSG_WARN_NO_CA_CERT);
+        A2_LOG_INFO(MSG_WARN_NO_CA_CERT);
       }
     } else if(option_->getAsBool(PREF_CHECK_CERTIFICATE)) {
-      logger_->info(MSG_WARN_NO_CA_CERT);
+      A2_LOG_INFO(MSG_WARN_NO_CA_CERT);
     }
     if(option_->getAsBool(PREF_CHECK_CERTIFICATE)) {
       tlsContext->enablePeerVerification();
@@ -168,8 +166,8 @@ downloadresultcode::RESULT MultiUrlRequestInfo::execute()
     SocketCore::setTLSContext(tlsContext);
 #endif
     if(!Timer::monotonicClock()) {
-      logger_->warn("Don't change system time while aria2c is running."
-                    " Doing this may make aria2c hang for long time.");
+      A2_LOG_WARN("Don't change system time while aria2c is running."
+                  " Doing this may make aria2c hang for long time.");
     }
 
     std::string serverStatIf = option_->get(PREF_SERVER_STAT_IF);
@@ -202,9 +200,9 @@ downloadresultcode::RESULT MultiUrlRequestInfo::execute()
       e->getRequestGroupMan()->getDownloadStat();
     if(!s.allCompleted()) {
       printMessageForContinue();
-      if(s.getLastErrorResult() == downloadresultcode::FINISHED &&
+      if(s.getLastErrorResult() == error_code::FINISHED &&
          s.getInProgress() > 0) {
-        returnValue = downloadresultcode::IN_PROGRESS;
+        returnValue = error_code::IN_PROGRESS;
       } else {
         returnValue = s.getLastErrorResult();
       }
@@ -214,18 +212,18 @@ downloadresultcode::RESULT MultiUrlRequestInfo::execute()
     if(!option_->blank(PREF_SAVE_SESSION)) {
       const std::string& filename = option_->get(PREF_SAVE_SESSION);
       if(sessionSerializer.save(filename)) {
-        logger_->notice("Serialized session to '%s' successfully.",
-                        filename.c_str());
+        A2_LOG_NOTICE(fmt("Serialized session to '%s' successfully.",
+                          filename.c_str()));
       } else {
-        logger_->notice("Failed to serialize session to '%s'.",
-                        filename.c_str());
+        A2_LOG_NOTICE(fmt("Failed to serialize session to '%s'.",
+                          filename.c_str()));
       }
     }
   } catch(RecoverableException& e) {
-    if(returnValue == downloadresultcode::FINISHED) {
-      returnValue = downloadresultcode::UNKNOWN_ERROR;
+    if(returnValue == error_code::FINISHED) {
+      returnValue = error_code::UNKNOWN_ERROR;
     }
-    logger_->error(EX_EXCEPTION_CAUGHT, e);
+    A2_LOG_ERROR_EX(EX_EXCEPTION_CAUGHT, e);
   }
 #ifdef SIGHUP
   util::setGlobalSignalHandler(SIGHUP, SIG_DFL, 0);
