@@ -40,7 +40,7 @@
 #include "A2STR.h"
 #include "util.h"
 #include "help_tags.h"
-#include "StringFormat.h"
+#include "a2functional.h"
 #include "File.h"
 
 namespace aria2 {
@@ -53,7 +53,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ALLOW_OVERWRITE,
                                     TEXT_ALLOW_OVERWRITE,
-                                    V_FALSE));
+                                    A2_V_FALSE,
+                                    OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_FILE);
     handlers.push_back(op);
@@ -62,7 +63,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ALLOW_PIECE_LENGTH_CHANGE,
                                     TEXT_ALLOW_PIECE_LENGTH_CHANGE,
-                                    V_FALSE));
+                                    A2_V_FALSE,
+                                    OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
   }
@@ -70,7 +72,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ALWAYS_RESUME,
                                     TEXT_ALWAYS_RESUME,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_FTP);
@@ -82,7 +84,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ASYNC_DNS,
                                     TEXT_ASYNC_DNS,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
@@ -92,7 +94,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_AUTO_FILE_RENAMING,
                                     TEXT_AUTO_FILE_RENAMING,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_FILE);
@@ -112,7 +114,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_CHECK_INTEGRITY,
                                     TEXT_CHECK_INTEGRITY,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG,
                                     'V'));
     op->addTag(TAG_BASIC);
@@ -126,7 +128,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_CONDITIONAL_GET,
                                     TEXT_CONDITIONAL_GET,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_HTTP);
@@ -136,7 +138,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
                                    (PREF_CONF_PATH,
                                     TEXT_CONF_PATH,
-                                    util::getHomeDir()+"/.aria2/aria2.conf"));
+                                    util::getHomeDir()+"/.aria2/aria2.conf",
+                                    PATH_TO_FILE));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
   }
@@ -144,8 +147,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_CONTINUE,
                                     TEXT_CONTINUE,
-                                    V_FALSE, // TODO ommit?
-                                    OptionHandler::NO_ARG,
+                                    A2_V_FALSE,
+                                    OptionHandler::OPT_ARG,
                                     'c'));
     op->addTag(TAG_BASIC);
     op->addTag(TAG_FTP);
@@ -156,9 +159,9 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_DAEMON,
                                     TEXT_DAEMON,
-                                    V_FALSE,
-                                    OptionHandler::NO_ARG,
-                                    'D')); // TODO ommit?
+                                    A2_V_FALSE,
+                                    OptionHandler::OPT_ARG,
+                                    'D'));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
   }
@@ -167,7 +170,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_DIR,
                                     TEXT_DIR,
                                     File::getCurrentDir(),
-                                    A2STR::NIL,
+                                    PATH_TO_DIR,
                                     OptionHandler::REQ_ARG,
                                     'd'));
     op->addTag(TAG_BASIC);
@@ -178,7 +181,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_DISABLE_IPV6,
                                     TEXT_DISABLE_IPV6,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
@@ -197,7 +200,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_ASYNC_DNS6,
                                     TEXT_ENABLE_ASYNC_DNS6,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
@@ -208,7 +211,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_DIRECT_IO,
                                     TEXT_ENABLE_DIRECT_IO,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_FILE);
@@ -220,7 +223,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_XML_RPC,
                                     TEXT_ENABLE_XML_RPC,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_XML_RPC);
     handlers.push_back(op);
@@ -277,7 +280,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_FORCE_SEQUENTIAL,
                                     TEXT_FORCE_SEQUENTIAL,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG,
                                     'Z'));
     op->addTag(TAG_BASIC);
@@ -287,7 +290,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_HUMAN_READABLE,
                                     TEXT_HUMAN_READABLE,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
@@ -297,7 +300,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_INPUT_FILE,
                                     TEXT_INPUT_FILE,
                                     NO_DEFAULT_VALUE,
-                                    "FILENAME,-",
+                                    PATH_TO_FILE_STDIN,
                                     OptionHandler::REQ_ARG,
                                     'i'));
     op->addTag(TAG_BASIC);
@@ -318,7 +321,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_LOG,
                                     TEXT_LOG,
                                     NO_DEFAULT_VALUE,
-                                    "FILENAME,-",
+                                    PATH_TO_FILE_STDOUT,
                                     OptionHandler::REQ_ARG,
                                     'l'));
     op->addTag(TAG_BASIC);
@@ -350,8 +353,11 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_MAX_CONNECTION_PER_SERVER,
                                     TEXT_MAX_CONNECTION_PER_SERVER,
                                     "1",
-                                    1, 4));
-    op->addTag(TAG_ADVANCED);
+                                    1, 16,
+                                    'x'));
+    op->addTag(TAG_BASIC);
+    op->addTag(TAG_FTP);
+    op->addTag(TAG_HTTP);
     handlers.push_back(op);
   }
   {
@@ -365,6 +371,15 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new NumberOptionHandler
+                                   (PREF_MAX_DOWNLOAD_RESULT,
+                                    TEXT_MAX_DOWNLOAD_RESULT,
+                                    "1000",
+                                    0));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<OptionHandler> op(new UnitNumberOptionHandler
                                    (PREF_MAX_OVERALL_DOWNLOAD_LIMIT,
@@ -392,8 +407,9 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_MIN_SPLIT_SIZE,
                                     TEXT_MIN_SPLIT_SIZE,
                                     "20M",
-                                    1024*1024, 1024*1024*1024));
-    op->addTag(TAG_ADVANCED);
+                                    1024*1024, 1024*1024*1024,
+                                    'k'));
+    op->addTag(TAG_BASIC);
     op->addTag(TAG_FTP);
     op->addTag(TAG_HTTP);
     handlers.push_back(op);    
@@ -402,8 +418,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_NO_CONF,
                                     TEXT_NO_CONF,
-                                    V_FALSE,
-                                    OptionHandler::NO_ARG));
+                                    A2_V_FALSE,
+                                    OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
   }
@@ -422,7 +438,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_ON_DOWNLOAD_COMPLETE,
                                     TEXT_ON_DOWNLOAD_COMPLETE,
                                     NO_DEFAULT_VALUE,
-                                    "/path/to/command"));
+                                    PATH_TO_COMMAND));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_HOOK);
     handlers.push_back(op);
@@ -432,7 +448,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_ON_DOWNLOAD_ERROR,
                                     TEXT_ON_DOWNLOAD_ERROR,
                                     NO_DEFAULT_VALUE,
-                                    "/path/to/command"));
+                                    PATH_TO_COMMAND));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_HOOK);
     handlers.push_back(op);
@@ -442,7 +458,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_ON_DOWNLOAD_PAUSE,
                                     TEXT_ON_DOWNLOAD_PAUSE,
                                     NO_DEFAULT_VALUE,
-                                    "/path/to/command"));
+                                    PATH_TO_COMMAND));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_HOOK);
     handlers.push_back(op);
@@ -452,7 +468,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_ON_DOWNLOAD_START,
                                     TEXT_ON_DOWNLOAD_START,
                                     NO_DEFAULT_VALUE,
-                                    "/path/to/command"));
+                                    PATH_TO_COMMAND));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_HOOK);
     handlers.push_back(op);
@@ -462,7 +478,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_ON_DOWNLOAD_STOP,
                                     TEXT_ON_DOWNLOAD_STOP,
                                     NO_DEFAULT_VALUE,
-                                    "/path/to/command"));
+                                    PATH_TO_COMMAND));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_HOOK);
     handlers.push_back(op);
@@ -471,7 +487,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_PARAMETERIZED_URI,
                                     TEXT_PARAMETERIZED_URI,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG,
                                     'P'));  
     op->addTag(TAG_ADVANCED);
@@ -481,7 +497,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_QUIET,
                                     TEXT_QUIET,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG,
                                     'q'));
     op->addTag(TAG_ADVANCED);
@@ -492,7 +508,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_REALTIME_CHUNK_CHECKSUM,
                                     TEXT_REALTIME_CHUNK_CHECKSUM,
-                                    V_TRUE));
+                                    A2_V_TRUE,
+                                    OptionHandler::OPT_ARG));
     op->addTag(TAG_METALINK);
     handlers.push_back(op);
   }
@@ -501,7 +518,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_REMOVE_CONTROL_FILE,
                                     TEXT_REMOVE_CONTROL_FILE,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
@@ -511,7 +528,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_SAVE_SESSION,
                                     TEXT_SAVE_SESSION,
                                     NO_DEFAULT_VALUE,
-                                    "FILENAME"));
+                                    PATH_TO_FILE));
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
   }
@@ -519,7 +536,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_SELECT_LEAST_USED_HOST,
                                     NO_DEFAULT_VALUE,
-                                    V_TRUE));
+                                    A2_V_TRUE));
     op->hide();
     handlers.push_back(op);
   }
@@ -546,7 +563,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_XML_RPC_LISTEN_ALL,
                                     TEXT_XML_RPC_LISTEN_ALL,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_XML_RPC);
     handlers.push_back(op);
@@ -599,7 +616,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_DRY_RUN,
                                     TEXT_DRY_RUN,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_FTP);
     op->addTag(TAG_HTTP);
@@ -640,8 +657,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_NO_NETRC,
                                     TEXT_NO_NETRC,
-                                    V_FALSE, // TODO ommit?
-                                    OptionHandler::NO_ARG,
+                                    A2_V_FALSE,
+                                    OptionHandler::OPT_ARG,
                                     'n'));
     op->addTag(TAG_FTP);
     op->addTag(TAG_HTTP);
@@ -652,7 +669,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_OUT,
                                     TEXT_OUT,
                                     NO_DEFAULT_VALUE,
-                                    "FILENAME",
+                                    PATH_TO_FILE,
                                     OptionHandler::REQ_ARG,
                                     'o'));
     op->addTag(TAG_BASIC);
@@ -665,7 +682,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_REMOTE_TIME,
                                     TEXT_REMOTE_TIME,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG,
                                     'R'));
     op->addTag(TAG_FTP);
@@ -676,7 +693,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_REUSE_URI,
                                     TEXT_REUSE_URI,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_FTP);
     op->addTag(TAG_HTTP);
@@ -696,7 +713,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_SERVER_STAT_IF,
                                     TEXT_SERVER_STAT_IF,
                                     NO_DEFAULT_VALUE,
-                                    "FILENAME"));
+                                    PATH_TO_FILE));
     op->addTag(TAG_FTP);
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -706,7 +723,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_SERVER_STAT_OF,
                                     TEXT_SERVER_STAT_OF,
                                     NO_DEFAULT_VALUE,
-                                    "FILENAME"));
+                                    PATH_TO_FILE));
     op->addTag(TAG_FTP);
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -770,7 +787,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
                                    (PREF_CA_CERTIFICATE,
                                     TEXT_CA_CERTIFICATE,
-                                    CA_BUNDLE));
+                                    CA_BUNDLE,
+                                    PATH_TO_FILE));
     op->addTag(TAG_HTTP);
     op->addTag(TAG_HTTPS);
     handlers.push_back(op);
@@ -778,7 +796,9 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
   {
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
                                    (PREF_CERTIFICATE,
-                                    TEXT_CERTIFICATE));
+                                    TEXT_CERTIFICATE,
+                                    NO_DEFAULT_VALUE,
+                                    PATH_TO_FILE));
     op->addTag(TAG_HTTP);
     op->addTag(TAG_HTTPS);
     handlers.push_back(op);
@@ -787,7 +807,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_CHECK_CERTIFICATE,
                                     TEXT_CHECK_CERTIFICATE,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     op->addTag(TAG_HTTPS);
@@ -797,7 +817,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_HTTP_KEEP_ALIVE,
                                     TEXT_ENABLE_HTTP_KEEP_ALIVE,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -806,7 +826,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_HTTP_PIPELINING,
                                     TEXT_ENABLE_HTTP_PIPELINING,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -824,7 +844,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_HTTP_ACCEPT_GZIP,
                                     TEXT_HTTP_ACCEPT_GZIP,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -833,7 +853,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_HTTP_AUTH_CHALLENGE,
                                     TEXT_HTTP_AUTH_CHALLENGE,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -842,7 +862,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_HTTP_NO_CACHE,
                                     TEXT_HTTP_NO_CACHE,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -868,7 +888,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_LOAD_COOKIES,
                                     TEXT_LOAD_COOKIES,
                                     NO_DEFAULT_VALUE,
-                                    "/path/to/file"));
+                                    PATH_TO_FILE));
     op->addTag(TAG_BASIC);
     op->addTag(TAG_HTTP);
     op->addTag(TAG_COOKIE);
@@ -886,7 +906,9 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
   {
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
                                    (PREF_PRIVATE_KEY,
-                                    TEXT_PRIVATE_KEY));
+                                    TEXT_PRIVATE_KEY,
+                                    NO_DEFAULT_VALUE,
+                                    PATH_TO_FILE));
     op->addTag(TAG_HTTP);
     op->addTag(TAG_HTTPS);
     handlers.push_back(op);
@@ -903,7 +925,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_SAVE_COOKIES,
                                     TEXT_SAVE_COOKIES,
                                     NO_DEFAULT_VALUE,
-                                    "/path/to/file"));
+                                    PATH_TO_FILE));
     op->addTag(TAG_HTTP);
     op->addTag(TAG_COOKIE);
     handlers.push_back(op);
@@ -912,7 +934,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_USE_HEAD,
                                     TEXT_USE_HEAD,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -941,7 +963,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_FTP_PASV,
                                     TEXT_FTP_PASV,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG,
                                     'p'));
     op->addTag(TAG_FTP);
@@ -951,7 +973,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_FTP_REUSE_CONNECTION,
                                     TEXT_FTP_REUSE_CONNECTION,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_FTP);
     handlers.push_back(op);
@@ -978,7 +1000,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                           (PREF_NETRC_PATH,
                                            NO_DESCRIPTION,
                                            util::getHomeDir()+"/.netrc",
-                                           "/PATH/TO/NETRC"));
+                                           PATH_TO_FILE));
     op->hide();
     handlers.push_back(op);
   }
@@ -1125,8 +1147,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_SHOW_FILES,
                                     TEXT_SHOW_FILES,
-                                    V_FALSE, // TODO ommit?
-                                    OptionHandler::NO_ARG,
+                                    A2_V_FALSE,
+                                    OptionHandler::OPT_ARG,
                                     'S'));
     op->addTag(TAG_BASIC);
     op->addTag(TAG_BITTORRENT);
@@ -1140,7 +1162,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_BT_ENABLE_LPD,
                                     TEXT_BT_ENABLE_LPD,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
@@ -1177,7 +1199,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_BT_HASH_CHECK_SEED,
                                     TEXT_BT_HASH_CHECK_SEED,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
@@ -1215,7 +1237,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_BT_METADATA_ONLY,
                                     TEXT_BT_METADATA_ONLY,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
@@ -1249,7 +1271,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_BT_REQUIRE_CRYPTO,
                                     TEXT_BT_REQUIRE_CRYPTO,
-                                    V_FALSE));
+                                    A2_V_FALSE,
+                                    OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
   }
@@ -1266,7 +1289,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_BT_SEED_UNVERIFIED,
                                     TEXT_BT_SEED_UNVERIFIED,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
@@ -1275,7 +1298,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_BT_SAVE_METADATA,
                                     TEXT_BT_SAVE_METADATA,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
@@ -1359,7 +1382,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_DHT_FILE_PATH,
                                     TEXT_DHT_FILE_PATH,
                                     util::getHomeDir()+"/.aria2/dht.dat",
-                                    "/PATH/TO/DHT_DAT"));
+                                    PATH_TO_FILE));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
   }
@@ -1368,7 +1391,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_DHT_FILE_PATH6,
                                     TEXT_DHT_FILE_PATH6,
                                     util::getHomeDir()+"/.aria2/dht6.dat",
-                                    "/PATH/TO/DHT_DAT"));
+                                    PATH_TO_FILE));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
   }
@@ -1414,7 +1437,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_DHT,
                                     TEXT_ENABLE_DHT,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BASIC);
     op->addTag(TAG_BITTORRENT);
@@ -1424,7 +1447,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_DHT6,
                                     TEXT_ENABLE_DHT6,
-                                    V_FALSE,
+                                    A2_V_FALSE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BASIC);
     op->addTag(TAG_BITTORRENT);
@@ -1434,7 +1457,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_ENABLE_PEER_EXCHANGE,
                                     TEXT_ENABLE_PEER_EXCHANGE,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
@@ -1443,8 +1466,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new ParameterOptionHandler
                                    (PREF_FOLLOW_TORRENT,
                                     TEXT_FOLLOW_TORRENT,
-                                    V_TRUE,
-                                    V_TRUE, V_MEM, V_FALSE));
+                                    A2_V_TRUE,
+                                    A2_V_TRUE, V_MEM, A2_V_FALSE));
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
   }
@@ -1492,7 +1515,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
                                    (PREF_ON_BT_DOWNLOAD_COMPLETE,
                                     TEXT_ON_BT_DOWNLOAD_COMPLETE,
                                     NO_DEFAULT_VALUE,
-                                    "/path/to/command"));
+                                    PATH_TO_COMMAND));
     op->addTag(TAG_ADVANCED);
     op->addTag(TAG_HOOK);
     handlers.push_back(op);
@@ -1550,8 +1573,8 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new ParameterOptionHandler
                                    (PREF_FOLLOW_METALINK,
                                     TEXT_FOLLOW_METALINK,
-                                    V_TRUE,
-                                    V_TRUE, V_MEM, V_FALSE));
+                                    A2_V_TRUE,
+                                    A2_V_TRUE, V_MEM, A2_V_FALSE));
     op->addTag(TAG_METALINK);
     handlers.push_back(op);
   }
@@ -1559,7 +1582,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
                                    (PREF_METALINK_ENABLE_UNIQUE_PROTOCOL,
                                     TEXT_METALINK_ENABLE_UNIQUE_PROTOCOL,
-                                    V_TRUE,
+                                    A2_V_TRUE,
                                     OptionHandler::OPT_ARG));
     op->addTag(TAG_METALINK);
     handlers.push_back(op);
@@ -1639,27 +1662,28 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
   }
   // Help Option
   {
+    static std::string tags[] = {
+      TAG_BASIC,
+      TAG_ADVANCED,
+      TAG_HTTP,
+      TAG_HTTPS,
+      TAG_FTP,
+      TAG_METALINK,
+      TAG_BITTORRENT,
+      TAG_COOKIE,
+      TAG_HOOK,
+      TAG_FILE,
+      TAG_XML_RPC,
+      TAG_EXPERIMENTAL,
+      TAG_HELP,
+      TAG_ALL
+    };
+    static std::string tagsStr = strjoin(vbegin(tags), vend(tags), ", ");
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
                                    ("help",
                                     TEXT_HELP,
                                     TAG_BASIC,
-                                    StringFormat
-                                    ("%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, "
-                                     "%s, %s, %s, %s",
-                                     TAG_BASIC,
-                                     TAG_ADVANCED,
-                                     TAG_HTTP,
-                                     TAG_HTTPS,
-                                     TAG_FTP,
-                                     TAG_METALINK,
-                                     TAG_BITTORRENT,
-                                     TAG_COOKIE,
-                                     TAG_HOOK,
-                                     TAG_FILE,
-                                     TAG_XML_RPC,
-                                     TAG_EXPERIMENTAL,
-                                     TAG_HELP,
-                                     TAG_ALL).str(),
+                                    tagsStr,
                                     OptionHandler::OPT_ARG,
                                     'h'));
     op->addTag(TAG_BASIC);
