@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_OPTION_PARSER_H_
-#define _D_OPTION_PARSER_H_
+#ifndef D_OPTION_PARSER_H
+#define D_OPTION_PARSER_H
 
 #include "common.h"
 
@@ -50,20 +50,20 @@ class OptionHandler;
 
 class OptionParser {
 private:
-  int _idCounter;
+  int idCounter_;
 
-  // _optionHandlers is sorted by OptionHandler::getName() in
+  // optionHandlers_ is sorted by OptionHandler::getName() in
   // ascending order.
-  std::vector<SharedHandle<OptionHandler> > _optionHandlers;
+  std::vector<SharedHandle<OptionHandler> > optionHandlers_;
 
   SharedHandle<OptionHandler>
   getOptionHandlerByName(const std::string& optName);
 
-  static SharedHandle<OptionParser> _optionParser;
+  static SharedHandle<OptionParser> optionParser_;
 public:
   OptionParser();
 
-  ~OptionParser() {}
+  ~OptionParser();
 
   // Parses options in argv and writes option name and value to out in
   // NAME=VALUE format. Non-option strings are stored in nonopts.
@@ -108,4 +108,4 @@ typedef SharedHandle<OptionParser> OptionParserHandle;
 
 } // namespace aria2
 
-#endif // _D_OPTION_PARSER_H_
+#endif // D_OPTION_PARSER_H
