@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_P_STRING_SEGMENT_H_
-#define _D_P_STRING_SEGMENT_H_
+#ifndef D_P_STRING_SEGMENT_H
+#define D_P_STRING_SEGMENT_H
 
 #include "PStringDatum.h"
 #include <string>
@@ -44,9 +44,9 @@ class PStringSegment : public PStringDatum
 {
 private:
 
-  std::string _value;
+  std::string value_;
 
-  SharedHandle<PStringDatum> _next;
+  SharedHandle<PStringDatum> next_;
 
 public:
   PStringSegment(const std::string& value,
@@ -67,4 +67,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_P_STRING_SEGMENT_H_
+#endif // D_P_STRING_SEGMENT_H
