@@ -47,7 +47,7 @@
 #include "a2netcompat.h"
 #include "ARC4Encryptor.h"
 #include "ARC4Decryptor.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "util.h"
 #include "Peer.h"
 
@@ -55,18 +55,16 @@ namespace aria2 {
 
 PeerConnection::PeerConnection
 (cuid_t cuid, const SharedHandle<Peer>& peer, const SocketHandle& socket)
-
-  :cuid_(cuid),
-   peer_(peer),
-   socket_(socket),
-   logger_(LogFactory::getInstance()),
-   resbuf_(new unsigned char[MAX_PAYLOAD_LEN]),
-   resbufLength_(0),
-   currentPayloadLength_(0),
-   lenbufLength_(0),
-   socketBuffer_(socket),
-   encryptionEnabled_(false),
-   prevPeek_(false)
+  : cuid_(cuid),
+    peer_(peer),
+    socket_(socket),
+    resbuf_(new unsigned char[MAX_PAYLOAD_LEN]),
+    resbufLength_(0),
+    currentPayloadLength_(0),
+    lenbufLength_(0),
+    socketBuffer_(socket),
+    encryptionEnabled_(false),
+    prevPeek_(false)
 {}
 
 PeerConnection::~PeerConnection()
@@ -112,9 +110,6 @@ void PeerConnection::pushBytes(unsigned char* data, size_t len)
 
 bool PeerConnection::receiveMessage(unsigned char* data, size_t& dataLength) {
   if(resbufLength_ == 0 && 4 > lenbufLength_) {
-    if(!socket_->isReadable(0)) {
-      return false;
-    }
     // read payload size, 32bit unsigned integer
     size_t remaining = 4-lenbufLength_;
     size_t temp = remaining;
@@ -124,12 +119,10 @@ bool PeerConnection::receiveMessage(unsigned char* data, size_t& dataLength) {
         return false;
       }
       // we got EOF
-      if(logger_->debug()) {
-        logger_->debug("CUID#%s - In PeerConnection::receiveMessage(),"
+      A2_LOG_DEBUG(fmt("CUID#%lld - In PeerConnection::receiveMessage(),"
                        " remain=%lu",
-                       util::itos(cuid_).c_str(),
-                       static_cast<unsigned long>(temp));
-      }
+                       cuid_,
+                       static_cast<unsigned long>(temp)));
       peer_->setDisconnectedGracefully(true);
       throw DL_ABORT_EX(EX_EOF_FROM_PEER);
     }
@@ -142,7 +135,7 @@ bool PeerConnection::receiveMessage(unsigned char* data, size_t& dataLength) {
     memcpy(&payloadLength, lenbuf_, sizeof(payloadLength));
     payloadLength = ntohl(payloadLength);
     if(payloadLength > MAX_PAYLOAD_LEN) {
-      throw DL_ABORT_EX(StringFormat(EX_TOO_LONG_PAYLOAD, payloadLength).str());
+      throw DL_ABORT_EX(fmt(EX_TOO_LONG_PAYLOAD, payloadLength));
     }
     currentPayloadLength_ = payloadLength;
   }
@@ -159,13 +152,11 @@ bool PeerConnection::receiveMessage(unsigned char* data, size_t& dataLength) {
         return false;
       }
       // we got EOF
-      if(logger_->debug()) {
-        logger_->debug("CUID#%s - In PeerConnection::receiveMessage(),"
+      A2_LOG_DEBUG(fmt("CUID#%lld - In PeerConnection::receiveMessage(),"
                        " payloadlen=%lu, remaining=%lu",
-                       util::itos(cuid_).c_str(),
+                       cuid_,
                        static_cast<unsigned long>(currentPayloadLength_),
-                       static_cast<unsigned long>(temp));
-      }
+                       static_cast<unsigned long>(temp)));
       peer_->setDisconnectedGracefully(true);
       throw DL_ABORT_EX(EX_EOF_FROM_PEER);
     }
@@ -186,44 +177,27 @@ bool PeerConnection::receiveMessage(unsigned char* data, size_t& dataLength) {
 
 bool PeerConnection::receiveHandshake(unsigned char* data, size_t& dataLength,
                                       bool peek) {
-  assert(BtHandshakeMessage::MESSAGE_LENGTH >= resbufLength_);
+  if(BtHandshakeMessage::MESSAGE_LENGTH < resbufLength_) {
+    throw DL_ABORT_EX
+      ("More than BtHandshakeMessage::MESSAGE_LENGTH bytes are buffered.");
+  }
   bool retval = true;
-  if(prevPeek_ && !peek && resbufLength_) {
-    // We have data in previous peek.
-    // There is a chance that socket is readable because of EOF, for example,
-    // official bttrack shutdowns socket after sending first 48 bytes of
-    // handshake in its NAT checking.
-    // So if there are data in resbuf_, return it without checking socket
-    // status.
-    prevPeek_ = false;
-    retval = BtHandshakeMessage::MESSAGE_LENGTH <= resbufLength_;
-  } else {
-    prevPeek_ = peek;
-    size_t remaining = BtHandshakeMessage::MESSAGE_LENGTH-resbufLength_;
-    if(remaining > 0 && !socket_->isReadable(0)) {
-      dataLength = 0;
-      return false;
+  size_t remaining = BtHandshakeMessage::MESSAGE_LENGTH-resbufLength_;
+  if(remaining > 0) {
+    size_t temp = remaining;
+    readData(resbuf_+resbufLength_, remaining, encryptionEnabled_);
+    if(remaining == 0 && !socket_->wantRead() && !socket_->wantWrite()) {
+      // we got EOF
+      A2_LOG_DEBUG
+        (fmt("CUID#%lld - In PeerConnection::receiveHandshake(), remain=%lu",
+             cuid_,
+             static_cast<unsigned long>(temp)));
+      peer_->setDisconnectedGracefully(true);
+      throw DL_ABORT_EX(EX_EOF_FROM_PEER);
     }
-    if(remaining > 0) {
-      size_t temp = remaining;
-      readData(resbuf_+resbufLength_, remaining, encryptionEnabled_);
-      if(remaining == 0) {
-        if(socket_->wantRead() || socket_->wantWrite()) {
-          return false;
-        }
-        // we got EOF
-        if(logger_->debug()) {
-          logger_->debug
-            ("CUID#%s - In PeerConnection::receiveHandshake(), remain=%lu",
-             util::itos(cuid_).c_str(), static_cast<unsigned long>(temp));
-        }
-        peer_->setDisconnectedGracefully(true);
-        throw DL_ABORT_EX(EX_EOF_FROM_PEER);
-      }
-      resbufLength_ += remaining;
-      if(BtHandshakeMessage::MESSAGE_LENGTH > resbufLength_) {
-        retval = false;
-      }
+    resbufLength_ += remaining;
+    if(BtHandshakeMessage::MESSAGE_LENGTH > resbufLength_) {
+      retval = false;
     }
   }
   size_t writeLength = std::min(resbufLength_, dataLength);
@@ -273,10 +247,15 @@ bool PeerConnection::sendBufferIsEmpty() const
 ssize_t PeerConnection::sendPendingData()
 {
   ssize_t writtenLength = socketBuffer_.send();
-  if(logger_->debug()) {
-    logger_->debug("sent %d byte(s).", writtenLength);
-  }
+  A2_LOG_DEBUG(fmt("sent %ld byte(s).", static_cast<long int>(writtenLength)));
   return writtenLength;
 }
 
+unsigned char* PeerConnection::detachBuffer()
+{
+  unsigned char* detachbuf = resbuf_;
+  resbuf_ = new unsigned char[MAX_PAYLOAD_LEN];
+  return detachbuf;
+}
+
 } // namespace aria2
