@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_PEER_LISTEN_COMMAND_H_
-#define _D_PEER_LISTEN_COMMAND_H_
+#ifndef D_PEER_LISTEN_COMMAND_H
+#define D_PEER_LISTEN_COMMAND_H
 
 #include "Command.h"
 #include "SharedHandle.h"
@@ -46,16 +46,18 @@ class SocketCore;
 
 class PeerListenCommand : public Command {
 private:
-  DownloadEngine* e;
-  SharedHandle<SocketCore> socket;
-  unsigned int _lowestSpeedLimit;
+  DownloadEngine* e_;
+  int family_;
+  SharedHandle<SocketCore> socket_;
+  unsigned int lowestSpeedLimit_;
 
-  static unsigned int __numInstance;
+  static unsigned int numInstance_;
 
-  static PeerListenCommand* __instance;
+  static PeerListenCommand* instance_;
 
+  static PeerListenCommand* instance6_;
 public:
-  PeerListenCommand(int32_t cuid, DownloadEngine* e);
+  PeerListenCommand(cuid_t cuid, DownloadEngine* e, int family);
 
   virtual ~PeerListenCommand();
   
@@ -72,18 +74,18 @@ public:
 
   void setLowestSpeedLimit(unsigned int speed)
   {
-    _lowestSpeedLimit = speed;
+    lowestSpeedLimit_ = speed;
   }
 
-  static PeerListenCommand* getInstance(DownloadEngine* e);
+  static PeerListenCommand* getInstance(DownloadEngine* e, int family);
 
   static unsigned int getNumInstance()
   {
-    return __numInstance;
+    return numInstance_;
   }
   
 };
 
 } // namespace aria2 
 
-#endif // _D_PEER_LISTEN_COMMAND_H_
+#endif // D_PEER_LISTEN_COMMAND_H
