@@ -33,6 +33,9 @@
  */
 /* copyright --> */
 #include "PeerReceiveHandshakeCommand.h"
+
+#include <cstring>
+
 #include "PeerConnection.h"
 #include "DownloadEngine.h"
 #include "BtHandshakeMessage.h"
@@ -45,20 +48,16 @@
 #include "PeerStorage.h"
 #include "PieceStorage.h"
 #include "BtRuntime.h"
-#include "BtAnnounce.h"
-#include "BtProgressInfoFile.h"
 #include "BtConstants.h"
 #include "message.h"
 #include "Socket.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "prefs.h"
 #include "Option.h"
 #include "RequestGroupMan.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "RequestGroup.h"
-#include "ServerStatMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
 
 namespace aria2 {
 
@@ -68,11 +67,15 @@ PeerReceiveHandshakeCommand::PeerReceiveHandshakeCommand
  DownloadEngine* e,
  const SocketHandle& s,
  const SharedHandle<PeerConnection>& peerConnection)
-  :
-  PeerAbstractCommand(cuid, peer, e, s),
-  peerConnection_(peerConnection)
+  : PeerAbstractCommand(cuid, peer, e, s),
+    peerConnection_(peerConnection)
 {
-  if(peerConnection_.isNull()) {
+  if(peerConnection_) {
+    if(peerConnection_->getBufferLength() > 0) {
+      setStatus(Command::STATUS_ONESHOT_REALTIME);
+      getDownloadEngine()->setNoWait(true);
+    }
+  } else {
     peerConnection_.reset(new PeerConnection(cuid, getPeer(), getSocket()));
   }
 }
@@ -87,22 +90,24 @@ bool PeerReceiveHandshakeCommand::exitBeforeExecute()
 
 bool PeerReceiveHandshakeCommand::executeInternal()
 {
-  unsigned char data[BtHandshakeMessage::MESSAGE_LENGTH];
-  size_t dataLength = BtHandshakeMessage::MESSAGE_LENGTH;
-  // ignore return value. The received data is kept in PeerConnection object
-  // because of peek = true.
-  peerConnection_->receiveHandshake(data, dataLength, true);
-  // To handle tracker's NAT-checking feature
-  if(dataLength >= 48) {
+  // Handle tracker's NAT-checking feature
+  if(peerConnection_->getBufferLength() < 48) {
+    size_t dataLength = 0;
+    // Ignore return value. The received data is kept in
+    // PeerConnection object because of peek = true.
+    peerConnection_->receiveHandshake(0, dataLength, true);
+  }
+  if(peerConnection_->getBufferLength() >= 48) {
+    const unsigned char* data = peerConnection_->getBuffer();
     // check info_hash
     std::string infoHash = std::string(&data[28], &data[28+INFO_HASH_LENGTH]);
 
     SharedHandle<DownloadContext> downloadContext =
       getDownloadEngine()->getBtRegistry()->getDownloadContext(infoHash);
-    if(downloadContext.isNull()) {
+    if(!downloadContext) {
       throw DL_ABORT_EX
-        (StringFormat("Unknown info hash %s",
-                      util::toHex(infoHash).c_str()).str());
+        (fmt("Unknown info hash %s",
+             util::toHex(infoHash).c_str()));
     }
     BtObject btObject = getDownloadEngine()->getBtRegistry()->get
       (downloadContext->getOwnerRequestGroup()->getGID());
@@ -111,12 +116,12 @@ bool PeerReceiveHandshakeCommand::executeInternal()
     SharedHandle<PeerStorage> peerStorage = btObject.peerStorage_;
     if(!btRuntime->ready()) {
       throw DL_ABORT_EX
-        (StringFormat("Unknown info hash %s",
-                      util::toHex(infoHash).c_str()).str());
+        (fmt("Unknown info hash %s",
+             util::toHex(infoHash).c_str()));
     }
     if(btRuntime->isHalt()) {
-      getLogger()->debug("Info hash found but the download is over."
-                         " Dropping connection.");
+      A2_LOG_DEBUG("Info hash found but the download is over."
+                   " Dropping connection.");
       return true;
     }
     TransferStat tstat =
@@ -148,11 +153,9 @@ bool PeerReceiveHandshakeCommand::executeInternal()
            PeerInteractionCommand::RECEIVER_WAIT_HANDSHAKE,
            peerConnection_);
         getDownloadEngine()->addCommand(command);
-        if(getLogger()->debug()) {
-          getLogger()->debug(MSG_INCOMING_PEER_CONNECTION,
-                             util::itos(getCuid()).c_str(),
-                             util::itos(getPeer()->usedBy()).c_str());
-        }
+        A2_LOG_DEBUG(fmt(MSG_INCOMING_PEER_CONNECTION,
+                         getCuid(),
+                         util::itos(getPeer()->usedBy()).c_str()));
       }
     }
     return true;
