@@ -66,30 +66,38 @@
 #include "util.h"
 #include "Command.h"
 #include "FileEntry.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "FileAllocationEntry.h"
 #include "CheckIntegrityEntry.h"
 #include "Segment.h"
 #include "DlAbortEx.h"
+#include "uri.h"
+#include "Triplet.h"
+#include "Signature.h"
 
 namespace aria2 {
 
 RequestGroupMan::RequestGroupMan
 (const std::vector<SharedHandle<RequestGroup> >& requestGroups,
  unsigned int maxSimultaneousDownloads,
- const Option* option):
-  reservedGroups_(requestGroups.begin(), requestGroups.end()),
-  logger_(LogFactory::getInstance()),
-  maxSimultaneousDownloads_(maxSimultaneousDownloads),
-  option_(option),
-  serverStatMan_(new ServerStatMan()),
-  maxOverallDownloadSpeedLimit_
-  (option->getAsInt(PREF_MAX_OVERALL_DOWNLOAD_LIMIT)),
-  maxOverallUploadSpeedLimit_(option->getAsInt(PREF_MAX_OVERALL_UPLOAD_LIMIT)),
-  xmlRpc_(option->getAsBool(PREF_ENABLE_XML_RPC)),
-  queueCheck_(true)
+ const Option* option)
+  : reservedGroups_(requestGroups.begin(), requestGroups.end()),
+    maxSimultaneousDownloads_(maxSimultaneousDownloads),
+    option_(option),
+    serverStatMan_(new ServerStatMan()),
+    maxOverallDownloadSpeedLimit_
+    (option->getAsInt(PREF_MAX_OVERALL_DOWNLOAD_LIMIT)),
+    maxOverallUploadSpeedLimit_(option->getAsInt
+                                (PREF_MAX_OVERALL_UPLOAD_LIMIT)),
+    xmlRpc_(option->getAsBool(PREF_ENABLE_XML_RPC)),
+    queueCheck_(true),
+    removedErrorResult_(0),
+    removedLastErrorResult_(error_code::FINISHED),
+    maxDownloadResult_(option->getAsInt(PREF_MAX_DOWNLOAD_RESULT))
 {}
 
+RequestGroupMan::~RequestGroupMan() {}
+
 bool RequestGroupMan::downloadFinished()
 {
 #ifdef ENABLE_XML_RPC
@@ -159,8 +167,9 @@ SharedHandle<RequestGroup> RequestGroupMan::getRequestGroup(size_t index) const
   }
 }
 
+namespace {
 template<typename Iterator>
-static Iterator findByGID(Iterator first, Iterator last, gid_t gid)
+Iterator findByGID(Iterator first, Iterator last, gid_t gid)
 {
   for(; first != last; ++first) {
     if((*first)->getGID() == gid) {
@@ -169,6 +178,7 @@ static Iterator findByGID(Iterator first, Iterator last, gid_t gid)
   }
   return first;
 }
+} // namespace
 
 SharedHandle<RequestGroup>
 RequestGroupMan::findRequestGroup(gid_t gid) const
@@ -201,8 +211,8 @@ size_t RequestGroupMan::changeReservedGroupPosition
     findByGID(reservedGroups_.begin(), reservedGroups_.end(), gid);
   if(i == reservedGroups_.end()) {
     throw DL_ABORT_EX
-      (StringFormat("GID#%s not found in the waiting queue.",
-                    util::itos(gid).c_str()).str());
+      (fmt("GID#%s not found in the waiting queue.",
+           util::itos(gid).c_str()));
   }
   SharedHandle<RequestGroup> rg = *i;
   const size_t maxPos = reservedGroups_.size()-1;
@@ -250,23 +260,26 @@ bool RequestGroupMan::removeReservedGroup(gid_t gid)
   }
 }
 
-static void executeStopHook
-(const SharedHandle<DownloadResult>& result, const Option* option)
+namespace {
+
+void executeStopHook
+(const SharedHandle<RequestGroup>& group,
+ const Option* option,
+ error_code::Value result)
 {
-  if(result->result == downloadresultcode::FINISHED &&
+  if(result == error_code::FINISHED &&
      !option->blank(PREF_ON_DOWNLOAD_COMPLETE)) {
-    util::executeHook(option->get(PREF_ON_DOWNLOAD_COMPLETE),
-                      util::itos(result->gid));
-  } else if(result->result != downloadresultcode::IN_PROGRESS &&
+    util::executeHookByOptName(group, option, PREF_ON_DOWNLOAD_COMPLETE);
+  } else if(result != error_code::IN_PROGRESS &&
             !option->blank(PREF_ON_DOWNLOAD_ERROR)) {
-    util::executeHook(option->get(PREF_ON_DOWNLOAD_ERROR),
-                      util::itos(result->gid));
+    util::executeHookByOptName(group, option, PREF_ON_DOWNLOAD_ERROR);
   } else if(!option->blank(PREF_ON_DOWNLOAD_STOP)) {
-    util::executeHook(option->get(PREF_ON_DOWNLOAD_STOP),
-                      util::itos(result->gid));
+    util::executeHookByOptName(group, option, PREF_ON_DOWNLOAD_STOP);
   }
 }
 
+} // namespace
+
 namespace {
 class ProcessStoppedRequestGroup {
 private:
@@ -279,14 +292,14 @@ private:
   {
     SharedHandle<Signature> sig =
       group->getDownloadContext()->getSignature();
-    if(!sig.isNull() && !sig->getBody().empty()) {
+    if(sig && !sig->getBody().empty()) {
       // filename of signature file is the path to download file followed by
       // ".sig".
       std::string signatureFile = group->getFirstFilePath()+".sig";
       if(sig->save(signatureFile)) {
-        logger_->notice(MSG_SIGNATURE_SAVED, signatureFile.c_str());
+        A2_LOG_NOTICE(fmt(MSG_SIGNATURE_SAVED, signatureFile.c_str()));
       } else {
-        logger_->notice(MSG_SIGNATURE_NOT_SAVED, signatureFile.c_str());
+        A2_LOG_NOTICE(fmt(MSG_SIGNATURE_NOT_SAVED, signatureFile.c_str()));
       }
     }
   }
@@ -294,11 +307,11 @@ public:
   ProcessStoppedRequestGroup
   (DownloadEngine* e,
    std::deque<SharedHandle<DownloadResult> >& downloadResults,
-   std::deque<SharedHandle<RequestGroup> >& reservedGroups):
-    e_(e),
-    downloadResults_(downloadResults),
-    reservedGroups_(reservedGroups),
-    logger_(LogFactory::getInstance()) {}
+   std::deque<SharedHandle<RequestGroup> >& reservedGroups)
+    : e_(e),
+      downloadResults_(downloadResults),
+      reservedGroups_(reservedGroups)
+  {}
 
   void operator()(const SharedHandle<RequestGroup>& group)
   {
@@ -329,38 +342,40 @@ public:
           std::vector<SharedHandle<RequestGroup> > nextGroups;
           group->postDownloadProcessing(nextGroups);
           if(!nextGroups.empty()) {
-            if(logger_->debug()) {
-              logger_->debug
-                ("Adding %lu RequestGroups as a result of PostDownloadHandler.",
-                 static_cast<unsigned long>(nextGroups.size()));
-            }
+            A2_LOG_DEBUG
+              (fmt("Adding %lu RequestGroups as a result of"
+                   " PostDownloadHandler.",
+                   static_cast<unsigned long>(nextGroups.size())));
             e_->getRequestGroupMan()->insertReservedGroup(0, nextGroups);
           }
         } else {
+          A2_LOG_NOTICE
+            (fmt("Download GID#%s not complete: %s",
+                 util::itos(group->getGID()).c_str(),
+                 group->getDownloadContext()->getBasePath().c_str()));
           group->saveControlFile();
         }
       } catch(RecoverableException& ex) {
-        logger_->error(EX_EXCEPTION_CAUGHT, ex);
+        A2_LOG_ERROR_EX(EX_EXCEPTION_CAUGHT, ex);
       }
       if(group->isPauseRequested()) {
         reservedGroups_.push_front(group);
-      } else {
-        downloadResults_.push_back(group->createDownloadResult());
-      }
-      group->releaseRuntimeResource(e_);
-      if(group->isPauseRequested()) {
+        group->releaseRuntimeResource(e_);
         group->setForceHaltRequested(false);
         util::executeHookByOptName
           (group, e_->getOption(), PREF_ON_DOWNLOAD_PAUSE);
         // TODO Should we have to prepend spend uris to remaining uris
         // in case PREF_REUSE_URI is disabed?
       } else {
-        executeStopHook(downloadResults_.back(), e_->getOption());
+        SharedHandle<DownloadResult> dr = group->createDownloadResult();
+        e_->getRequestGroupMan()->addDownloadResult(dr);
+        executeStopHook(group, e_->getOption(), dr->result);
+        group->releaseRuntimeResource(e_);
       }
     }
   }
 };
-}
+} // namespace
 
 namespace {
 class CollectServerStat {
@@ -375,7 +390,7 @@ public:
     if(group->getNumCommand() == 0) {
       // Collect statistics during download in PeerStats and update/register
       // ServerStatMan
-      if(!group->getSegmentMan().isNull()) {
+      if(group->getSegmentMan()) {
         bool singleConnection =
           group->getSegmentMan()->getPeerStats().size() == 1;
         const std::vector<SharedHandle<PeerStat> >& peerStats =
@@ -404,7 +419,7 @@ public:
     }    
   }
 };
-}
+} // namespace
 
 namespace {
 class FindStoppedRequestGroup {
@@ -413,7 +428,7 @@ public:
     return group->getNumCommand() == 0;
   }
 };
-}
+} // namespace
 
 void RequestGroupMan::updateServerStat()
 {
@@ -440,10 +455,8 @@ void RequestGroupMan::removeStoppedGroup(DownloadEngine* e)
 
   size_t numRemoved = numPrev-requestGroups_.size();
   if(numRemoved > 0) {
-    if(logger_->debug()) {
-      logger_->debug("%lu RequestGroup(s) deleted.",
-                     static_cast<unsigned long>(numRemoved));
-    }
+    A2_LOG_DEBUG(fmt("%lu RequestGroup(s) deleted.",
+                     static_cast<unsigned long>(numRemoved)));
   }
 }
 
@@ -452,24 +465,26 @@ void RequestGroupMan::configureRequestGroup
 {
   const std::string& uriSelectorValue = option_->get(PREF_URI_SELECTOR);
   if(uriSelectorValue == V_FEEDBACK) {
-    requestGroup->setURISelector
-      (SharedHandle<URISelector>(new FeedbackURISelector(serverStatMan_)));
+    SharedHandle<URISelector> sel(new FeedbackURISelector(serverStatMan_));
+    requestGroup->setURISelector(sel);
   } else if(uriSelectorValue == V_INORDER) {
-    requestGroup->setURISelector
-      (SharedHandle<URISelector>(new InOrderURISelector()));
+    SharedHandle<URISelector> sel(new InOrderURISelector());
+    requestGroup->setURISelector(sel);
   } else if(uriSelectorValue == V_ADAPTIVE) {
-    requestGroup->setURISelector
-      (SharedHandle<URISelector>(new AdaptiveURISelector(serverStatMan_,
-                                                         requestGroup.get())));
+    SharedHandle<URISelector> sel(new AdaptiveURISelector(serverStatMan_,
+                                                          requestGroup.get()));
+    requestGroup->setURISelector(sel);
   }
 }
 
-static void createInitialCommand(const SharedHandle<RequestGroup>& requestGroup,
-                                 std::vector<Command*>& commands,
-                                 DownloadEngine* e)
+namespace {
+void createInitialCommand(const SharedHandle<RequestGroup>& requestGroup,
+                          std::vector<Command*>& commands,
+                          DownloadEngine* e)
 {
   requestGroup->createInitialCommand(commands, e);
 }
+} // namespace
 
 void RequestGroupMan::fillRequestGroupFromReserver(DownloadEngine* e)
 {
@@ -502,30 +517,27 @@ void RequestGroupMan::fillRequestGroupFromReserver(DownloadEngine* e)
       ++count;
       e->addCommand(commands);
       commands.clear();
-      util::executeHookByOptName
-        (groupToAdd, e->getOption(), PREF_ON_DOWNLOAD_START);
     } catch(RecoverableException& ex) {
-      logger_->error(EX_EXCEPTION_CAUGHT, ex);
-      if(logger_->debug()) {
-        logger_->debug("Deleting temporal commands.");
-      }
+      A2_LOG_ERROR_EX(EX_EXCEPTION_CAUGHT, ex);
+      A2_LOG_DEBUG("Deleting temporal commands.");
       std::for_each(commands.begin(), commands.end(), Deleter());
       commands.clear();
-      if(logger_->debug()) {
-        logger_->debug("Commands deleted");
-      }
-      groupToAdd->releaseRuntimeResource(e);
-      downloadResults_.push_back(groupToAdd->createDownloadResult());
+      A2_LOG_DEBUG("Commands deleted");
+      groupToAdd->setLastErrorCode(ex.getErrorCode());
+      // We add groupToAdd to e in order to it is processed in
+      // removeStoppedGroup().
+      requestGroups_.push_back(groupToAdd);
+      requestQueueCheck();
     }
+    util::executeHookByOptName
+      (groupToAdd, e->getOption(), PREF_ON_DOWNLOAD_START);
   }
   if(!temp.empty()) {
     reservedGroups_.insert(reservedGroups_.begin(), temp.begin(), temp.end());
   }
   if(count > 0) {
     e->setNoWait(true);
-    if(logger_->debug()) {
-      logger_->debug("%d RequestGroup(s) added.", count);
-    }
+    A2_LOG_DEBUG(fmt("%d RequestGroup(s) added.", count));
   }
 }
 
@@ -540,7 +552,7 @@ void RequestGroupMan::save()
       try {
         (*itr)->saveControlFile();
       } catch(RecoverableException& e) {
-        logger_->error(EX_EXCEPTION_CAUGHT, e);
+        A2_LOG_ERROR_EX(EX_EXCEPTION_CAUGHT, e);
       }
     }
   }
@@ -557,13 +569,13 @@ void RequestGroupMan::closeFile()
 RequestGroupMan::DownloadStat RequestGroupMan::getDownloadStat() const
 {
   size_t finished = 0;
-  size_t error = 0;
+  size_t error = removedErrorResult_;
   size_t inprogress = 0;
-  downloadresultcode::RESULT lastError = downloadresultcode::FINISHED;
+  error_code::Value lastError = removedLastErrorResult_;
   for(std::deque<SharedHandle<DownloadResult> >::const_iterator itr =
         downloadResults_.begin(), eoi = downloadResults_.end();
       itr != eoi; ++itr) {
-    if((*itr)->result == downloadresultcode::FINISHED) {
+    if((*itr)->result == error_code::FINISHED) {
       ++finished;
     } else {
       ++error;
@@ -573,7 +585,7 @@ RequestGroupMan::DownloadStat RequestGroupMan::getDownloadStat() const
   for(std::deque<SharedHandle<RequestGroup> >::const_iterator itr =
         requestGroups_.begin(), eoi = requestGroups_.end(); itr != eoi; ++itr) {
     DownloadResultHandle result = (*itr)->createDownloadResult();
-    if(result->result == downloadresultcode::FINISHED) {
+    if(result->result == error_code::FINISHED) {
       ++finished;
     } else {
       ++inprogress;
@@ -610,10 +622,10 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
         downloadResults_.begin(), eoi = downloadResults_.end();
       itr != eoi; ++itr) {
     std::string status;
-    if((*itr)->result == downloadresultcode::FINISHED) {
+    if((*itr)->result == error_code::FINISHED) {
       status = MARK_OK;
       ++ok;
-    } else if((*itr)->result == downloadresultcode::IN_PROGRESS) {
+    } else if((*itr)->result == error_code::IN_PROGRESS) {
       status = MARK_INPR;
       ++inpr;
     } else {
@@ -622,25 +634,6 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
     }
     o << formatDownloadResult(status, *itr) << "\n";
   }
-  for(std::deque<SharedHandle<RequestGroup> >::const_iterator itr =
-        requestGroups_.begin(), eoi = requestGroups_.end(); itr != eoi; ++itr) {
-    DownloadResultHandle result = (*itr)->createDownloadResult();
-    std::string status;
-    if(result->result == downloadresultcode::FINISHED) {
-      status = MARK_OK;
-      ++ok;
-    } else {
-      // Since this RequestGroup is not processed by ProcessStoppedRequestGroup,
-      // its download stop time is not reseted.
-      // Reset download stop time and assign sessionTime here.
-      (*itr)->getDownloadContext()->resetDownloadStopTime();
-      result->sessionTime =
-        (*itr)->getDownloadContext()->calculateSessionTime();
-      status = MARK_INPR;
-      ++inpr;
-    }
-    o << formatDownloadResult(status, result) << "\n";
-  }
   for(std::deque<SharedHandle<RequestGroup> >::const_iterator itr =
         reservedGroups_.begin(), eoi = reservedGroups_.end();
       itr != eoi; ++itr) {
@@ -689,11 +682,12 @@ std::string RequestGroupMan::formatDownloadResult(const std::string& status, con
   return o.str();
 }
 
+namespace {
 template<typename StringInputIterator, typename FileEntryInputIterator>
-static bool sameFilePathExists(StringInputIterator sfirst,
-                               StringInputIterator slast,
-                               FileEntryInputIterator ffirst,
-                               FileEntryInputIterator flast)
+bool sameFilePathExists(StringInputIterator sfirst,
+                        StringInputIterator slast,
+                        FileEntryInputIterator ffirst,
+                        FileEntryInputIterator flast)
 {
   for(; ffirst != flast; ++ffirst) {
     if(std::binary_search(sfirst, slast, (*ffirst)->getPath())) {
@@ -702,6 +696,7 @@ static bool sameFilePathExists(StringInputIterator sfirst,
   }
   return false;
 }
+} // namespace
 
 bool RequestGroupMan::isSameFileBeingDownloaded(RequestGroup* requestGroup) const
 {
@@ -766,6 +761,42 @@ RequestGroupMan::findDownloadResult(gid_t gid) const
   return SharedHandle<DownloadResult>();
 }
 
+void RequestGroupMan::addDownloadResult(const SharedHandle<DownloadResult>& dr)
+{
+  if(maxDownloadResult_ == 0) {
+    if(!downloadResults_.empty()) {
+      for(std::deque<SharedHandle<DownloadResult> >::iterator i =
+            downloadResults_.begin(), eoi = downloadResults_.end(); i != eoi;
+          ++i) {
+        if((*i)->result != error_code::FINISHED) {
+          removedLastErrorResult_ = (*i)->result;
+          ++removedErrorResult_;
+        }
+      }
+      downloadResults_.clear();
+    }
+    if(dr->result != error_code::FINISHED) {
+      removedLastErrorResult_ = dr->result;
+      ++removedErrorResult_;
+    }
+  } else {
+    size_t curSize = downloadResults_.size();
+    if(curSize >= maxDownloadResult_) {
+      std::deque<SharedHandle<DownloadResult> >::iterator last =
+        downloadResults_.begin()+curSize-maxDownloadResult_+1;
+      for(std::deque<SharedHandle<DownloadResult> >::iterator i =
+            downloadResults_.begin(); i != last; ++i) {
+        if((*i)->result != error_code::FINISHED) {
+          removedLastErrorResult_ = (*i)->result;
+          ++removedErrorResult_;
+        }
+      }        
+      downloadResults_.erase(downloadResults_.begin(), last);
+    }
+    downloadResults_.push_back(dr);
+  }
+}
+
 void RequestGroupMan::purgeDownloadResult()
 {
   downloadResults_.clear();
@@ -783,7 +814,7 @@ RequestGroupMan::getOrCreateServerStat(const std::string& hostname,
                                        const std::string& protocol)
 {
   SharedHandle<ServerStat> ss = findServerStat(hostname, protocol);
-  if(ss.isNull()) {
+  if(!ss) {
     ss.reset(new ServerStat(hostname, protocol));
     addServerStat(ss);
   }
@@ -799,14 +830,15 @@ bool RequestGroupMan::loadServerStat(const std::string& filename)
 {
   std::ifstream in(filename.c_str(), std::ios::binary);
   if(!in) {
-    logger_->error(MSG_OPENING_READABLE_SERVER_STAT_FILE_FAILED, filename.c_str());
+    A2_LOG_ERROR(fmt(MSG_OPENING_READABLE_SERVER_STAT_FILE_FAILED,
+                     filename.c_str()));
     return false;
   }
   if(serverStatMan_->load(in)) {
-    logger_->notice(MSG_SERVER_STAT_LOADED, filename.c_str());
+    A2_LOG_NOTICE(fmt(MSG_SERVER_STAT_LOADED, filename.c_str()));
     return true;
   } else {
-    logger_->error(MSG_READING_SERVER_STAT_FILE_FAILED, filename.c_str());
+    A2_LOG_ERROR(fmt(MSG_READING_SERVER_STAT_FILE_FAILED, filename.c_str()));
     return false;
   }
 }
@@ -818,20 +850,20 @@ bool RequestGroupMan::saveServerStat(const std::string& filename) const
   {
     std::ofstream out(tempfile.c_str(), std::ios::binary);
     if(!out) {
-      logger_->error(MSG_OPENING_WRITABLE_SERVER_STAT_FILE_FAILED,
-                     filename.c_str());
+      A2_LOG_ERROR(fmt(MSG_OPENING_WRITABLE_SERVER_STAT_FILE_FAILED,
+                       filename.c_str()));
       return false;
     }
     if(!serverStatMan_->save(out)) {
-      logger_->error(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str());
+      A2_LOG_ERROR(fmt(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str()));
       return false;
     }
   }
   if(File(tempfile).renameTo(filename)) {
-    logger_->notice(MSG_SERVER_STAT_SAVED, filename.c_str());
+    A2_LOG_NOTICE(fmt(MSG_SERVER_STAT_SAVED, filename.c_str()));
     return true;
   } else {
-    logger_->error(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str());
+    A2_LOG_ERROR(fmt(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str()));
     return false;
   }
 }
@@ -856,30 +888,40 @@ bool RequestGroupMan::doesOverallUploadSpeedExceed()
 void RequestGroupMan::getUsedHosts
 (std::vector<std::pair<size_t, std::string> >& usedHosts)
 {
-  Request r;
+  // vector of triplet which consists of use count, -download speed,
+  // hostname. We want to sort by least used and faster download
+  // speed. We use -download speed so that we can sort them using
+  // operator<().
+  std::vector<Triplet<size_t, int, std::string> > tempHosts;
   for(std::deque<SharedHandle<RequestGroup> >::const_iterator i =
         requestGroups_.begin(), eoi = requestGroups_.end(); i != eoi; ++i) {
     const std::deque<SharedHandle<Request> >& inFlightReqs =
       (*i)->getDownloadContext()->getFirstFileEntry()->getInFlightRequests();
     for(std::deque<SharedHandle<Request> >::const_iterator j =
           inFlightReqs.begin(), eoj = inFlightReqs.end(); j != eoj; ++j) {
-      if(r.setUri((*j)->getUri())) {
-        std::vector<std::pair<size_t, std::string> >::iterator k;
-        std::vector<std::pair<size_t, std::string> >::iterator eok =
-          usedHosts.end();
-        for(k =  usedHosts.begin(); k != eok; ++k) {
-          if((*k).second == r.getHost()) {
+      uri::UriStruct us;
+      if(uri::parse(us, (*j)->getUri())) {
+        std::vector<Triplet<size_t, int, std::string> >::iterator k;
+        std::vector<Triplet<size_t, int, std::string> >::iterator eok =
+          tempHosts.end();
+        for(k =  tempHosts.begin(); k != eok; ++k) {
+          if((*k).third == us.host) {
             ++(*k).first;
             break;
           }
         }
         if(k == eok) {
-          usedHosts.push_back(std::make_pair(1, r.getHost()));
+          SharedHandle<ServerStat> ss = findServerStat(us.host, us.protocol);
+          int invDlSpeed = (ss && ss->isOK()) ?
+            -(static_cast<int>(ss->getDownloadSpeed())) : 0;
+          tempHosts.push_back(makeTriplet(1, invDlSpeed, us.host));
         }
       }
     }
   }
-  std::sort(usedHosts.begin(), usedHosts.end());
+  std::sort(tempHosts.begin(), tempHosts.end());
+  std::transform(tempHosts.begin(), tempHosts.end(),
+                 std::back_inserter(usedHosts), Tuple2Pair<1, 3>());
 }
 
 } // namespace aria2
