@@ -32,12 +32,11 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_SEGMENT_H_
-#define _D_SEGMENT_H_
+#ifndef D_SEGMENT_H
+#define D_SEGMENT_H
 
 #include "common.h"
 
-#include <unistd.h>
 #include <stdint.h>
 #include <string>
 
@@ -65,8 +64,6 @@ public:
 
   virtual size_t getWrittenLength() const = 0;
 
-  virtual size_t getOverflowLength() const = 0;
-
   virtual void updateWrittenLength(size_t bytes) = 0;
 
 #ifdef ENABLE_MESSAGE_DIGEST
@@ -93,5 +90,5 @@ public:
 
 } // namespace aria2
 
-#endif // _D_SEGMENT_H_
+#endif // D_SEGMENT_H
 
