@@ -52,20 +52,27 @@
 #include "Piece.h"
 #include "FileEntry.h"
 #include "wallclock.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-SegmentMan::SegmentMan(const Option* option,
-                       const SharedHandle<DownloadContext>& downloadContext,
-                       const PieceStorageHandle& pieceStorage):
-  option_(option),
-  logger_(LogFactory::getInstance()),
-  downloadContext_(downloadContext),
-  pieceStorage_(pieceStorage),
-  lastPeerStatDlspdMapUpdated_(0),
-  cachedDlspd_(0),
-  ignoreBitfield_(downloadContext->getPieceLength(),
-                  downloadContext->getTotalLength())
+SegmentEntry::SegmentEntry(cuid_t cuid, const SharedHandle<Segment>& segment)
+  : cuid(cuid), segment(segment)
+{}
+
+SegmentEntry::~SegmentEntry() {}
+
+SegmentMan::SegmentMan
+(const Option* option,
+ const SharedHandle<DownloadContext>& downloadContext,
+ const PieceStorageHandle& pieceStorage)
+  : option_(option),
+    downloadContext_(downloadContext),
+    pieceStorage_(pieceStorage),
+    lastPeerStatDlspdMapUpdated_(0),
+    cachedDlspd_(0),
+    ignoreBitfield_(downloadContext->getPieceLength(),
+                    downloadContext->getTotalLength())
 {
   ignoreBitfield_.enableFilter();
 }
@@ -74,7 +81,7 @@ SegmentMan::~SegmentMan() {}
 
 bool SegmentMan::downloadFinished() const
 {
-  if(pieceStorage_.isNull()) {
+  if(!pieceStorage_) {
     return false;
   } else {
     return pieceStorage_->downloadFinished();
@@ -89,7 +96,7 @@ void SegmentMan::init()
 
 uint64_t SegmentMan::getTotalLength() const
 {
-  if(pieceStorage_.isNull()) {
+  if(!pieceStorage_) {
     return 0;
   } else {
     return pieceStorage_->getTotalLength();
@@ -110,13 +117,12 @@ void SegmentMan::setDownloadContext
 SharedHandle<Segment> SegmentMan::checkoutSegment
 (cuid_t cuid, const SharedHandle<Piece>& piece)
 {
-  if(piece.isNull()) {
+  if(!piece) {
     return SharedHandle<Segment>();
   }
-  if(logger_->debug()) {
-    logger_->debug("Attach segment#%d to CUID#%s.",
-                   piece->getIndex(), util::itos(cuid).c_str());
-  }
+  A2_LOG_DEBUG(fmt("Attach segment#%lu to CUID#%lld.",
+                   static_cast<unsigned long>(piece->getIndex()),
+                   cuid));
   SharedHandle<Segment> segment;
   if(piece->getLength() == 0) {
     segment.reset(new GrowSegment(piece));
@@ -125,22 +131,21 @@ SharedHandle<Segment> SegmentMan::checkoutSegment
   }
   SegmentEntryHandle entry(new SegmentEntry(cuid, segment));
   usedSegmentEntries_.push_back(entry);
-  if(logger_->debug()) {
-    logger_->debug("index=%d, length=%d, segmentLength=%d, writtenLength=%d",
-                   segment->getIndex(),
-                   segment->getLength(),
-                   segment->getSegmentLength(),
-                   segment->getWrittenLength());
-  }
+  A2_LOG_DEBUG(fmt("index=%lu, length=%lu, segmentLength=%lu,"
+                   " writtenLength=%lu",
+                   static_cast<unsigned long>(segment->getIndex()),
+                   static_cast<unsigned long>(segment->getLength()),
+                   static_cast<unsigned long>(segment->getSegmentLength()),
+                   static_cast<unsigned long>(segment->getWrittenLength())));
   if(piece->getLength() > 0) {
     std::map<size_t, size_t>::iterator positr =
       segmentWrittenLengthMemo_.find(segment->getIndex());
     if(positr != segmentWrittenLengthMemo_.end()) {
       const size_t writtenLength = (*positr).second;
-      if(logger_->debug()) {
-        logger_->debug("writtenLength(in memo)=%d, writtenLength=%d",
-                       writtenLength, segment->getWrittenLength());
-      }
+      A2_LOG_DEBUG(fmt("writtenLength(in memo)=%lu, writtenLength=%lu",
+                       static_cast<unsigned long>(writtenLength),
+                       static_cast<unsigned long>(segment->getWrittenLength()))
+                   );
       //  If the difference between cached writtenLength and segment's
       //  writtenLength is less than one block, we assume that these
       //  missing bytes are already downloaded.
@@ -191,7 +196,7 @@ void SegmentMan::getSegment
                       pieceStorage_->getSparseMissingUnusedPiece
                       (minSplitSize,
                        filter.getFilterBitfield(), filter.getBitfieldLength()));
-    if(segment.isNull()) {
+    if(!segment) {
       break;
     }
     if(segment->getPositionToWrite() < fileEntry->getOffset() ||
@@ -233,7 +238,7 @@ SharedHandle<Segment> SegmentMan::getCleanSegmentIfOwnerIsIdle
       }
       cuid_t owner = segmentEntry->cuid;
       SharedHandle<PeerStat> ps = getPeerStat(owner);
-      if(ps.isNull() || (!ps.isNull() && ps->getStatus() == PeerStat::IDLE)) {
+      if(!ps || ps->getStatus() == PeerStat::IDLE) {
         cancelSegment(owner);
         return getSegmentWithIndex(cuid, index);
       } else {
@@ -246,15 +251,13 @@ SharedHandle<Segment> SegmentMan::getCleanSegmentIfOwnerIsIdle
 
 void SegmentMan::cancelSegment(const SharedHandle<Segment>& segment)
 {
-  if(logger_->debug()) {
-    logger_->debug("Canceling segment#%d", segment->getIndex());
-  }
+  A2_LOG_DEBUG(fmt("Canceling segment#%lu",
+                   static_cast<unsigned long>(segment->getIndex())));
   pieceStorage_->cancelPiece(segment->getPiece());
   segmentWrittenLengthMemo_[segment->getIndex()] = segment->getWrittenLength();
-  if(logger_->debug()) {
-    logger_->debug("Memorized segment index=%u, writtenLength=%u",
-                   segment->getIndex(), segment->getWrittenLength());
-  }
+  A2_LOG_DEBUG(fmt("Memorized segment index=%lu, writtenLength=%lu",
+                   static_cast<unsigned long>(segment->getIndex()),
+                   static_cast<unsigned long>(segment->getWrittenLength())));
 }
 
 void SegmentMan::cancelSegment(cuid_t cuid) {
@@ -275,7 +278,7 @@ void SegmentMan::cancelSegment
 {
   for(SegmentEntries::iterator itr = usedSegmentEntries_.begin(),
         eoi = usedSegmentEntries_.end(); itr != eoi;) {
-    if((*itr)->cuid == cuid && (*itr)->segment == segment) {
+    if((*itr)->cuid == cuid && *(*itr)->segment == *segment) {
       cancelSegment((*itr)->segment);
       itr = usedSegmentEntries_.erase(itr);
       //eoi = usedSegmentEntries_.end();
@@ -313,7 +316,7 @@ public:
     return segmentEntry->segment->getIndex() == segment_->getIndex();
   }
 };
-}
+} // namespace
 
 bool SegmentMan::completeSegment
 (cuid_t cuid, const SharedHandle<Segment>& segment) {
@@ -335,7 +338,7 @@ bool SegmentMan::hasSegment(size_t index) const {
 }
 
 uint64_t SegmentMan::getDownloadLength() const {
-  if(pieceStorage_.isNull()) {
+  if(!pieceStorage_) {
     return 0;
   } else {
     return pieceStorage_->getCompletedLength();
@@ -379,7 +382,7 @@ public:
       peerStat_->getProtocol() == p->getProtocol();
   }
 };
-}
+} // namespace
 
 void SegmentMan::updateFastestPeerStat(const SharedHandle<PeerStat>& peerStat)
 {
@@ -440,7 +443,7 @@ public:
     return ps->getSessionDownloadLength()+total;
   }
 };
-}
+} // namespace
 
 uint64_t SegmentMan::calculateSessionDownloadLength() const
 {
@@ -461,12 +464,10 @@ size_t SegmentMan::countFreePieceFrom(size_t index) const
 
 void SegmentMan::ignoreSegmentFor(const SharedHandle<FileEntry>& fileEntry)
 {
-  if(logger_->debug()) {
-    logger_->debug("ignoring segment for path=%s, offset=%s, length=%s",
+  A2_LOG_DEBUG(fmt("ignoring segment for path=%s, offset=%s, length=%s",
                    fileEntry->getPath().c_str(),
                    util::itos(fileEntry->getOffset()).c_str(),
-                   util::uitos(fileEntry->getLength()).c_str());
-  }
+                   util::uitos(fileEntry->getLength()).c_str()));
   ignoreBitfield_.addFilter(fileEntry->getOffset(), fileEntry->getLength());
 }
 
