@@ -35,32 +35,29 @@
 #include "SleepCommand.h"
 #include "RequestGroup.h"
 #include "DownloadEngine.h"
-#include "DownloadContext.h"
 #include "wallclock.h"
 
 namespace aria2 {
 
-SleepCommand::SleepCommand(int32_t cuid, DownloadEngine* e,
+SleepCommand::SleepCommand(cuid_t cuid, DownloadEngine* e,
                            RequestGroup* requestGroup,
                            Command* nextCommand, time_t wait):
-  Command(cuid), engine(e), _requestGroup(requestGroup),
-  nextCommand(nextCommand), wait(wait) {}
+  Command(cuid), engine_(e), requestGroup_(requestGroup),
+  nextCommand_(nextCommand), wait_(wait), checkPoint_(global::wallclock) {}
 
 SleepCommand::~SleepCommand() {
-  if(nextCommand) {
-    delete(nextCommand);
-  }
+  delete nextCommand_;
 }
 
 bool SleepCommand::execute() {
-  if(_requestGroup->downloadFinished() || _requestGroup->isHaltRequested()) {
+  if(requestGroup_->downloadFinished() || requestGroup_->isHaltRequested()) {
     return true;
-  } else if(checkPoint.difference(global::wallclock) >= wait) {
-    engine->commands.push_back(nextCommand);
-    nextCommand = 0;
+  } else if(checkPoint_.difference(global::wallclock) >= wait_) {
+    engine_->addCommand(nextCommand_);
+    nextCommand_ = 0;
     return true;
   } else {
-    engine->commands.push_back(this);
+    engine_->addCommand(this);
     return false;
   }
 }
