@@ -49,7 +49,7 @@
 #include "message.h"
 #include "DlRetryEx.h"
 #include "DlAbortEx.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "util.h"
 #include "TimeA2.h"
 #include "a2functional.h"
@@ -92,32 +92,29 @@ namespace aria2 {
 # define CLOSE(X) while(close(X) == -1 && errno == EINTR)
 #endif // __MINGW32__
 
-static const char *errorMsg(const int err)
+namespace {
+std::string errorMsg(int errNum)
 {
 #ifndef __MINGW32__
-  return strerror(err);
+  return util::safeStrerror(errNum);
 #else
   static char buf[256];
   if (FormatMessage(
                     FORMAT_MESSAGE_FROM_SYSTEM |
                     FORMAT_MESSAGE_IGNORE_INSERTS,
                     NULL,
-                    err,
+                    errNum,
                     MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
                     (LPTSTR) &buf,
                     sizeof(buf),
                     NULL
                     ) == 0) {
-    snprintf(buf, sizeof(buf), EX_SOCKET_UNKNOWN_ERROR, err, err);
+    snprintf(buf, sizeof(buf), EX_SOCKET_UNKNOWN_ERROR, errNum, errNum);
   }
   return buf;
 #endif // __MINGW32__
 }
-
-static const char *errorMsg()
-{
-  return errorMsg(SOCKET_ERRNO);
-}
+} // namespace
 
 int SocketCore::protocolFamily_ = AF_UNSPEC;
 
@@ -133,11 +130,17 @@ void SocketCore::setTLSContext(const SharedHandle<TLSContext>& tlsContext)
 }
 #endif // ENABLE_SSL
 
-SocketCore::SocketCore(int sockType):sockType_(sockType), sockfd_(-1)  {
+SocketCore::SocketCore(int sockType)
+  : sockType_(sockType),
+    sockfd_(-1)
+{
   init();
 }
 
-SocketCore::SocketCore(sock_t sockfd, int sockType):sockType_(sockType), sockfd_(sockfd) {
+SocketCore::SocketCore(sock_t sockfd, int sockType)
+  : sockType_(sockType),
+    sockfd_(sockfd)
+{
   init();
 }
 
@@ -170,18 +173,23 @@ SocketCore::~SocketCore() {
 
 void SocketCore::create(int family, int protocol)
 {
+  int errNum;
   closeConnection();
   sock_t fd = socket(family, sockType_, protocol);
+  errNum = SOCKET_ERRNO;
   if(fd == (sock_t) -1) {
     throw DL_ABORT_EX
-      (StringFormat("Failed to create socket. Cause:%s", errorMsg()).str());
+      (fmt("Failed to create socket. Cause:%s",
+           errorMsg(errNum).c_str()));
   }
   int sockopt = 1;
   if(setsockopt(fd, SOL_SOCKET, SO_REUSEADDR,
                 (a2_sockopt_t) &sockopt, sizeof(sockopt)) < 0) {
+    errNum = SOCKET_ERRNO;
     CLOSE(fd);
     throw DL_ABORT_EX
-      (StringFormat("Failed to create socket. Cause:%s", errorMsg()).str());
+      (fmt("Failed to create socket. Cause:%s",
+           errorMsg(errNum).c_str()));
   }
   sockfd_ = fd;
 }
@@ -190,13 +198,18 @@ static sock_t bindInternal(int family, int socktype, int protocol,
                            const struct sockaddr* addr, socklen_t addrlen,
                            std::string& error)
 {
+  int errNum;
   sock_t fd = socket(family, socktype, protocol);
+  errNum = SOCKET_ERRNO;
   if(fd == (sock_t) -1) {
+    error = errorMsg(errNum);
     return -1;
   }
   int sockopt = 1;
   if(setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, (a2_sockopt_t) &sockopt,
                 sizeof(sockopt)) < 0) {
+    errNum = SOCKET_ERRNO;
+    error = errorMsg(errNum);
     CLOSE(fd);
     return -1;
   }
@@ -205,13 +218,16 @@ static sock_t bindInternal(int family, int socktype, int protocol,
     int sockopt = 1;
     if(setsockopt(fd, IPPROTO_IPV6, IPV6_V6ONLY, (a2_sockopt_t) &sockopt,
                   sizeof(sockopt)) < 0) {
+      errNum = SOCKET_ERRNO;
+      error = errorMsg(errNum);
       CLOSE(fd);
       return -1;
     }
   }
 #endif // IPV6_V6ONLY
   if(::bind(fd, addr, addrlen) == -1) {
-    error = errorMsg();
+    errNum = SOCKET_ERRNO;
+    error = errorMsg(errNum);
     CLOSE(fd);
     return -1;
   }
@@ -247,7 +263,7 @@ void SocketCore::bindWithFamily(uint16_t port, int family, int flags)
   std::string error;
   sock_t fd = bindTo(0, port, family, sockType_, flags, error);
   if(fd == (sock_t) -1) {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_BIND, error.c_str()).str());
+    throw DL_ABORT_EX(fmt(EX_SOCKET_BIND, error.c_str()));
   } else {
     sockfd_ = fd;
   }
@@ -295,7 +311,7 @@ void SocketCore::bind
     }
   }
   if(sockfd_ == (sock_t) -1) {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_BIND, error.c_str()).str());
+    throw DL_ABORT_EX(fmt(EX_SOCKET_BIND, error.c_str()));
   }
 }
 
@@ -312,14 +328,15 @@ void SocketCore::bind(const struct sockaddr* addr, socklen_t addrlen)
   if(fd != (sock_t)-1) {
     sockfd_ = fd;
   } else {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_BIND, error.c_str()).str());
+    throw DL_ABORT_EX(fmt(EX_SOCKET_BIND, error.c_str()));
   }
 }
 
 void SocketCore::beginListen()
 {
   if(listen(sockfd_, 1) == -1) {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_LISTEN, errorMsg()).str());
+    int errNum = SOCKET_ERRNO;
+    throw DL_ABORT_EX(fmt(EX_SOCKET_LISTEN, errorMsg(errNum).c_str()));
   }
 }
 
@@ -328,9 +345,12 @@ SocketCore* SocketCore::acceptConnection() const
   struct sockaddr_storage sockaddr;
   socklen_t len = sizeof(sockaddr);
   sock_t fd;
-  while((fd = accept(sockfd_, reinterpret_cast<struct sockaddr*>(&sockaddr), &len)) == (sock_t) -1 && SOCKET_ERRNO == A2_EINTR);
+  while((fd = accept(sockfd_, reinterpret_cast<struct sockaddr*>(&sockaddr),
+                     &len)) == (sock_t) -1 &&
+        SOCKET_ERRNO == A2_EINTR);
+  int errNum = SOCKET_ERRNO;
   if(fd == (sock_t) -1) {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_ACCEPT, errorMsg()).str());
+    throw DL_ABORT_EX(fmt(EX_SOCKET_ACCEPT, errorMsg(errNum).c_str()));
   }
   return new SocketCore(fd, sockType_);
 }
@@ -349,7 +369,8 @@ void SocketCore::getAddrInfo
 {
   struct sockaddr* addrp = reinterpret_cast<struct sockaddr*>(&sockaddr);
   if(getsockname(sockfd_, addrp, &len) == -1) {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_GET_NAME, errorMsg()).str());
+    int errNum = SOCKET_ERRNO;
+    throw DL_ABORT_EX(fmt(EX_SOCKET_GET_NAME, errorMsg(errNum).c_str()));
   }
 }
 
@@ -367,7 +388,8 @@ void SocketCore::getPeerInfo(std::pair<std::string, uint16_t>& peerinfo) const
   socklen_t len = sizeof(sockaddr);
   struct sockaddr* addrp = reinterpret_cast<struct sockaddr*>(&sockaddr);
   if(getpeername(sockfd_, addrp, &len) == -1) {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_GET_NAME, errorMsg()).str());
+    int errNum = SOCKET_ERRNO;
+    throw DL_ABORT_EX(fmt(EX_SOCKET_GET_NAME, errorMsg(errNum).c_str()));
   }
   peerinfo = util::getNumericNameInfo(addrp, len);
 }
@@ -381,20 +403,25 @@ void SocketCore::establishConnection(const std::string& host, uint16_t port)
   s = callGetaddrinfo(&res, host.c_str(), util::uitos(port).c_str(),
                       protocolFamily_, sockType_, 0, 0);
   if(s) {
-    throw DL_ABORT_EX(StringFormat(EX_RESOLVE_HOSTNAME,
-                                   host.c_str(), gai_strerror(s)).str());
+    throw DL_ABORT_EX(fmt(EX_RESOLVE_HOSTNAME,
+                          host.c_str(),
+                          gai_strerror(s)));
   }
   WSAAPI_AUTO_DELETE<struct addrinfo*> resDeleter(res, freeaddrinfo);
   struct addrinfo* rp;
+  int errNum;
   for(rp = res; rp; rp = rp->ai_next) {
     sock_t fd = socket(rp->ai_family, rp->ai_socktype, rp->ai_protocol);
+    errNum = SOCKET_ERRNO;
     if(fd == (sock_t) -1) {
-      error = errorMsg();
+      error = errorMsg(errNum);
       continue;
     }
     int sockopt = 1;
-    if(setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, (a2_sockopt_t) &sockopt, sizeof(sockopt)) < 0) {
-      error = errorMsg();
+    if(setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, (a2_sockopt_t) &sockopt,
+                  sizeof(sockopt)) < 0) {
+      errNum = SOCKET_ERRNO;
+      error = errorMsg(errNum);
       CLOSE(fd);
       continue;
     }
@@ -405,10 +432,9 @@ void SocketCore::establishConnection(const std::string& host, uint16_t port)
           i != eoi; ++i) {
         if(::bind(fd,reinterpret_cast<const struct sockaddr*>(&(*i).first),
                   (*i).second) == -1) {
-          error = errorMsg();
-          if(LogFactory::getInstance()->debug()) {
-            LogFactory::getInstance()->debug(EX_SOCKET_BIND, error.c_str());
-          }
+          errNum = SOCKET_ERRNO;
+          error = errorMsg(errNum);
+          A2_LOG_DEBUG(fmt(EX_SOCKET_BIND, error.c_str()));
         } else {
           bindSuccess = true;
           break;
@@ -425,7 +451,8 @@ void SocketCore::establishConnection(const std::string& host, uint16_t port)
     setNonBlockingMode();
     if(connect(fd, rp->ai_addr, rp->ai_addrlen) == -1 &&
        SOCKET_ERRNO != A2_EINPROGRESS) {
-      error = errorMsg();
+      errNum = SOCKET_ERRNO;
+      error = errorMsg(errNum);
       CLOSE(sockfd_);
       sockfd_ = (sock_t) -1;
       continue;
@@ -435,8 +462,10 @@ void SocketCore::establishConnection(const std::string& host, uint16_t port)
     break;
   }
   if(sockfd_ == (sock_t) -1) {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_CONNECT, host.c_str(),
-                                   error.c_str()).str());
+    throw DL_ABORT_EX
+      (fmt(EX_SOCKET_CONNECT,
+           host.c_str(),
+           error.c_str()));
   }
 }
 
@@ -444,7 +473,8 @@ void SocketCore::setSockOpt
 (int level, int optname, void* optval, socklen_t optlen)
 {
   if(setsockopt(sockfd_, level, optname, (a2_sockopt_t)optval, optlen) < 0) {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_SET_OPT, errorMsg()).str());
+    int errNum = SOCKET_ERRNO;
+    throw DL_ABORT_EX(fmt(EX_SOCKET_SET_OPT, errorMsg(errNum).c_str()));
   }
 }   
 
@@ -455,8 +485,7 @@ void SocketCore::setMulticastInterface(const std::string& localAddr)
     addr.s_addr = htonl(INADDR_ANY);
   } else {
     if(inet_aton(localAddr.c_str(), &addr) == 0) {
-      throw DL_ABORT_EX
-        (StringFormat("inet_aton failed for %s", localAddr.c_str()).str());
+      throw DL_ABORT_EX(fmt("inet_aton failed for %s", localAddr.c_str()));
     }
   }
   setSockOpt(IPPROTO_IP, IP_MULTICAST_IF, &addr, sizeof(addr));
@@ -478,16 +507,14 @@ void SocketCore::joinMulticastGroup
 {
   in_addr multiAddr;
   if(inet_aton(multicastAddr.c_str(), &multiAddr) == 0) {
-    throw DL_ABORT_EX
-      (StringFormat("inet_aton failed for %s", multicastAddr.c_str()).str());
+    throw DL_ABORT_EX(fmt("inet_aton failed for %s", multicastAddr.c_str()));
   }
   in_addr ifAddr;
   if(localAddr.empty()) {
     ifAddr.s_addr = htonl(INADDR_ANY);
   } else {
     if(inet_aton(localAddr.c_str(), &ifAddr) == 0) {
-      throw DL_ABORT_EX
-        (StringFormat("inet_aton failed for %s", localAddr.c_str()).str());
+      throw DL_ABORT_EX(fmt("inet_aton failed for %s", localAddr.c_str()));
     }
   }
   struct ip_mreq mreq;
@@ -502,7 +529,8 @@ void SocketCore::setNonBlockingMode()
 #ifdef __MINGW32__
   static u_long flag = 1;
   if (::ioctlsocket(sockfd_, FIONBIO, &flag) == -1) {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_NONBLOCKING, errorMsg()).str());
+    int errNum = SOCKET_ERRNO;
+    throw DL_ABORT_EX(fmt(EX_SOCKET_NONBLOCKING, errorMsg(errNum).c_str()));
   }
 #else
   int flags;
@@ -518,7 +546,8 @@ void SocketCore::setBlockingMode()
 #ifdef __MINGW32__
   static u_long flag = 0;
   if (::ioctlsocket(sockfd_, FIONBIO, &flag) == -1) {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_BLOCKING, errorMsg()).str());
+    int errNum = SOCKET_ERRNO;
+    throw DL_ABORT_EX(fmt(EX_SOCKET_BLOCKING, errorMsg(errNum).c_str()));
   }
 #else
   int flags;
@@ -576,13 +605,13 @@ bool SocketCore::isWritable(time_t timeout)
   p.events = POLLOUT;
   int r;
   while((r = poll(&p, 1, timeout*1000)) == -1 && errno == EINTR);
+  int errNum = SOCKET_ERRNO;
   if(r > 0) {
     return p.revents&(POLLOUT|POLLHUP|POLLERR);
   } else if(r == 0) {
     return false;
   } else {
-    throw DL_RETRY_EX
-      (StringFormat(EX_SOCKET_CHECK_WRITABLE, errorMsg()).str());
+    throw DL_RETRY_EX(fmt(EX_SOCKET_CHECK_WRITABLE, errorMsg(errNum).c_str()));
   }
 #else // !HAVE_POLL
 # ifndef __MINGW32__
@@ -597,17 +626,19 @@ bool SocketCore::isWritable(time_t timeout)
   tv.tv_usec = 0;
 
   int r = select(sockfd_+1, NULL, &fds, NULL, &tv);
+  int errNum = SOCKET_ERRNO;
   if(r == 1) {
     return true;
   } else if(r == 0) {
     // time out
     return false;
   } else {
-    if(SOCKET_ERRNO == A2_EINPROGRESS || SOCKET_ERRNO == A2_EINTR) {
+    if(errNum == A2_EINPROGRESS || errNum == A2_EINTR) {
       return false;
     } else {
       throw DL_RETRY_EX
-        (StringFormat(EX_SOCKET_CHECK_WRITABLE, errorMsg()).str());
+        (fmt(EX_SOCKET_CHECK_WRITABLE,
+             errorMsg(errNum).c_str()));
     }
   }
 #endif // !HAVE_POLL
@@ -626,13 +657,13 @@ bool SocketCore::isReadable(time_t timeout)
   p.events = POLLIN;
   int r;
   while((r = poll(&p, 1, timeout*1000)) == -1 && errno == EINTR);
+  int errNum = SOCKET_ERRNO;
   if(r > 0) {
     return p.revents&(POLLIN|POLLHUP|POLLERR);
   } else if(r == 0) {
     return false;
   } else {
-    throw DL_RETRY_EX
-      (StringFormat(EX_SOCKET_CHECK_READABLE, errorMsg()).str());
+    throw DL_RETRY_EX(fmt(EX_SOCKET_CHECK_READABLE, errorMsg(errNum).c_str()));
   }
 #else // !HAVE_POLL
 # ifndef __MINGW32__
@@ -647,17 +678,19 @@ bool SocketCore::isReadable(time_t timeout)
   tv.tv_usec = 0;
 
   int r = select(sockfd_+1, &fds, NULL, NULL, &tv);
+  int errNum = SOCKET_ERRNO;
   if(r == 1) {
     return true;
   } else if(r == 0) {
     // time out
     return false;
   } else {
-    if(SOCKET_ERRNO == A2_EINPROGRESS || SOCKET_ERRNO == A2_EINTR) {
+    if(errNum == A2_EINPROGRESS || errNum == A2_EINTR) {
       return false;
     } else {
       throw DL_RETRY_EX
-        (StringFormat(EX_SOCKET_CHECK_READABLE, errorMsg()).str());
+        (fmt(EX_SOCKET_CHECK_READABLE,
+             errorMsg(errNum).c_str()));
     }
   }
 #endif // !HAVE_POLL
@@ -699,12 +732,13 @@ ssize_t SocketCore::writeData(const char* data, size_t len)
 
   if(!secure_) {
     while((ret = send(sockfd_, data, len, 0)) == -1 && SOCKET_ERRNO == A2_EINTR);
+    int errNum = SOCKET_ERRNO;
     if(ret == -1) {
-      if(A2_WOULDBLOCK(SOCKET_ERRNO)) {
+      if(A2_WOULDBLOCK(errNum)) {
         wantWrite_ = true;
         ret = 0;
       } else {
-        throw DL_RETRY_EX(StringFormat(EX_SOCKET_SEND, errorMsg()).str());
+        throw DL_RETRY_EX(fmt(EX_SOCKET_SEND, errorMsg(errNum).c_str()));
       }
     }
   } else {
@@ -715,8 +749,8 @@ ssize_t SocketCore::writeData(const char* data, size_t len)
     }
     if(ret < 0) {
       throw DL_RETRY_EX
-        (StringFormat
-         (EX_SOCKET_SEND, ERR_error_string(SSL_get_error(ssl, ret), 0)).str());
+        (fmt(EX_SOCKET_SEND,
+             ERR_error_string(SSL_get_error(ssl, ret), 0)));
     }
 #endif // HAVE_LIBSSL
 #ifdef HAVE_LIBGNUTLS
@@ -726,7 +760,7 @@ ssize_t SocketCore::writeData(const char* data, size_t len)
       gnutlsRecordCheckDirection();
       ret = 0;
     } else if(ret < 0) {
-      throw DL_RETRY_EX(StringFormat(EX_SOCKET_SEND, gnutls_strerror(ret)).str());
+      throw DL_RETRY_EX(fmt(EX_SOCKET_SEND, gnutls_strerror(ret)));
     }
 #endif // HAVE_LIBGNUTLS
   }
@@ -743,12 +777,13 @@ void SocketCore::readData(char* data, size_t& len)
   if(!secure_) {    
     while((ret = recv(sockfd_, data, len, 0)) == -1 && SOCKET_ERRNO == A2_EINTR);
     
+    int errNum = SOCKET_ERRNO;
     if(ret == -1) {
-      if(A2_WOULDBLOCK(SOCKET_ERRNO)) {
+      if(A2_WOULDBLOCK(errNum)) {
         wantRead_ = true;
         ret = 0;
       } else {
-        throw DL_RETRY_EX(StringFormat(EX_SOCKET_RECV, errorMsg()).str());
+        throw DL_RETRY_EX(fmt(EX_SOCKET_RECV, errorMsg(errNum).c_str()));
       }
     }
   } else {
@@ -761,8 +796,8 @@ void SocketCore::readData(char* data, size_t& len)
     }
     if(ret < 0) {
       throw DL_RETRY_EX
-        (StringFormat
-         (EX_SOCKET_RECV, ERR_error_string(SSL_get_error(ssl, ret), 0)).str());
+        (fmt(EX_SOCKET_RECV,
+             ERR_error_string(SSL_get_error(ssl, ret), 0)));
     }
 #endif // HAVE_LIBSSL
 #ifdef HAVE_LIBGNUTLS
@@ -771,8 +806,7 @@ void SocketCore::readData(char* data, size_t& len)
       gnutlsRecordCheckDirection();
       ret = 0;
     } else if(ret < 0) {
-      throw DL_RETRY_EX
-        (StringFormat(EX_SOCKET_RECV, gnutls_strerror(ret)).str());
+      throw DL_RETRY_EX(fmt(EX_SOCKET_RECV, gnutls_strerror(ret)));
     }
 #endif // HAVE_LIBGNUTLS
   }
@@ -789,12 +823,13 @@ void SocketCore::peekData(char* data, size_t& len)
   if(!secure_) {
     while((ret = recv(sockfd_, data, len, MSG_PEEK)) == -1 &&
           SOCKET_ERRNO == A2_EINTR);
+    int errNum = SOCKET_ERRNO;
     if(ret == -1) {
-      if(A2_WOULDBLOCK(SOCKET_ERRNO)) {
+      if(A2_WOULDBLOCK(errNum)) {
         wantRead_ = true;
         ret = 0;
       } else {
-        throw DL_RETRY_EX(StringFormat(EX_SOCKET_PEEK, errorMsg()).str());
+        throw DL_RETRY_EX(fmt(EX_SOCKET_PEEK, errorMsg(errNum).c_str()));
       }
     }
   } else {
@@ -807,8 +842,8 @@ void SocketCore::peekData(char* data, size_t& len)
     }
     if(ret < 0) {
       throw DL_RETRY_EX
-        (StringFormat(EX_SOCKET_PEEK,
-                      ERR_error_string(SSL_get_error(ssl, ret), 0)).str());
+        (fmt(EX_SOCKET_PEEK,
+             ERR_error_string(SSL_get_error(ssl, ret), 0)));
     }
 #endif // HAVE_LIBSSL
 #ifdef HAVE_LIBGNUTLS
@@ -817,8 +852,7 @@ void SocketCore::peekData(char* data, size_t& len)
       gnutlsRecordCheckDirection();
       ret = 0;
     } else if(ret < 0) {
-      throw DL_RETRY_EX(StringFormat(EX_SOCKET_PEEK,
-                                     gnutls_strerror(ret)).str());
+      throw DL_RETRY_EX(fmt(EX_SOCKET_PEEK, gnutls_strerror(ret)));
     }
 #endif // HAVE_LIBGNUTLS
   }
@@ -863,8 +897,7 @@ static ssize_t GNUTLS_RECORD_RECV_NO_INTERRUPT
   while((ret = gnutls_record_recv(sslSession, data, len)) ==
         GNUTLS_E_INTERRUPTED);
   if(ret < 0 && ret != GNUTLS_E_AGAIN) {
-    throw DL_RETRY_EX
-      (StringFormat(EX_SOCKET_RECV, gnutls_strerror(ret)).str());
+    throw DL_RETRY_EX(fmt(EX_SOCKET_RECV, gnutls_strerror(ret)));
   }
   return ret;
 }
@@ -910,13 +943,13 @@ void SocketCore::prepareSecureConnection()
     ssl = SSL_new(tlsContext_->getSSLCtx());
     if(!ssl) {
       throw DL_ABORT_EX
-        (StringFormat(EX_SSL_INIT_FAILURE,
-                      ERR_error_string(ERR_get_error(), 0)).str());
+        (fmt(EX_SSL_INIT_FAILURE,
+             ERR_error_string(ERR_get_error(), 0)));
     }
     if(SSL_set_fd(ssl, sockfd_) == 0) {
       throw DL_ABORT_EX
-        (StringFormat(EX_SSL_INIT_FAILURE,
-                      ERR_error_string(ERR_get_error(), 0)).str());
+        (fmt(EX_SSL_INIT_FAILURE,
+             ERR_error_string(ERR_get_error(), 0)));
     }
 #endif // HAVE_LIBSSL
 #ifdef HAVE_LIBGNUTLS
@@ -929,8 +962,7 @@ void SocketCore::prepareSecureConnection()
     // understand TLS1.1.
     r = gnutls_priority_set_direct(sslSession_, "NORMAL:!VERS-TLS1.1", &err);
     if(r != GNUTLS_E_SUCCESS) {
-      throw DL_ABORT_EX
-        (StringFormat(EX_SSL_INIT_FAILURE, gnutls_strerror(r)).str());
+      throw DL_ABORT_EX(fmt(EX_SSL_INIT_FAILURE, gnutls_strerror(r)));
     }
     // put the x509 credentials to the current session
     gnutls_credentials_set(sslSession_, GNUTLS_CRD_CERTIFICATE,
@@ -964,8 +996,7 @@ bool SocketCore::initiateSecureConnection(const std::string& hostname)
       case SSL_ERROR_WANT_X509_LOOKUP:
       case SSL_ERROR_ZERO_RETURN:
         if (blocking_) {
-          throw DL_ABORT_EX
-            (StringFormat(EX_SSL_CONNECT_ERROR, ssl_error).str());
+          throw DL_ABORT_EX(fmt(EX_SSL_CONNECT_ERROR, ssl_error));
         }
         break;
 
@@ -976,8 +1007,7 @@ bool SocketCore::initiateSecureConnection(const std::string& hostname)
         throw DL_ABORT_EX(EX_SSL_PROTOCOL_ERROR);
 
       default:
-        throw DL_ABORT_EX
-          (StringFormat(EX_SSL_UNKNOWN_ERROR, ssl_error).str());
+        throw DL_ABORT_EX(fmt(EX_SSL_UNKNOWN_ERROR, ssl_error));
       }
     }
     if(tlsContext_->peerVerificationEnabled()) {
@@ -991,8 +1021,8 @@ bool SocketCore::initiateSecureConnection(const std::string& hostname)
       long verifyResult = SSL_get_verify_result(ssl);
       if(verifyResult != X509_V_OK) {
         throw DL_ABORT_EX
-          (StringFormat(MSG_CERT_VERIFICATION_FAILED,
-                        X509_verify_cert_error_string(verifyResult)).str());
+          (fmt(MSG_CERT_VERIFICATION_FAILED,
+               X509_verify_cert_error_string(verifyResult)));
       }
       X509_NAME* name = X509_get_subject_name(peerCert);
       if(!name) {
@@ -1030,8 +1060,7 @@ bool SocketCore::initiateSecureConnection(const std::string& hostname)
       gnutlsRecordCheckDirection();
       return false;
     } else if(ret < 0) {
-      throw DL_ABORT_EX
-        (StringFormat(EX_SSL_INIT_FAILURE, gnutls_strerror(ret)).str());
+      throw DL_ABORT_EX(fmt(EX_SSL_INIT_FAILURE, gnutls_strerror(ret)));
     }
 
     if(tlsContext_->peerVerificationEnabled()) {
@@ -1040,8 +1069,8 @@ bool SocketCore::initiateSecureConnection(const std::string& hostname)
       ret = gnutls_certificate_verify_peers2(sslSession_, &status);
       if(ret < 0) {
         throw DL_ABORT_EX
-          (StringFormat("gnutls_certificate_verify_peer2() failed. Cause: %s",
-                        gnutls_strerror(ret)).str());
+          (fmt("gnutls_certificate_verify_peer2() failed. Cause: %s",
+               gnutls_strerror(ret)));
       }
       if(status) {
         std::string errors;
@@ -1055,8 +1084,7 @@ bool SocketCore::initiateSecureConnection(const std::string& hostname)
           errors += " `issuer is not known'";
         }
         if(!errors.empty()) {
-          throw DL_ABORT_EX
-            (StringFormat(MSG_CERT_VERIFICATION_FAILED, errors.c_str()).str());
+          throw DL_ABORT_EX(fmt(MSG_CERT_VERIFICATION_FAILED, errors.c_str()));
         }
       }
       // certificate type: only X509 is allowed.
@@ -1076,16 +1104,16 @@ bool SocketCore::initiateSecureConnection(const std::string& hostname)
         ret = gnutls_x509_crt_init(&cert);
         if(ret < 0) {
           throw DL_ABORT_EX
-            (StringFormat("gnutls_x509_crt_init() failed. Cause: %s",
-                          gnutls_strerror(ret)).str());
+            (fmt("gnutls_x509_crt_init() failed. Cause: %s",
+                 gnutls_strerror(ret)));
         }
         auto_delete<gnutls_x509_crt_t> certDeleter
           (cert, gnutls_x509_crt_deinit);
         ret = gnutls_x509_crt_import(cert, &peerCerts[i], GNUTLS_X509_FMT_DER);
         if(ret < 0) {
           throw DL_ABORT_EX
-            (StringFormat("gnutls_x509_crt_import() failed. Cause: %s",
-                          gnutls_strerror(ret)).str());
+            (fmt("gnutls_x509_crt_import() failed. Cause: %s",
+                 gnutls_strerror(ret)));
         }
         if(i == 0) {
           if(!gnutls_x509_crt_check_hostname(cert, hostname.c_str())) {
@@ -1128,25 +1156,27 @@ ssize_t SocketCore::writeData(const char* data, size_t len,
   s = callGetaddrinfo(&res, host.c_str(), util::uitos(port).c_str(),
                       protocolFamily_, sockType_, 0, 0);
   if(s) {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_SEND, gai_strerror(s)).str());
+    throw DL_ABORT_EX(fmt(EX_SOCKET_SEND, gai_strerror(s)));
   }
   WSAAPI_AUTO_DELETE<struct addrinfo*> resDeleter(res, freeaddrinfo);
   struct addrinfo* rp;
   ssize_t r = -1;
+  int errNum = 0;
   for(rp = res; rp; rp = rp->ai_next) {
     while((r = sendto(sockfd_, data, len, 0, rp->ai_addr, rp->ai_addrlen)) == -1
           && A2_EINTR == SOCKET_ERRNO);
+    errNum = SOCKET_ERRNO;
     if(r == static_cast<ssize_t>(len)) {
       break;
     }
-    if(r == -1 && A2_WOULDBLOCK(SOCKET_ERRNO)) {
+    if(r == -1 && A2_WOULDBLOCK(errNum)) {
       wantWrite_ = true;
       r = 0;
       break;
     }
   }
   if(r == -1) {
-    throw DL_ABORT_EX(StringFormat(EX_SOCKET_SEND, errorMsg()).str());
+    throw DL_ABORT_EX(fmt(EX_SOCKET_SEND, errorMsg(errNum).c_str()));
   }
   return r;
 }
@@ -1163,12 +1193,13 @@ ssize_t SocketCore::readDataFrom(char* data, size_t len,
   ssize_t r;
   while((r = recvfrom(sockfd_, data, len, 0, addrp, &sockaddrlen)) == -1 &&
         A2_EINTR == SOCKET_ERRNO);
+  int errNum = SOCKET_ERRNO;
   if(r == -1) {
-    if(A2_WOULDBLOCK(SOCKET_ERRNO)) {
+    if(A2_WOULDBLOCK(errNum)) {
       wantRead_ = true;
       r = 0;
     } else {
-      throw DL_RETRY_EX(StringFormat(EX_SOCKET_RECV, errorMsg()).str());
+      throw DL_RETRY_EX(fmt(EX_SOCKET_RECV, errorMsg(errNum).c_str()));
     }
   } else {
     sender = util::getNumericNameInfo(addrp, sockaddrlen);
@@ -1182,9 +1213,12 @@ std::string SocketCore::getSocketError() const
   int error;
   socklen_t optlen = sizeof(error);
 
-  if(getsockopt(sockfd_, SOL_SOCKET, SO_ERROR, (a2_sockopt_t) &error, &optlen) == -1) {
-    throw DL_ABORT_EX(StringFormat("Failed to get socket error: %s",
-                                   errorMsg()).str());
+  if(getsockopt(sockfd_, SOL_SOCKET, SO_ERROR,
+                (a2_sockopt_t) &error, &optlen) == -1) {
+    int errNum = SOCKET_ERRNO;
+    throw DL_ABORT_EX
+      (fmt("Failed to get socket error: %s",
+           errorMsg(errNum).c_str()));
   }
   if(error != 0) {
     return errorMsg(error);
@@ -1209,8 +1243,9 @@ void SocketCore::bindAddress(const std::string& iface)
   getInterfaceAddress(bindAddrs, iface, protocolFamily_);
   if(bindAddrs.empty()) {
     throw DL_ABORT_EX
-      (StringFormat(MSG_INTERFACE_NOT_FOUND,
-                    iface.c_str(), "not available").str());
+      (fmt(MSG_INTERFACE_NOT_FOUND,
+           iface.c_str(),
+           "not available"));
   } else {
     bindAddrs_ = bindAddrs;
     for(std::vector<std::pair<struct sockaddr_storage, socklen_t> >::
@@ -1223,9 +1258,7 @@ void SocketCore::bindAddress(const std::string& iface)
                       host, NI_MAXHOST, 0, 0,
                       NI_NUMERICHOST);
       if(s == 0) {
-        if(LogFactory::getInstance()->debug()) {
-          LogFactory::getInstance()->debug("Sockets will bind to %s", host);
-        }
+        A2_LOG_DEBUG(fmt("Sockets will bind to %s", host));
       }
     }
   }
@@ -1235,15 +1268,14 @@ void getInterfaceAddress
 (std::vector<std::pair<struct sockaddr_storage, socklen_t> >& ifAddrs,
  const std::string& iface, int family, int aiFlags)
 {
-  Logger* logger = LogFactory::getInstance();
-  if(logger->debug()) {
-    logger->debug("Finding interface %s", iface.c_str());
-  }
+  A2_LOG_DEBUG(fmt("Finding interface %s", iface.c_str()));
 #ifdef HAVE_GETIFADDRS
   // First find interface in interface addresses
   struct ifaddrs* ifaddr = 0;
   if(getifaddrs(&ifaddr) == -1) {
-    logger->info(MSG_INTERFACE_NOT_FOUND, iface.c_str(), errorMsg());
+    int errNum = SOCKET_ERRNO;
+    A2_LOG_INFO(fmt(MSG_INTERFACE_NOT_FOUND,
+                    iface.c_str(), errorMsg(errNum).c_str()));
   } else {
     auto_delete<struct ifaddrs*> ifaddrDeleter(ifaddr, freeifaddrs);
     for(struct ifaddrs* ifa = ifaddr; ifa; ifa = ifa->ifa_next) {
@@ -1282,7 +1314,7 @@ void getInterfaceAddress
     int s;
     s = callGetaddrinfo(&res, iface.c_str(), 0, family, SOCK_STREAM, aiFlags,0);
     if(s) {
-      logger->info(MSG_INTERFACE_NOT_FOUND, iface.c_str(), gai_strerror(s));
+      A2_LOG_INFO(fmt(MSG_INTERFACE_NOT_FOUND, iface.c_str(), gai_strerror(s)));
     } else {
       WSAAPI_AUTO_DELETE<struct addrinfo*> resDeleter(res, freeaddrinfo);
       struct addrinfo* rp;
