@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_SPEED_CALC_H_
-#define _D_SPEED_CALC_H_
+#ifndef D_SPEED_CALC_H
+#define D_SPEED_CALC_H
 
 #include "common.h"
 #include "TimerA2.h"
@@ -42,14 +42,14 @@ namespace aria2 {
 
 class SpeedCalc {
 private:
-  uint64_t lengthArray[2];
-  int sw;
-  Timer cpArray[2];
-  unsigned int maxSpeed;
-  unsigned int prevSpeed;
-  Timer start;
-  uint64_t accumulatedLength;
-  time_t nextInterval;
+  uint64_t lengthArray_[2];
+  int sw_;
+  Timer cpArray_[2];
+  unsigned int maxSpeed_;
+  unsigned int prevSpeed_;
+  Timer start_;
+  uint64_t accumulatedLength_;
+  time_t nextInterval_;
 
   bool isIntervalOver() const;
 
@@ -65,7 +65,7 @@ public:
   unsigned int calculateSpeed();
 
   unsigned int getMaxSpeed() const {
-    return maxSpeed;
+    return maxSpeed_;
   }
 
   unsigned int calculateAvgSpeed() const;
@@ -77,4 +77,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_SPEED_CALC_H_
+#endif // D_SPEED_CALC_H
