@@ -36,9 +36,6 @@
 #include "RequestGroup.h"
 #include "DownloadEngine.h"
 #include "StreamFileAllocationEntry.h"
-#include "DownloadContext.h"
-#include "RequestGroupMan.h"
-#include "ServerStatMan.h"
 
 namespace aria2 {
 
