@@ -53,6 +53,7 @@
 #include "Option.h"
 #include "DlAbortEx.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "A2STR.h"
 #include "SocketCore.h"
 #include "Request.h"
@@ -61,18 +62,15 @@
 #include "bittorrent_helper.h"
 #include "a2functional.h"
 #include "util.h"
-#include "RequestGroupMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
-#include "ServerStatMan.h"
+#include "fmt.h"
 
 namespace aria2 {
 
 TrackerWatcherCommand::TrackerWatcherCommand
-(cuid_t cuid, RequestGroup* requestGroup, DownloadEngine* e):
-  Command(cuid),
-  requestGroup_(requestGroup),
-  e_(e)
+(cuid_t cuid, RequestGroup* requestGroup, DownloadEngine* e)
+  : Command(cuid),
+    requestGroup_(requestGroup),
+    e_(e)
 {
   requestGroup_->increaseNumCommand();
 }
@@ -84,7 +82,7 @@ TrackerWatcherCommand::~TrackerWatcherCommand()
 
 bool TrackerWatcherCommand::execute() {
   if(requestGroup_->isForceHaltRequested()) {
-    if(trackerRequestGroup_.isNull()) {
+    if(!trackerRequestGroup_) {
       return true;
     } else if(trackerRequestGroup_->getNumCommand() == 0 ||
               trackerRequestGroup_->downloadFinished()) {
@@ -96,25 +94,21 @@ bool TrackerWatcherCommand::execute() {
     }
   }
   if(btAnnounce_->noMoreAnnounce()) {
-    if(getLogger()->debug()) {
-      getLogger()->debug("no more announce");
-    }
+    A2_LOG_DEBUG("no more announce");
     return true;
   }
-  if(trackerRequestGroup_.isNull()) {
+  if(!trackerRequestGroup_) {
     trackerRequestGroup_ = createAnnounce();
-    if(!trackerRequestGroup_.isNull()) {
+    if(trackerRequestGroup_) {
       try {
         std::vector<Command*>* commands = new std::vector<Command*>();
         auto_delete_container<std::vector<Command*> > commandsDel(commands);
         trackerRequestGroup_->createInitialCommand(*commands, e_);
         e_->addCommand(*commands);
         commands->clear();
-        if(getLogger()->debug()) {
-          getLogger()->debug("added tracker request command");
-        }
+        A2_LOG_DEBUG("added tracker request command");
       } catch(RecoverableException& ex) {
-        getLogger()->error(EX_EXCEPTION_CAUGHT, ex);
+        A2_LOG_ERROR_EX(EX_EXCEPTION_CAUGHT, ex);
       }
     }
   } else if(trackerRequestGroup_->downloadFinished()){
@@ -125,7 +119,7 @@ bool TrackerWatcherCommand::execute() {
       btAnnounce_->announceSuccess();
       btAnnounce_->resetAnnounce();
     } catch(RecoverableException& ex) {
-      getLogger()->error(EX_EXCEPTION_CAUGHT, ex);      
+      A2_LOG_ERROR_EX(EX_EXCEPTION_CAUGHT, ex);      
       btAnnounce_->announceFailure();
       if(btAnnounce_->isAllAnnounceFailed()) {
         btAnnounce_->resetAnnounce();
@@ -170,7 +164,7 @@ void TrackerWatcherCommand::processTrackerResponse
      trackerResponse.size());
   while(!btRuntime_->isHalt() && btRuntime_->lessThanMinPeers()) {
     SharedHandle<Peer> peer = peerStorage_->getUnusedPeer();
-    if(peer.isNull()) {
+    if(!peer) {
       break;
     }
     peer->usedBy(e_->newCUID());
@@ -180,11 +174,9 @@ void TrackerWatcherCommand::processTrackerResponse
     command->setPeerStorage(peerStorage_);
     command->setPieceStorage(pieceStorage_);
     e_->addCommand(command);
-    if(getLogger()->debug()) {
-      getLogger()->debug("CUID#%s - Adding new command CUID#%s",
-                         util::itos(getCuid()).c_str(),
-                         util::itos(peer->usedBy()).c_str());
-    }
+    A2_LOG_DEBUG(fmt("CUID#%lld - Adding new command CUID#%s",
+                     getCuid(),
+                     util::itos(peer->usedBy()).c_str()));
   }
 }
 
@@ -224,13 +216,9 @@ TrackerWatcherCommand::createRequestGroup(const std::string& uri)
   uris.push_back(uri);
   SharedHandle<RequestGroup> rg(new RequestGroup(getOption()));
   if(backupTrackerIsAvailable(requestGroup_->getDownloadContext())) {
-    if(getLogger()->debug()) {
-      getLogger()->debug("This is multi-tracker announce.");
-    }
+    A2_LOG_DEBUG("This is multi-tracker announce.");
   } else {
-    if(getLogger()->debug()) {
-      getLogger()->debug("This is single-tracker announce.");
-    }
+    A2_LOG_DEBUG("This is single-tracker announce.");
   }
   rg->setNumConcurrentCommand(1);
   // If backup tracker is available, try 2 times for each tracker
@@ -250,7 +238,6 @@ TrackerWatcherCommand::createRequestGroup(const std::string& uri)
     (new DownloadContext(getOption()->getAsInt(PREF_SEGMENT_SIZE),
                          0,
                          TRACKER_ANNOUNCE_FILE));
-  dctx->setDir(A2STR::NIL);
   dctx->getFileEntries().front()->setUris(uris);
   rg->setDownloadContext(dctx);
   SharedHandle<DiskWriterFactory> dwf(new ByteArrayDiskWriterFactory());
@@ -258,10 +245,8 @@ TrackerWatcherCommand::createRequestGroup(const std::string& uri)
   rg->setFileAllocationEnabled(false);
   rg->setPreLocalFileCheckEnabled(false);
   util::removeMetalinkContentTypes(rg);
-  if(getLogger()->info()) {
-    getLogger()->info("Creating tracker request group GID#%s",
-                      util::itos(rg->getGID()).c_str());
-  }
+  A2_LOG_INFO(fmt("Creating tracker request group GID#%s",
+                  util::itos(rg->getGID()).c_str()));
   return rg;
 }
 
