@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,13 +32,13 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_UT_PEX_EXTENSION_MESSAGE_H_
-#define _D_UT_PEX_EXTENSION_MESSAGE_H_
+#ifndef D_UT_PEX_EXTENSION_MESSAGE_H
+#define D_UT_PEX_EXTENSION_MESSAGE_H
 
 #include "ExtensionMessage.h"
 
 #include <utility>
-#include <deque>
+#include <vector>
 
 #include "a2time.h"
 
@@ -51,33 +51,35 @@ typedef SharedHandle<UTPexExtensionMessage> UTPexExtensionMessageHandle;
 
 class UTPexExtensionMessage:public ExtensionMessage {
 private:
-  uint8_t _extensionMessageID;
+  uint8_t extensionMessageID_;
 
-  std::deque<SharedHandle<Peer> > _freshPeers;
+  std::vector<SharedHandle<Peer> > freshPeers_;
 
-  std::deque<SharedHandle<Peer> > _droppedPeers;
+  std::vector<SharedHandle<Peer> > droppedPeers_;
 
-  SharedHandle<PeerStorage> _peerStorage;
+  SharedHandle<PeerStorage> peerStorage_;
 
-  time_t _interval;
+  time_t interval_;
 
-  size_t _maxFreshPeer;
+  size_t maxFreshPeer_;
 
-  size_t _maxDroppedPeer;
+  size_t maxDroppedPeer_;
 
-  std::pair<std::string, std::string>
-  createCompactPeerListAndFlag(const std::deque<SharedHandle<Peer> >& peers);
+
+  std::pair<std::pair<std::string, std::string>,
+            std::pair<std::string, std::string> >
+  createCompactPeerListAndFlag(const std::vector<SharedHandle<Peer> >& peers);
 
 public:
   UTPexExtensionMessage(uint8_t extensionMessageID);
 
   virtual ~UTPexExtensionMessage();
 
-  virtual std::string getBencodedData();
+  virtual std::string getPayload();
 
   virtual uint8_t getExtensionMessageID()
   {
-    return _extensionMessageID;
+    return extensionMessageID_;
   }
   
   virtual const std::string& getExtensionName() const
@@ -93,18 +95,18 @@ public:
 
   bool addFreshPeer(const SharedHandle<Peer>& peer);
 
-  const std::deque<SharedHandle<Peer> >& getFreshPeers() const
+  const std::vector<SharedHandle<Peer> >& getFreshPeers() const
   {
-    return _freshPeers;
+    return freshPeers_;
   }
   
   bool freshPeersAreFull() const;
 
   bool addDroppedPeer(const SharedHandle<Peer>& peer);
 
-  const std::deque<SharedHandle<Peer> >& getDroppedPeers() const
+  const std::vector<SharedHandle<Peer> >& getDroppedPeers() const
   {
-    return _droppedPeers;
+    return droppedPeers_;
   }
 
   bool droppedPeersAreFull() const;
@@ -118,25 +120,25 @@ public:
 
   size_t getMaxFreshPeer() const
   {
-    return _maxFreshPeer;
+    return maxFreshPeer_;
   }
 
   void setMaxDroppedPeer(size_t maxDroppedPeer);
 
   size_t getMaxDroppedPeer() const
   {
-    return _maxDroppedPeer;
+    return maxDroppedPeer_;
   }
 
   static const time_t DEFAULT_INTERVAL = 60;
 
-  static const size_t DEFAULT_MAX_FRESH_PEER = 30;
+  static const size_t DEFAULT_MAX_FRESH_PEER = 50;
 
-  static const size_t DEFAULT_MAX_DROPPED_PEER = 10;
+  static const size_t DEFAULT_MAX_DROPPED_PEER = 50;
 };
 
 typedef SharedHandle<UTPexExtensionMessage> UTPexExtensionMessageHandle;
 
 } // namespace aria2
 
-#endif // _D_UT_PEX_EXTENSION_MESSAGE_H_
+#endif // D_UT_PEX_EXTENSION_MESSAGE_H
