@@ -48,13 +48,12 @@
 #include "download_helper.h"
 #include "util.h"
 #include "RequestGroupMan.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "XmlRpcRequest.h"
 #include "PieceStorage.h"
 #include "DownloadContext.h"
 #include "DiskAdaptor.h"
 #include "FileEntry.h"
-#include "BtProgressInfoFile.h"
 #include "prefs.h"
 #include "message.h"
 #include "FeatureConfig.h"
@@ -63,10 +62,7 @@
 #include "XmlRpcResponse.h"
 #include "SegmentMan.h"
 #include "TimedHaltCommand.h"
-#include "ServerStatMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
-#include "Segment.h"
+#include "PeerStat.h"
 #ifdef ENABLE_BITTORRENT
 # include "bittorrent_helper.h"
 # include "BtRegistry.h"
@@ -166,7 +162,7 @@ SharedHandle<RequestGroup>
 findRequestGroup(const SharedHandle<RequestGroupMan>& rgman, gid_t gid)
 {
   SharedHandle<RequestGroup> group = rgman->findRequestGroup(gid);
-  if(group.isNull()) {
+  if(!group) {
     group = rgman->findReservedGroup(gid);
   }
   return group;
@@ -321,19 +317,19 @@ SharedHandle<ValueBase> removeDownload
 
   SharedHandle<RequestGroup> group =
     e->getRequestGroupMan()->findRequestGroup(gid);
-  if(group.isNull()) {
+  if(!group) {
     group = e->getRequestGroupMan()->findReservedGroup(gid);
-    if(group.isNull()) {
+    if(!group) {
       throw DL_ABORT_EX
-        (StringFormat("Active Download not found for GID#%s",
-                      util::itos(gid).c_str()).str());
+        (fmt("Active Download not found for GID#%s",
+             util::itos(gid).c_str()));
     }
     if(group->isDependencyResolved()) {
       e->getRequestGroupMan()->removeReservedGroup(gid);
     } else {
       throw DL_ABORT_EX
-        (StringFormat("GID#%s cannot be removed now",
-                      util::itos(gid).c_str()).str());
+        (fmt("GID#%s cannot be removed now",
+             util::itos(gid).c_str()));
     }
   } else {
     if(forceRemove) {
@@ -393,16 +389,16 @@ SharedHandle<ValueBase> pauseDownload
   bool reserved = false;
   SharedHandle<RequestGroup> group =
     e->getRequestGroupMan()->findRequestGroup(gid);
-  if(group.isNull()) {
+  if(!group) {
     reserved = true;
     group = e->getRequestGroupMan()->findReservedGroup(gid);
   }
-  if(!group.isNull() && pauseRequestGroup(group, reserved, forcePause)) {
+  if(group && pauseRequestGroup(group, reserved, forcePause)) {
     return createGIDResponse(gid);
   } else {
     throw DL_ABORT_EX
-      (StringFormat("GID#%s cannot be paused now",
-                    util::itos(gid).c_str()).str());
+      (fmt("GID#%s cannot be paused now",
+           util::itos(gid).c_str()));
   }
 }
 } // namespace
@@ -463,10 +459,10 @@ SharedHandle<ValueBase> UnpauseXmlRpcMethod::process
   gid_t gid = getRequiredGidParam(req, 0);
   SharedHandle<RequestGroup> group =
     e->getRequestGroupMan()->findReservedGroup(gid);
-  if(group.isNull() || !group->isPauseRequested()) {
+  if(!group || !group->isPauseRequested()) {
     throw DL_ABORT_EX
-      (StringFormat("GID#%s cannot be unpaused now",
-                    util::itos(gid).c_str()).str());
+      (fmt("GID#%s cannot be unpaused now",
+           util::itos(gid).c_str()));
   } else {
     group->setPauseRequested(false);
     e->getRequestGroupMan()->requestQueueCheck();    
@@ -579,7 +575,7 @@ void gatherProgressCommon
   }
   if(requested_key(keys, KEY_BITFIELD)) {
     SharedHandle<PieceStorage> ps = group->getPieceStorage();
-    if(!ps.isNull()) {
+    if(ps) {
       if(ps->getBitfieldLength() > 0) {
         entryDict->put(KEY_BITFIELD,
                        util::toHex(ps->getBitfield(), ps->getBitfieldLength()));
@@ -616,7 +612,7 @@ void gatherProgressCommon
     entryDict->put(KEY_FILES, files);
   }
   if(requested_key(keys, KEY_DIR)) {
-    entryDict->put(KEY_DIR, dctx->getDir());
+    entryDict->put(KEY_DIR, group->getOption()->get(PREF_DIR));
   }
 }
 
@@ -673,7 +669,7 @@ void gatherProgressBitTorrent
       entryDict->put(KEY_NUM_SEEDERS, VLB_ZERO);
     } else {
       SharedHandle<PeerStorage> peerStorage = btObject.peerStorage_;
-      assert(!peerStorage.isNull());
+      assert(peerStorage);
       std::vector<SharedHandle<Peer> > peers;
       peerStorage->getActivePeers(peers);
       entryDict->put(KEY_NUM_SEEDERS,
@@ -744,9 +740,9 @@ void gatherStoppedDownload
     entryDict->put(KEY_ERROR_CODE, util::itos(static_cast<int>(ds->result)));
   }
   if(requested_key(keys, KEY_STATUS)) {
-    if(ds->result == downloadresultcode::IN_PROGRESS) {
+    if(ds->result == error_code::IN_PROGRESS) {
       entryDict->put(KEY_STATUS, VLB_REMOVED);
-    } else if(ds->result == downloadresultcode::FINISHED) {
+    } else if(ds->result == error_code::FINISHED) {
       entryDict->put(KEY_STATUS, VLB_COMPLETE);
     } else {
       entryDict->put(KEY_STATUS, VLB_ERROR);
@@ -822,13 +818,13 @@ SharedHandle<ValueBase> GetFilesXmlRpcMethod::process
   SharedHandle<List> files = List::g();
   SharedHandle<RequestGroup> group =
     findRequestGroup(e->getRequestGroupMan(), gid);
-  if(group.isNull()) {
+  if(!group) {
     SharedHandle<DownloadResult> dr =
       e->getRequestGroupMan()->findDownloadResult(gid);
-    if(dr.isNull()) {
+    if(!dr) {
       throw DL_ABORT_EX
-        (StringFormat("No file data is available for GID#%s",
-                      util::itos(gid).c_str()).str());
+        (fmt("No file data is available for GID#%s",
+             util::itos(gid).c_str()));
     } else {
       createFileEntry(files, dr->fileEntries.begin(), dr->fileEntries.end());
     }
@@ -846,10 +842,10 @@ SharedHandle<ValueBase> GetUrisXmlRpcMethod::process
   gid_t gid = getRequiredGidParam(req, 0);
   SharedHandle<RequestGroup> group =
     findRequestGroup(e->getRequestGroupMan(), gid);
-  if(group.isNull()) {
+  if(!group) {
     throw DL_ABORT_EX
-      (StringFormat("No URI data is available for GID#%s",
-                    util::itos(gid).c_str()).str());
+      (fmt("No URI data is available for GID#%s",
+           util::itos(gid).c_str()));
   }
   SharedHandle<List> uriList = List::g();
   // TODO Current implementation just returns first FileEntry's URIs.
@@ -867,15 +863,15 @@ SharedHandle<ValueBase> GetPeersXmlRpcMethod::process
 
   SharedHandle<RequestGroup> group =
     findRequestGroup(e->getRequestGroupMan(), gid);
-  if(group.isNull()) {
+  if(!group) {
     throw DL_ABORT_EX
-      (StringFormat("No peer data is available for GID#%s",
-                    util::itos(gid).c_str()).str());
+      (fmt("No peer data is available for GID#%s",
+           util::itos(gid).c_str()));
   }
   SharedHandle<List> peers = List::g();
   BtObject btObject = e->getBtRegistry()->get(group->getGID());
   if(!btObject.isNull()) {
-    assert(!btObject.peerStorage_.isNull());
+    assert(btObject.peerStorage_);
     gatherPeer(peers, btObject.peerStorage_);
   }
   return peers;
@@ -895,15 +891,15 @@ SharedHandle<ValueBase> TellStatusXmlRpcMethod::process
     e->getRequestGroupMan()->findRequestGroup(gid);
 
   SharedHandle<Dict> entryDict = Dict::g();
-  if(group.isNull()) {
+  if(!group) {
     group = e->getRequestGroupMan()->findReservedGroup(gid);
-    if(group.isNull()) {
+    if(!group) {
       SharedHandle<DownloadResult> ds =
         e->getRequestGroupMan()->findDownloadResult(gid);
-      if(ds.isNull()) {
+      if(!ds) {
         throw DL_ABORT_EX
-          (StringFormat("No such download for GID#%s",
-                        util::itos(gid).c_str()).str());
+          (fmt("No such download for GID#%s",
+               util::itos(gid).c_str()));
       }
       gatherStoppedDownload(entryDict, ds, keys);
     } else {
@@ -997,10 +993,10 @@ SharedHandle<ValueBase> ChangeOptionXmlRpcMethod::process
 
   SharedHandle<RequestGroup> group =
     findRequestGroup(e->getRequestGroupMan(), gid);
-  if(group.isNull()) {
+  if(!group) {
     throw DL_ABORT_EX
-      (StringFormat("Cannot change option for GID#%s",
-                    util::itos(gid).c_str()).str());
+      (fmt("Cannot change option for GID#%s",
+           util::itos(gid).c_str()));
   }
   SharedHandle<Option> option(new Option());
   const Dict* optionsParam = req.getDictParam(1);
@@ -1104,10 +1100,10 @@ SharedHandle<ValueBase> GetOptionXmlRpcMethod::process
 
   SharedHandle<RequestGroup> group =
     findRequestGroup(e->getRequestGroupMan(), gid);
-  if(group.isNull()) {
+  if(!group) {
     throw DL_ABORT_EX
-      (StringFormat("Cannot get option for GID#%s",
-                    util::itos(gid).c_str()).str());
+      (fmt("Cannot get option for GID#%s",
+           util::itos(gid).c_str()));
   }
   SharedHandle<Dict> result = Dict::g();
   SharedHandle<Option> option = group->getOption();
@@ -1122,7 +1118,7 @@ SharedHandle<ValueBase> GetGlobalOptionXmlRpcMethod::process
   for(std::map<std::string, std::string>::const_iterator i =
         e->getOption()->begin(), eoi = e->getOption()->end(); i != eoi; ++i) {
     SharedHandle<OptionHandler> h = getOptionParser()->findByName((*i).first);
-    if(!h.isNull() && !h->isHidden()) {
+    if(h && !h->isHidden()) {
       result->put((*i).first, (*i).second);
     }
   }
@@ -1171,9 +1167,9 @@ SharedHandle<ValueBase> GetServersXmlRpcMethod::process
   gid_t gid = getRequiredGidParam(req, 0);
   SharedHandle<RequestGroup> group =
     e->getRequestGroupMan()->findRequestGroup(gid);
-  if(group.isNull()) {
-    throw DL_ABORT_EX(StringFormat("No active download for GID#%s",
-                                   util::itos(gid).c_str()).str());
+  if(!group) {
+    throw DL_ABORT_EX(fmt("No active download for GID#%s",
+                          util::itos(gid).c_str()));
   }
   const SharedHandle<DownloadContext>& dctx = group->getDownloadContext();
   const std::vector<SharedHandle<FileEntry> >& files = dctx->getFileEntries();
@@ -1189,7 +1185,7 @@ SharedHandle<ValueBase> GetServersXmlRpcMethod::process
     for(std::deque<SharedHandle<Request> >::const_iterator ri =requests.begin(),
           eoi = requests.end(); ri != eoi; ++ri) {
       SharedHandle<PeerStat> ps = (*ri)->getPeerStat();
-      if(!ps.isNull()) {
+      if(ps) {
         SharedHandle<Dict> serverEntry = Dict::g();
         serverEntry->put(KEY_URI, (*ri)->getUri());
         serverEntry->put(KEY_CURRENT_URI, (*ri)->getCurrentUri());
@@ -1221,15 +1217,15 @@ SharedHandle<ValueBase> ChangeUriXmlRpcMethod::process
   size_t index = indexParam->i()-1;
   SharedHandle<RequestGroup> group =
     findRequestGroup(e->getRequestGroupMan(), gid);
-  if(group.isNull()) {
+  if(!group) {
     throw DL_ABORT_EX
-      (StringFormat("Cannot remove URIs from GID#%s",
-                    util::itos(gid).c_str()).str());
+      (fmt("Cannot remove URIs from GID#%s",
+           util::itos(gid).c_str()));
   }
   const SharedHandle<DownloadContext>& dctx = group->getDownloadContext();
   const std::vector<SharedHandle<FileEntry> >& files = dctx->getFileEntries();
   if(files.size() <= index) {
-    throw DL_ABORT_EX(StringFormat("fileIndex is out of range").str());
+    throw DL_ABORT_EX(fmt("fileIndex is out of range"));
   }
   SharedHandle<FileEntry> s = files[index];
   size_t delcount = 0;
@@ -1259,7 +1255,7 @@ SharedHandle<ValueBase> ChangeUriXmlRpcMethod::process
       }
     }
   }
-  if(addcount && !group->getPieceStorage().isNull()) {
+  if(addcount && group->getPieceStorage()) {
     std::vector<Command*> commands;
     group->createNextCommand(commands, e);
     e->addCommand(commands);
@@ -1278,7 +1274,7 @@ SharedHandle<ValueBase> goingShutdown
   // Schedule shutdown after 3seconds to give time to client to
   // receive XML-RPC response.
   e->addRoutineCommand(new TimedHaltCommand(e->newCUID(), e, 3, forceHalt));
-  LogFactory::getInstance()->info("Scheduled shutdown in 3 seconds.");
+  A2_LOG_INFO("Scheduled shutdown in 3 seconds.");
   return VLB_OK;
 }
 } // namespace
@@ -1343,8 +1339,7 @@ SharedHandle<ValueBase> SystemMulticallXmlRpcMethod::process
 SharedHandle<ValueBase> NoSuchMethodXmlRpcMethod::process
 (const XmlRpcRequest& req, DownloadEngine* e)
 {
-  throw DL_ABORT_EX
-    (StringFormat("No such method: %s", req.methodName.c_str()).str());
+  throw DL_ABORT_EX(fmt("No such method: %s", req.methodName.c_str()));
 }
 
 } // namespace xmlrpc
