@@ -43,9 +43,9 @@
 #include "util.h"
 #include "DlAbortEx.h"
 #include "message.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "BtConstants.h"
-#include "messageDigest.h"
+#include "MessageDigest.h"
 #include "MessageDigestHelper.h"
 #include "a2netcompat.h"
 #include "BtConstants.h"
@@ -57,48 +57,52 @@
 #include "SocketCore.h"
 #include "Option.h"
 #include "prefs.h"
+#include "FileEntry.h"
+#include "error_code.h"
 
 namespace aria2 {
 
 namespace bittorrent {
 
-static const std::string C_NAME("name");
+namespace {
+const std::string C_NAME("name");
 
-static const std::string C_NAME_UTF8("name.utf-8");
+const std::string C_NAME_UTF8("name.utf-8");
 
-static const std::string C_FILES("files");
+const std::string C_FILES("files");
 
-static const std::string C_LENGTH("length");
+const std::string C_LENGTH("length");
 
-static const std::string C_PATH("path");
+const std::string C_PATH("path");
 
-static const std::string C_PATH_UTF8("path.utf-8");
+const std::string C_PATH_UTF8("path.utf-8");
 
-static const std::string C_INFO("info");
+const std::string C_INFO("info");
 
-static const std::string C_PIECES("pieces");
+const std::string C_PIECES("pieces");
 
-static const std::string C_PIECE_LENGTH("piece length");
+const std::string C_PIECE_LENGTH("piece length");
 
-static const std::string C_PRIVATE("private");
+const std::string C_PRIVATE("private");
 
-static const std::string C_URL_LIST("url-list");
+const std::string C_URL_LIST("url-list");
 
-static const std::string C_ANNOUNCE("announce");
+const std::string C_ANNOUNCE("announce");
 
-static const std::string C_ANNOUNCE_LIST("announce-list");
+const std::string C_ANNOUNCE_LIST("announce-list");
 
-static const std::string C_NODES("nodes");
+const std::string C_NODES("nodes");
 
-static const std::string C_CREATION_DATE("creation date");
+const std::string C_CREATION_DATE("creation date");
 
-static const std::string C_COMMENT("comment");
+const std::string C_COMMENT("comment");
 
-static const std::string C_COMMENT_UTF8("comment.utf-8");
+const std::string C_COMMENT_UTF8("comment.utf-8");
 
-static const std::string C_CREATED_BY("created by");
+const std::string C_CREATED_BY("created by");
 
-static const std::string DEFAULT_PEER_ID_PREFIX("aria2-");
+const std::string DEFAULT_PEER_ID_PREFIX("aria2-");
+} // namespace
 
 const std::string BITTORRENT("bittorrent");
 
@@ -106,10 +110,11 @@ const std::string MULTI("multi");
 
 const std::string SINGLE("single");
 
-static void extractPieceHash(const SharedHandle<DownloadContext>& ctx,
-                             const std::string& hashData,
-                             size_t hashLength,
-                             size_t numPieces)
+namespace {
+void extractPieceHash(const SharedHandle<DownloadContext>& ctx,
+                      const std::string& hashData,
+                      size_t hashLength,
+                      size_t numPieces)
 {
   std::vector<std::string> pieceHashes;
   pieceHashes.reserve(numPieces);
@@ -118,10 +123,12 @@ static void extractPieceHash(const SharedHandle<DownloadContext>& ctx,
                                       hashLength));
   }
   ctx->setPieceHashes(pieceHashes.begin(), pieceHashes.end());
-  ctx->setPieceHashAlgo(MessageDigestContext::SHA1);
+  ctx->setPieceHashAlgo("sha-1");
 }
+} // namespace
 
-static void extractUrlList
+namespace {
+void extractUrlList
 (const SharedHandle<TorrentAttribute>& torrent, std::vector<std::string>& uris,
  const ValueBase* v)
 {
@@ -162,9 +169,11 @@ static void extractUrlList
     v->accept(visitor);
   }
 }
+} // namespace
 
+namespace {
 template<typename InputIterator, typename OutputIterator>
-static OutputIterator createUri
+OutputIterator createUri
 (InputIterator first, InputIterator last, OutputIterator out,
  const std::string& filePath)
 {
@@ -177,11 +186,14 @@ static OutputIterator createUri
   }
   return out;
 }
+} // namespace
 
-static void extractFileEntries
+namespace {
+void extractFileEntries
 (const SharedHandle<DownloadContext>& ctx,
  const SharedHandle<TorrentAttribute>& torrent,
  const Dict* infoDict,
+ const SharedHandle<Option>& option,
  const std::string& defaultName,
  const std::string& overrideName,
  const std::vector<std::string>& urlList)
@@ -199,9 +211,10 @@ static void extractFileEntries
     if(nameData) {
       utf8Name = util::encodeNonUtf8(nameData->s());
       if(util::detectDirTraversal(utf8Name)) {
-        throw DL_ABORT_EX
-          (StringFormat
-           (MSG_DIR_TRAVERSAL_DETECTED,nameData->s().c_str()).str());
+        throw DL_ABORT_EX2
+          (fmt(MSG_DIR_TRAVERSAL_DETECTED,
+               nameData->s().c_str()),
+           error_code::BITTORRENT_PARSE_ERROR);
       }
       name = nameData->s();
     } else {
@@ -227,8 +240,8 @@ static void extractFileEntries
       }
       const Integer* fileLengthData = asInteger(fileDict->get(C_LENGTH));
       if(!fileLengthData) {
-        throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-                                       C_LENGTH.c_str()).str());
+        throw DL_ABORT_EX2(fmt(MSG_MISSING_BT_INFO, C_LENGTH.c_str()),
+                           error_code::BITTORRENT_PARSE_ERROR);
       }
       length += fileLengthData->i();
 
@@ -240,7 +253,8 @@ static void extractFileEntries
       }
       const List* pathList = asList(fileDict->get(pathKey));
       if(!pathList || pathList->empty()) {
-        throw DL_ABORT_EX("Path is empty.");
+        throw DL_ABORT_EX2("Path is empty.",
+                           error_code::BITTORRENT_PARSE_ERROR);
       }
       
       std::vector<std::string> pathelem(pathList->size()+1);
@@ -253,15 +267,16 @@ static void extractFileEntries
         if(elem) {
           (*pathelemOutItr++) = elem->s();
         } else {
-          throw DL_ABORT_EX("Path element is not string.");
+          throw DL_ABORT_EX2("Path element is not string.",
+                             error_code::BITTORRENT_PARSE_ERROR);
         }
       }
       std::string path = strjoin(pathelem.begin(), pathelem.end(), '/');
       std::string utf8Path = strjoin(pathelem.begin(), pathelem.end(), '/',
                                      std::ptr_fun(util::encodeNonUtf8));
       if(util::detectDirTraversal(utf8Path)) {
-        throw DL_ABORT_EX
-          (StringFormat(MSG_DIR_TRAVERSAL_DETECTED, utf8Path.c_str()).str());
+        throw DL_ABORT_EX2(fmt(MSG_DIR_TRAVERSAL_DETECTED, utf8Path.c_str()),
+                           error_code::BITTORRENT_PARSE_ERROR);
       }
       std::string pePath =
         strjoin(pathelem.begin(), pathelem.end(), '/',
@@ -270,7 +285,8 @@ static void extractFileEntries
       std::vector<std::string> uris;
       createUri(urlList.begin(), urlList.end(),std::back_inserter(uris),pePath);
       SharedHandle<FileEntry> fileEntry
-        (new FileEntry(util::applyDir(ctx->getDir(),util::escapePath(utf8Path)),
+        (new FileEntry(util::applyDir(option->get(PREF_DIR),
+                                      util::escapePath(utf8Path)),
                        fileLengthData->i(), offset, uris));
       fileEntry->setOriginalName(path);
       fileEntries.push_back(fileEntry);
@@ -281,8 +297,8 @@ static void extractFileEntries
     torrent->mode = SINGLE;
     const Integer* lengthData = asInteger(infoDict->get(C_LENGTH));
     if(!lengthData) {
-      throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-                                     C_LENGTH.c_str()).str());      
+      throw DL_ABORT_EX2(fmt(MSG_MISSING_BT_INFO, C_LENGTH.c_str()),
+                         error_code::BITTORRENT_PARSE_ERROR);
     }
     uint64_t totalLength = lengthData->i();
 
@@ -298,18 +314,21 @@ static void extractFileEntries
       }
     }
     SharedHandle<FileEntry> fileEntry
-      (new FileEntry(util::applyDir(ctx->getDir(), util::escapePath(utf8Name)),
+      (new FileEntry(util::applyDir(option->get(PREF_DIR),
+                                    util::escapePath(utf8Name)),
                      totalLength, 0, uris));
     fileEntry->setOriginalName(name);
     fileEntries.push_back(fileEntry);
   }
   ctx->setFileEntries(fileEntries.begin(), fileEntries.end());
   if(torrent->mode == MULTI) {
-    ctx->setBasePath(util::applyDir(ctx->getDir(), utf8Name));
+    ctx->setBasePath(util::applyDir(option->get(PREF_DIR), utf8Name));
   }
 }
+} // namespace
 
-static void extractAnnounce
+namespace {
+void extractAnnounce
 (const SharedHandle<TorrentAttribute>& torrent, const Dict* rootDict)
 {
   const List* announceList = asList(rootDict->get(C_ANNOUNCE_LIST));
@@ -341,8 +360,10 @@ static void extractAnnounce
     }
   }
 }
+} // namespace
 
-static void extractNodes
+namespace {
+void extractNodes
 (const SharedHandle<TorrentAttribute>& torrent, const ValueBase* nodesListSrc)
 {
   const List* nodesList = asList(nodesListSrc);
@@ -368,22 +389,26 @@ static void extractNodes
     }
   }
 }
+} // namespace
 
-static void processRootDictionary
+namespace {
+void processRootDictionary
 (const SharedHandle<DownloadContext>& ctx,
  const SharedHandle<ValueBase>& root,
+ const SharedHandle<Option>& option,
  const std::string& defaultName,
  const std::string& overrideName,
  const std::vector<std::string>& uris)
 {
   const Dict* rootDict = asDict(root);
   if(!rootDict) {
-    throw DL_ABORT_EX("torrent file does not contain a root dictionary.");
+    throw DL_ABORT_EX2("torrent file does not contain a root dictionary.",
+                       error_code::BITTORRENT_PARSE_ERROR);
   }
   const Dict* infoDict = asDict(rootDict->get(C_INFO));
   if(!infoDict) {
-    throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-                                   C_INFO.c_str()).str());
+    throw DL_ABORT_EX2(fmt(MSG_MISSING_BT_INFO, C_INFO.c_str()),
+                       error_code::BITTORRENT_PARSE_ERROR);
   }
   SharedHandle<TorrentAttribute> torrent(new TorrentAttribute());
 
@@ -391,7 +416,7 @@ static void processRootDictionary
   std::string encodedInfoDict = bencode2::encode(infoDict);
   unsigned char infoHash[INFO_HASH_LENGTH];
   MessageDigestHelper::digest(infoHash, INFO_HASH_LENGTH,
-                              MessageDigestContext::SHA1,
+                              MessageDigest::sha1(),
                               encodedInfoDict.data(),
                               encodedInfoDict.size());
   torrent->infoHash = std::string(&infoHash[0], &infoHash[INFO_HASH_LENGTH]);
@@ -401,8 +426,8 @@ static void processRootDictionary
   // calculate the number of pieces
   const String* piecesData = asString(infoDict->get(C_PIECES));
   if(!piecesData) {
-    throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-                                   C_PIECES.c_str()).str());
+    throw DL_ABORT_EX2(fmt(MSG_MISSING_BT_INFO, C_PIECES.c_str()),
+                       error_code::BITTORRENT_PARSE_ERROR);
   }
   // Commented out To download 0 length torrent.
   //   if(piecesData.s().empty()) {
@@ -416,8 +441,8 @@ static void processRootDictionary
   // retrieve piece length
   const Integer* pieceLengthData = asInteger(infoDict->get(C_PIECE_LENGTH));
   if(!pieceLengthData) {
-    throw DL_ABORT_EX(StringFormat(MSG_MISSING_BT_INFO,
-                                   C_PIECE_LENGTH.c_str()).str());
+    throw DL_ABORT_EX2(fmt(MSG_MISSING_BT_INFO, C_PIECE_LENGTH.c_str()),
+                       error_code::BITTORRENT_PARSE_ERROR);
   }
   size_t pieceLength = pieceLengthData->i();
   ctx->setPieceLength(pieceLength);
@@ -445,9 +470,10 @@ static void processRootDictionary
 
   // retrieve file entries
   extractFileEntries
-    (ctx, torrent, infoDict, defaultName, overrideName, urlList);
+    (ctx, torrent, infoDict, option, defaultName, overrideName, urlList);
   if((ctx->getTotalLength()+pieceLength-1)/pieceLength != numPieces) {
-    throw DL_ABORT_EX("Too few/many piece hash.");
+    throw DL_ABORT_EX2("Too few/many piece hash.",
+                       error_code::BITTORRENT_PARSE_ERROR);
   }
   // retrieve announce
   extractAnnounce(torrent, rootDict);
@@ -474,13 +500,16 @@ static void processRootDictionary
 
   ctx->setAttribute(BITTORRENT, torrent);
 }
+} // namespace
 
 void load(const std::string& torrentFile,
           const SharedHandle<DownloadContext>& ctx,
+          const SharedHandle<Option>& option,
           const std::string& overrideName)
 {
   processRootDictionary(ctx,
                         bencode2::decodeFromFile(torrentFile),
+                        option,
                         torrentFile,
                         overrideName,
                         std::vector<std::string>());
@@ -488,11 +517,13 @@ void load(const std::string& torrentFile,
 
 void load(const std::string& torrentFile,
           const SharedHandle<DownloadContext>& ctx,
+          const SharedHandle<Option>& option,
           const std::vector<std::string>& uris,
           const std::string& overrideName)
 {
   processRootDictionary(ctx,
                         bencode2::decodeFromFile(torrentFile),
+                        option,
                         torrentFile,
                         overrideName,
                         uris);
@@ -501,11 +532,13 @@ void load(const std::string& torrentFile,
 void loadFromMemory(const unsigned char* content,
                     size_t length,
                     const SharedHandle<DownloadContext>& ctx,
+                    const SharedHandle<Option>& option,
                     const std::string& defaultName,
                     const std::string& overrideName)
 {
   processRootDictionary(ctx,
                         bencode2::decode(content, length),
+                        option,
                         defaultName,
                         overrideName,
                         std::vector<std::string>());
@@ -514,12 +547,14 @@ void loadFromMemory(const unsigned char* content,
 void loadFromMemory(const unsigned char* content,
                     size_t length,
                     const SharedHandle<DownloadContext>& ctx,
+                    const SharedHandle<Option>& option,
                     const std::vector<std::string>& uris,
                     const std::string& defaultName,
                     const std::string& overrideName)
 {
   processRootDictionary(ctx,
                         bencode2::decode(content, length),
+                        option,
                         defaultName,
                         overrideName,
                         uris);
@@ -527,18 +562,21 @@ void loadFromMemory(const unsigned char* content,
 
 void loadFromMemory(const std::string& context,
                     const SharedHandle<DownloadContext>& ctx,
+                    const SharedHandle<Option>& option,
                     const std::string& defaultName,
                     const std::string& overrideName)
 {
   processRootDictionary
     (ctx,
      bencode2::decode(context),
+     option,
      defaultName, overrideName,
      std::vector<std::string>());
 }
 
 void loadFromMemory(const std::string& context,
                     const SharedHandle<DownloadContext>& ctx,
+                    const SharedHandle<Option>& option,
                     const std::vector<std::string>& uris,
                     const std::string& defaultName,
                     const std::string& overrideName)
@@ -546,6 +584,7 @@ void loadFromMemory(const std::string& context,
   processRootDictionary
     (ctx,
      bencode2::decode(context),
+     option,
      defaultName, overrideName,
      uris);
 }
@@ -639,7 +678,8 @@ void computeFastSet
   }
   memcpy(tx+4, infoHash, 20);
   unsigned char x[20];
-  MessageDigestHelper::digest(x, sizeof(x), MessageDigestContext::SHA1, tx, 24);
+  SharedHandle<MessageDigest> sha1 = MessageDigest::sha1();
+  MessageDigestHelper::digest(x, sizeof(x), sha1, tx, 24);
   while(fastSet.size() < fastSetSize) {
     for(size_t i = 0; i < 5 && fastSet.size() < fastSetSize; ++i) {
       size_t j = i*4;
@@ -652,7 +692,8 @@ void computeFastSet
       }
     }
     unsigned char temp[20];
-    MessageDigestHelper::digest(temp, sizeof(temp), MessageDigestContext::SHA1, x, sizeof(x));
+    sha1->reset();
+    MessageDigestHelper::digest(temp, sizeof(temp), sha1, x, sizeof(x));
     memcpy(x, temp, sizeof(x));
   }
 }
@@ -671,7 +712,9 @@ std::string generatePeerId(const std::string& peerIdPrefix)
   return peerId;
 }
 
-static std::string peerId;
+namespace {
+std::string peerId;
+} // namespace
 
 const std::string& generateStaticPeerId(const std::string& peerIdPrefix)
 {
@@ -721,15 +764,15 @@ uint16_t getShortIntParam(const unsigned char* msg, size_t pos)
 void checkIndex(size_t index, size_t pieces)
 {
   if(!(index < pieces)) {
-    throw DL_ABORT_EX(StringFormat("Invalid index: %lu",
-                                   static_cast<unsigned long>(index)).str());
+    throw DL_ABORT_EX(fmt("Invalid index: %lu",
+                          static_cast<unsigned long>(index)));
   }
 }
 
 void checkBegin(uint32_t begin, size_t pieceLength)
 {
   if(!(begin < pieceLength)) {
-    throw DL_ABORT_EX(StringFormat("Invalid begin: %u", begin).str());
+    throw DL_ABORT_EX(fmt("Invalid begin: %u", begin));
   }  
 }
 
@@ -737,14 +780,14 @@ void checkLength(size_t length)
 {
   if(length > MAX_BLOCK_LENGTH) {
     throw DL_ABORT_EX
-      (StringFormat("Length too long: %lu > %uKB",
-                    static_cast<unsigned long>(length),
-                    MAX_BLOCK_LENGTH/1024).str());
+      (fmt("Length too long: %lu > %uKB",
+           static_cast<unsigned long>(length),
+           MAX_BLOCK_LENGTH/1024));
   }
   if(length == 0) {
     throw DL_ABORT_EX
-      (StringFormat("Invalid length: %lu",
-                    static_cast<unsigned long>(length)).str());
+      (fmt("Invalid length: %lu",
+           static_cast<unsigned long>(length)));
   }
 }
 
@@ -752,16 +795,16 @@ void checkRange(uint32_t begin, size_t length, size_t pieceLength)
 {
   if(!(0 < length)) {
     throw DL_ABORT_EX
-      (StringFormat("Invalid range: begin=%u, length=%lu",
-                    begin,
-                    static_cast<unsigned long>(length)).str());
+      (fmt("Invalid range: begin=%u, length=%lu",
+           begin,
+           static_cast<unsigned long>(length)));
   }
   uint32_t end = begin+length;
   if(!(end <= pieceLength)) {
     throw DL_ABORT_EX
-      (StringFormat("Invalid range: begin=%u, length=%lu",
-                    begin,
-                    static_cast<unsigned long>(length)).str());
+      (fmt("Invalid range: begin=%u, length=%lu",
+           begin,
+           static_cast<unsigned long>(length)));
   }
 }
 
@@ -770,8 +813,8 @@ void checkBitfield
 {
   if(!(bitfieldLength == (pieces+7)/8)) {
     throw DL_ABORT_EX
-      (StringFormat("Invalid bitfield length: %lu",
-                    static_cast<unsigned long>(bitfieldLength)).str());
+      (fmt("Invalid bitfield length: %lu",
+           static_cast<unsigned long>(bitfieldLength)));
   }
   // Check if last byte contains garbage set bit.
   if(bitfield[bitfieldLength-1]&~bitfield::lastByteMask(pieces)) {
@@ -862,7 +905,8 @@ void assertPayloadLengthGreater
 {
   if(actual <= threshold) {
     throw DL_ABORT_EX
-      (StringFormat(MSG_TOO_SMALL_PAYLOAD_SIZE, msgName.c_str(), actual).str());
+      (fmt(MSG_TOO_SMALL_PAYLOAD_SIZE, msgName.c_str(),
+           static_cast<unsigned long>(actual)));
   }
 }
 
@@ -871,8 +915,9 @@ void assertPayloadLengthEqual
 {
   if(expected != actual) {
     throw DL_ABORT_EX
-      (StringFormat(EX_INVALID_PAYLOAD_SIZE, msgName.c_str(),
-                    actual, expected).str());
+      (fmt(EX_INVALID_PAYLOAD_SIZE, msgName.c_str(),
+           static_cast<unsigned long>(actual),
+           static_cast<unsigned long>(expected)));
   }
 }
 
@@ -882,20 +927,22 @@ void assertID
   uint8_t id = getId(data);
   if(expected != id) {
     throw DL_ABORT_EX
-      (StringFormat(EX_INVALID_BT_MESSAGE_ID, id, msgName.c_str(),
-                    expected).str());
+      (fmt(EX_INVALID_BT_MESSAGE_ID, id, msgName.c_str(),
+           expected));
   }
 }
 
 SharedHandle<TorrentAttribute> parseMagnet(const std::string& magnet)
 {
   SharedHandle<Dict> r = magnet::parse(magnet);
-  if(r.isNull()) {
-    throw DL_ABORT_EX("Bad BitTorrent Magnet URI.");
+  if(!r) {
+    throw DL_ABORT_EX2("Bad BitTorrent Magnet URI.",
+                       error_code::MAGNET_PARSE_ERROR);
   }
   const List* xts = asList(r->get("xt"));
   if(!xts) {
-    throw DL_ABORT_EX("Missing xt parameter in Magnet URI.");
+    throw DL_ABORT_EX2("Missing xt parameter in Magnet URI.",
+                       error_code::MAGNET_PARSE_ERROR);
   }
   SharedHandle<TorrentAttribute> attrs(new TorrentAttribute());
   std::string infoHash;
@@ -919,8 +966,9 @@ SharedHandle<TorrentAttribute> parseMagnet(const std::string& magnet)
     }
   }
   if(infoHash.empty()) {
-    throw DL_ABORT_EX("Bad BitTorrent Magnet URI. "
-                      "No valid BitTorrent Info Hash found.");
+    throw DL_ABORT_EX2("Bad BitTorrent Magnet URI. "
+                       "No valid BitTorrent Info Hash found.",
+                       error_code::MAGNET_PARSE_ERROR);
   }
   const List* trs = asList(r->get("tr"));
   if(trs) {
