@@ -51,7 +51,7 @@
 #include "RecoverableException.h"
 #include "DlAbortEx.h"
 #include "message.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "FileEntry.h"
 #include "LogFactory.h"
 #include "File.h"
@@ -172,7 +172,8 @@ const std::set<std::string>& listRequestOptions()
   return requestOptions;
 }
 
-static void unfoldURI
+namespace {
+void unfoldURI
 (std::vector<std::string>& result, const std::vector<std::string>& args)
 {
   ParameterizedStringParser p;
@@ -184,13 +185,15 @@ static void unfoldURI
     result.insert(result.end(), v.getURIs().begin(), v.getURIs().end()); 
   }
 }
+} // namespace
 
+namespace {
 template<typename InputIterator>
-static void splitURI(std::vector<std::string>& result,
-                     InputIterator begin,
-                     InputIterator end,
-                     size_t numSplit,
-                     size_t maxIter)
+void splitURI(std::vector<std::string>& result,
+              InputIterator begin,
+              InputIterator end,
+              size_t numSplit,
+              size_t maxIter)
 {
   size_t numURIs = std::distance(begin, end);
   if(numURIs >= numSplit) {
@@ -205,8 +208,10 @@ static void splitURI(std::vector<std::string>& result,
     }
   }
 }
+} // namespace
 
-static SharedHandle<RequestGroup> createRequestGroup
+namespace {
+SharedHandle<RequestGroup> createRequestGroup
 (const SharedHandle<Option>& option, const std::vector<std::string>& uris,
  bool useOutOption = false)
 {
@@ -217,27 +222,33 @@ static SharedHandle<RequestGroup> createRequestGroup
       0,
       useOutOption&&!option->blank(PREF_OUT)?
       util::applyDir(option->get(PREF_DIR), option->get(PREF_OUT)):A2STR::NIL));
-  dctx->setDir(option->get(PREF_DIR));
   dctx->getFirstFileEntry()->setUris(uris);
   dctx->getFirstFileEntry()->setMaxConnectionPerServer
     (option->getAsInt(PREF_MAX_CONNECTION_PER_SERVER));
   rg->setDownloadContext(dctx);
   return rg;
 }
+} // namespace
 
-static SharedHandle<MetadataInfo> createMetadataInfo(const std::string& uri)
+#if defined ENABLE_BITTORRENT || ENABLE_METALINK
+namespace {
+SharedHandle<MetadataInfo> createMetadataInfo(const std::string& uri)
 {
   return SharedHandle<MetadataInfo>(new MetadataInfo(uri));
 }
+} // namespace
 
-static SharedHandle<MetadataInfo> createMetadataInfoDataOnly()
+namespace {
+SharedHandle<MetadataInfo> createMetadataInfoDataOnly()
 {
   return SharedHandle<MetadataInfo>(new MetadataInfo());
 }
+} // namespace
+#endif // ENABLE_BITTORRENT || ENABLE_METALINK
 
 #ifdef ENABLE_BITTORRENT
 
-static
+namespace {
 SharedHandle<RequestGroup>
 createBtRequestGroup(const std::string& torrentFilePath,
                      const SharedHandle<Option>& option,
@@ -247,14 +258,13 @@ createBtRequestGroup(const std::string& torrentFilePath,
 {
   SharedHandle<RequestGroup> rg(new RequestGroup(option));
   SharedHandle<DownloadContext> dctx(new DownloadContext());
-  dctx->setDir(option->get(PREF_DIR));
   if(torrentData.empty()) {
-    bittorrent::load(torrentFilePath, dctx, auxUris);// may throw exception
+    // may throw exception
+    bittorrent::load(torrentFilePath, dctx, option, auxUris);
     rg->setMetadataInfo(createMetadataInfo(torrentFilePath));
   } else {
-    bittorrent::loadFromMemory(torrentData, dctx, auxUris, "default"); // may
-    // throw
-    // exception
+    // may throw exception
+    bittorrent::loadFromMemory(torrentData, dctx, option, auxUris, "default");
     rg->setMetadataInfo(createMetadataInfoDataOnly());
   }
   if(adjustAnnounceUri) {
@@ -267,7 +277,7 @@ createBtRequestGroup(const std::string& torrentFilePath,
   for(std::map<size_t, std::string>::const_iterator i = indexPathMap.begin(),
         eoi = indexPathMap.end(); i != eoi; ++i) {
     dctx->setFilePathWithIndex
-      ((*i).first, util::applyDir(dctx->getDir(), (*i).second));
+      ((*i).first, util::applyDir(option->get(PREF_DIR), (*i).second));
   }
   rg->setDownloadContext(dctx);
   // Remove "metalink" from Accept Type list to avoid server from
@@ -275,18 +285,17 @@ createBtRequestGroup(const std::string& torrentFilePath,
   util::removeMetalinkContentTypes(rg);
   return rg;
 }
+} // namespace
 
-static
+namespace {
 SharedHandle<RequestGroup>
 createBtMagnetRequestGroup(const std::string& magnetLink,
-                           const SharedHandle<Option>& option,
-                           const std::vector<std::string>& auxUris)
+                           const SharedHandle<Option>& option)
 {
   SharedHandle<RequestGroup> rg(new RequestGroup(option));
   SharedHandle<DownloadContext> dctx
     (new DownloadContext(METADATA_PIECE_SIZE, 0,
                          A2STR::NIL));
-  dctx->setDir(A2STR::NIL);
   // We only know info hash. Total Length is unknown at this moment.
   dctx->markTotalLengthIsUnknown();
   rg->setFileAllocationEnabled(false);
@@ -298,14 +307,16 @@ createBtMagnetRequestGroup(const std::string& magnetLink,
   dctx->getFirstFileEntry()->setPath(torrentAttrs->name);
   rg->setDownloadContext(dctx);
   rg->clearPostDownloadHandler();
-  rg->addPostDownloadHandler
-    (SharedHandle<UTMetadataPostDownloadHandler>
-     (new UTMetadataPostDownloadHandler()));
+  SharedHandle<UTMetadataPostDownloadHandler> utMetadataPostHandler
+    (new UTMetadataPostDownloadHandler());
+  rg->addPostDownloadHandler(utMetadataPostHandler);
   rg->setDiskWriterFactory
     (SharedHandle<DiskWriterFactory>(new ByteArrayDiskWriterFactory()));
   rg->setMetadataInfo(createMetadataInfo(magnetLink));
+  rg->markInMemoryDownload();
   return rg;
 }
+} // namespace
 
 void createRequestGroupForBitTorrent
 (std::vector<SharedHandle<RequestGroup> >& result,
@@ -315,7 +326,7 @@ void createRequestGroupForBitTorrent
  bool adjustAnnounceUri)
 {
   std::vector<std::string> nargs;
-  if(option->get(PREF_PARAMETERIZED_URI) == V_TRUE) {
+  if(option->get(PREF_PARAMETERIZED_URI) == A2_V_TRUE) {
     unfoldURI(nargs, uris);
   } else {
     nargs = uris;
@@ -349,18 +360,23 @@ void createRequestGroupForMetalink
 }
 #endif // ENABLE_METALINK
 
+namespace {
 class AccRequestGroup {
 private:
   std::vector<SharedHandle<RequestGroup> >& requestGroups_;
   ProtocolDetector detector_;
   SharedHandle<Option> option_;
   bool ignoreLocalPath_;
+  bool throwOnError_;
 public:
   AccRequestGroup(std::vector<SharedHandle<RequestGroup> >& requestGroups,
                   const SharedHandle<Option>& option,
-                  bool ignoreLocalPath = false):
+                  bool ignoreLocalPath = false,
+                  bool throwOnError = false):
     requestGroups_(requestGroups), option_(option),
-    ignoreLocalPath_(ignoreLocalPath) {}
+    ignoreLocalPath_(ignoreLocalPath),
+    throwOnError_(throwOnError)
+  {}
 
   void
   operator()(const std::string& uri)
@@ -379,23 +395,21 @@ public:
     }
 #ifdef ENABLE_BITTORRENT
     else if(detector_.guessTorrentMagnet(uri)) {
-      try {
-        SharedHandle<RequestGroup> group =
-          createBtMagnetRequestGroup(uri, option_, std::vector<std::string>());
-        requestGroups_.push_back(group);
-      } catch(RecoverableException& e) {
-        // error occurred while parsing torrent file.
-        // We simply ignore it. 
-        LogFactory::getInstance()->error(EX_EXCEPTION_CAUGHT, e);
-      }
+      SharedHandle<RequestGroup> group =
+        createBtMagnetRequestGroup(uri, option_);
+      requestGroups_.push_back(group);
     } else if(!ignoreLocalPath_ && detector_.guessTorrentFile(uri)) {
       try {
         requestGroups_.push_back
           (createBtRequestGroup(uri, option_, std::vector<std::string>()));
       } catch(RecoverableException& e) {
-        // error occurred while parsing torrent file.
-        // We simply ignore it. 
-        LogFactory::getInstance()->error(EX_EXCEPTION_CAUGHT, e);
+        if(throwOnError_) {
+          throw;
+        } else {
+          // error occurred while parsing torrent file.
+          // We simply ignore it.
+          A2_LOG_ERROR_EX(EX_EXCEPTION_CAUGHT, e);
+        }
       }
     } 
 #endif // ENABLE_BITTORRENT
@@ -404,18 +418,28 @@ public:
       try {
         Metalink2RequestGroup().generate(requestGroups_, uri, option_);
       } catch(RecoverableException& e) {
-        // error occurred while parsing metalink file.
-        // We simply ignore it.
-        LogFactory::getInstance()->error(EX_EXCEPTION_CAUGHT, e);
+        if(throwOnError_) {
+          throw;
+        } else {
+          // error occurred while parsing metalink file.
+          // We simply ignore it.
+          A2_LOG_ERROR_EX(EX_EXCEPTION_CAUGHT, e);
+        }
       }
     }
 #endif // ENABLE_METALINK
     else {
-      LogFactory::getInstance()->error(MSG_UNRECOGNIZED_URI, (uri).c_str());
+      if(throwOnError_) {
+        throw DL_ABORT_EX(fmt(MSG_UNRECOGNIZED_URI, uri.c_str()));
+      } else {
+        A2_LOG_ERROR(fmt(MSG_UNRECOGNIZED_URI, uri.c_str()));
+      }
     }
   }
 };
+} // namespace
 
+namespace {
 class StreamProtocolFilter {
 private:
   ProtocolDetector detector_;
@@ -424,23 +448,26 @@ public:
     return detector_.isStreamProtocol(uri);
   }
 };
+} // namespace
 
 void createRequestGroupForUri
 (std::vector<SharedHandle<RequestGroup> >& result,
  const SharedHandle<Option>& option,
  const std::vector<std::string>& uris,
  bool ignoreForceSequential,
- bool ignoreLocalPath)
+ bool ignoreLocalPath,
+ bool throwOnError)
 {
   std::vector<std::string> nargs;
-  if(option->get(PREF_PARAMETERIZED_URI) == V_TRUE) {
+  if(option->get(PREF_PARAMETERIZED_URI) == A2_V_TRUE) {
     unfoldURI(nargs, uris);
   } else {
     nargs = uris;
   }
-  if(!ignoreForceSequential && option->get(PREF_FORCE_SEQUENTIAL) == V_TRUE) {
+  if(!ignoreForceSequential && option->get(PREF_FORCE_SEQUENTIAL) == A2_V_TRUE) {
     std::for_each(nargs.begin(), nargs.end(),
-                  AccRequestGroup(result, option, ignoreLocalPath));
+                  AccRequestGroup(result, option, ignoreLocalPath,
+                                  throwOnError));
   } else {
     std::vector<std::string>::iterator strmProtoEnd =
       std::stable_partition(nargs.begin(), nargs.end(), StreamProtocolFilter());
@@ -457,11 +484,13 @@ void createRequestGroupForUri
     }
     // process remaining URIs(local metalink, BitTorrent files)
     std::for_each(strmProtoEnd, nargs.end(),
-                  AccRequestGroup(result, option, ignoreLocalPath));
+                  AccRequestGroup(result, option, ignoreLocalPath,
+                                  throwOnError));
   }
 }
 
-static void createRequestGroupForUriList
+namespace {
+void createRequestGroupForUriList
 (std::vector<SharedHandle<RequestGroup> >& result,
  const SharedHandle<Option>& option,
  std::istream& in)
@@ -487,6 +516,7 @@ static void createRequestGroupForUriList
     createRequestGroupForUri(result, requestOption, uris);
   }
 }
+} // namespace
 
 void createRequestGroupForUriList
 (std::vector<SharedHandle<RequestGroup> >& result,
@@ -497,8 +527,8 @@ void createRequestGroupForUriList
   } else {
     if(!File(option->get(PREF_INPUT_FILE)).isFile()) {
       throw DL_ABORT_EX
-        (StringFormat(EX_FILE_OPEN, option->get(PREF_INPUT_FILE).c_str(),
-                      "No such file").str());
+        (fmt(EX_FILE_OPEN, option->get(PREF_INPUT_FILE).c_str(),
+             "No such file"));
     }
     std::ifstream f(option->get(PREF_INPUT_FILE).c_str(), std::ios::binary);
     createRequestGroupForUriList(result, option, f);
