@@ -22,7 +22,7 @@ class BtPieceMessageTest:public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(BtPieceMessageTest);
   CPPUNIT_TEST(testCreate);
-  CPPUNIT_TEST(testGetMessageHeader);
+  CPPUNIT_TEST(testCreateMessageHeader);
   CPPUNIT_TEST(testChokingEvent);
   CPPUNIT_TEST(testChokingEvent_allowedFastEnabled);
   CPPUNIT_TEST(testChokingEvent_inAmAllowedIndexSet);
@@ -38,7 +38,7 @@ class BtPieceMessageTest:public CppUnit::TestFixture {
   CPPUNIT_TEST_SUITE_END();
 public:
   void testCreate();
-  void testGetMessageHeader();
+  void testCreateMessageHeader();
   void testChokingEvent();
   void testChokingEvent_allowedFastEnabled();
   void testChokingEvent_inAmAllowedIndexSet();
@@ -65,37 +65,37 @@ public:
   public:
     virtual SharedHandle<BtMessage>
     createRejectMessage(size_t index,
-			uint32_t begin,
-			size_t length) {
+                        uint32_t begin,
+                        size_t length) {
       SharedHandle<MockBtMessage2> msg(new MockBtMessage2(index, begin, length));
       return msg;
     }
   };
 
-  SharedHandle<DownloadContext> _dctx;
+  SharedHandle<DownloadContext> dctx_;
   SharedHandle<MockBtMessageDispatcher> btMessageDispatcher;
-  SharedHandle<MockBtMessageFactory> _btMessageFactory;
+  SharedHandle<MockBtMessageFactory> btMessageFactory_;
   SharedHandle<Peer> peer;
   SharedHandle<BtPieceMessage> msg;
 
   void setUp() {
-    _dctx.reset(new DownloadContext(16*1024, 256*1024, "/path/to/file"));
+    dctx_.reset(new DownloadContext(16*1024, 256*1024, "/path/to/file"));
 
     peer.reset(new Peer("host", 6969));
-    peer->allocateSessionResource(_dctx->getPieceLength(),
-				  _dctx->getTotalLength());
+    peer->allocateSessionResource(dctx_->getPieceLength(),
+                                  dctx_->getTotalLength());
 
     btMessageDispatcher.reset(new MockBtMessageDispatcher());
-    _btMessageFactory.reset(new MockBtMessageFactory2());
+    btMessageFactory_.reset(new MockBtMessageFactory2());
 
     msg.reset(new BtPieceMessage());
     msg->setIndex(1);
     msg->setBegin(1024);
     msg->setBlockLength(16*1024);
-    msg->setDownloadContext(_dctx);
+    msg->setDownloadContext(dctx_);
     msg->setPeer(peer);
-    msg->setBtMessageDispatcher(btMessageDispatcher);
-    msg->setBtMessageFactory(_btMessageFactory);
+    msg->setBtMessageDispatcher(btMessageDispatcher.get());
+    msg->setBtMessageFactory(btMessageFactory_.get());
   }
 };
 
@@ -114,7 +114,6 @@ void BtPieceMessageTest::testCreate() {
   CPPUNIT_ASSERT_EQUAL((uint8_t)7, pm->getId());
   CPPUNIT_ASSERT_EQUAL((size_t)12345, pm->getIndex());
   CPPUNIT_ASSERT_EQUAL((uint32_t)256, pm->getBegin());
-  CPPUNIT_ASSERT(memcmp(data, pm->getBlock(), sizeof(data)) == 0);
   CPPUNIT_ASSERT_EQUAL((size_t)2, pm->getBlockLength());
 
   // case: payload size is wrong
@@ -135,7 +134,7 @@ void BtPieceMessageTest::testCreate() {
   }
 }
 
-void BtPieceMessageTest::testGetMessageHeader() {
+void BtPieceMessageTest::testCreateMessageHeader() {
   BtPieceMessage msg;
   msg.setIndex(12345);
   msg.setBegin(256);
@@ -144,7 +143,9 @@ void BtPieceMessageTest::testGetMessageHeader() {
   bittorrent::createPeerMessageString(data, sizeof(data), 9+1024, 7);
   bittorrent::setIntParam(&data[5], 12345);
   bittorrent::setIntParam(&data[9], 256);
-  CPPUNIT_ASSERT(memcmp(msg.getMessageHeader(), data, 13) == 0);
+  unsigned char* rawmsg = msg.createMessageHeader();
+  CPPUNIT_ASSERT(memcmp(rawmsg, data, 13) == 0);
+  delete [] rawmsg;
 }
 
 void BtPieceMessageTest::testChokingEvent() {
@@ -171,8 +172,9 @@ void BtPieceMessageTest::testChokingEvent_allowedFastEnabled() {
 
   CPPUNIT_ASSERT(msg->isInvalidate());  
   CPPUNIT_ASSERT_EQUAL((size_t)1, btMessageDispatcher->messageQueue.size());
-  MockBtMessage2* rej =
-    (MockBtMessage2*)btMessageDispatcher->messageQueue.front().get();
+  SharedHandle<MockBtMessage2> rej =
+    dynamic_pointer_cast<MockBtMessage2>
+    (btMessageDispatcher->messageQueue.front());
   CPPUNIT_ASSERT_EQUAL((size_t)1, rej->index);
   CPPUNIT_ASSERT_EQUAL((uint32_t)1024, rej->begin);
   CPPUNIT_ASSERT_EQUAL((size_t)16*1024, rej->length);
@@ -257,8 +259,9 @@ void BtPieceMessageTest::testCancelSendingPieceEvent_allowedFastEnabled() {
 
   CPPUNIT_ASSERT(msg->isInvalidate());
   CPPUNIT_ASSERT_EQUAL((size_t)1, btMessageDispatcher->messageQueue.size());
-  MockBtMessage2* rej = (MockBtMessage2*)btMessageDispatcher->
-    messageQueue.front().get();
+  SharedHandle<MockBtMessage2> rej =
+    dynamic_pointer_cast<MockBtMessage2>
+    (btMessageDispatcher->messageQueue.front());
   CPPUNIT_ASSERT_EQUAL((size_t)1, rej->index);
   CPPUNIT_ASSERT_EQUAL((uint32_t)1024, rej->begin);
   CPPUNIT_ASSERT_EQUAL((size_t)16*1024, rej->length);
@@ -290,7 +293,7 @@ void BtPieceMessageTest::testCancelSendingPieceEvent_sendingInProgress() {
 
 void BtPieceMessageTest::testToString() {
   CPPUNIT_ASSERT_EQUAL(std::string("piece index=1, begin=1024, length=16384"),
-		       msg->toString());
+                       msg->toString());
 }
 
 } // namespace aria2
