@@ -107,14 +107,14 @@ void BtPortMessageTest::testDoReceivedAction()
 
   // 9 nodes to create at least 2 buckets.
   SharedHandle<DHTNode> nodes[9];
-  for(size_t i = 0; i < arrayLength(nodes); ++i) {
+  for(size_t i = 0; i < A2_ARRAY_LEN(nodes); ++i) {
     memset(nodeID, 0, DHT_ID_LENGTH);
     nodeID[DHT_ID_LENGTH-1] = i+1;
     nodes[i].reset(new DHTNode(nodeID));
   }
 
   DHTRoutingTable routingTable(localNode);
-  for(size_t i = 0; i < arrayLength(nodes); ++i) {
+  for(size_t i = 0; i < A2_ARRAY_LEN(nodes); ++i) {
     routingTable.addNode(nodes[i]);
   }
 
@@ -122,19 +122,19 @@ void BtPortMessageTest::testDoReceivedAction()
   BtPortMessage msg(6881);
   MockDHTTaskQueue taskQueue;
   MockDHTTaskFactory2 taskFactory;
-  msg.setLocalNode(localNode);
-  msg.setRoutingTable(WeakHandle<DHTRoutingTable>(&routingTable));
-  msg.setTaskQueue(WeakHandle<DHTTaskQueue>(&taskQueue));
-  msg.setTaskFactory(WeakHandle<DHTTaskFactory>(&taskFactory));
+  msg.setLocalNode(localNode.get());
+  msg.setRoutingTable(&routingTable);
+  msg.setTaskQueue(&taskQueue);
+  msg.setTaskFactory(&taskFactory);
   msg.setPeer(peer);
 
   msg.doReceivedAction();
 
-  CPPUNIT_ASSERT_EQUAL((size_t)1, taskQueue._immediateTaskQueue.size());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, taskQueue.immediateTaskQueue_.size());
 
   SharedHandle<MockDHTTask> task
-    (dynamic_pointer_cast<MockDHTTask>(taskQueue._immediateTaskQueue[0]));
-  SharedHandle<DHTNode> node = task->_remoteNode;
+    (dynamic_pointer_cast<MockDHTTask>(taskQueue.immediateTaskQueue_[0]));
+  SharedHandle<DHTNode> node = task->remoteNode_;
   CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), node->getIPAddress());
   CPPUNIT_ASSERT_EQUAL((uint16_t)6881, node->getPort());
 }
@@ -151,24 +151,24 @@ void BtPortMessageTest::testDoReceivedAction_bootstrap()
   BtPortMessage msg(6881);
   MockDHTTaskQueue taskQueue;
   MockDHTTaskFactory2 taskFactory;
-  msg.setLocalNode(localNode);
-  msg.setRoutingTable(WeakHandle<DHTRoutingTable>(&routingTable));
-  msg.setTaskQueue(WeakHandle<DHTTaskQueue>(&taskQueue));
-  msg.setTaskFactory(WeakHandle<DHTTaskFactory>(&taskFactory));
+  msg.setLocalNode(localNode.get());
+  msg.setRoutingTable(&routingTable);
+  msg.setTaskQueue(&taskQueue);
+  msg.setTaskFactory(&taskFactory);
   msg.setPeer(peer);
 
   msg.doReceivedAction();
 
-  CPPUNIT_ASSERT_EQUAL((size_t)2, taskQueue._immediateTaskQueue.size());
+  CPPUNIT_ASSERT_EQUAL((size_t)2, taskQueue.immediateTaskQueue_.size());
   SharedHandle<MockDHTTask> task
-    (dynamic_pointer_cast<MockDHTTask>(taskQueue._immediateTaskQueue[0]));
-  SharedHandle<DHTNode> node(task->_remoteNode);
+    (dynamic_pointer_cast<MockDHTTask>(taskQueue.immediateTaskQueue_[0]));
+  SharedHandle<DHTNode> node(task->remoteNode_);
   CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), node->getIPAddress());
   CPPUNIT_ASSERT_EQUAL((uint16_t)6881, node->getPort());
 
   SharedHandle<MockDHTTask> task2
-    (dynamic_pointer_cast<MockDHTTask>(taskQueue._immediateTaskQueue[1]));
-  CPPUNIT_ASSERT(memcmp(nodeID, task2->_targetID, DHT_ID_LENGTH) == 0);
+    (dynamic_pointer_cast<MockDHTTask>(taskQueue.immediateTaskQueue_[1]));
+  CPPUNIT_ASSERT(memcmp(nodeID, task2->targetID_, DHT_ID_LENGTH) == 0);
 }
 
 } // namespace aria2
