@@ -12,6 +12,10 @@
 #include "InOrderPieceSelector.h"
 #include "DownloadContext.h"
 #include "bittorrent_helper.h"
+#include "DiskAdaptor.h"
+#include "DiskWriterFactory.h"
+#include "PieceStatMan.h"
+#include "prefs.h"
 
 namespace aria2 {
 
@@ -20,7 +24,9 @@ class DefaultPieceStorageTest:public CppUnit::TestFixture {
   CPPUNIT_TEST_SUITE(DefaultPieceStorageTest);
   CPPUNIT_TEST(testGetTotalLength);
   CPPUNIT_TEST(testGetMissingPiece);
+  CPPUNIT_TEST(testGetMissingPiece_many);
   CPPUNIT_TEST(testGetMissingPiece_excludedIndexes);
+  CPPUNIT_TEST(testGetMissingPiece_manyWithExcludedIndexes);
   CPPUNIT_TEST(testGetMissingFastPiece);
   CPPUNIT_TEST(testGetMissingFastPiece_excludedIndexes);
   CPPUNIT_TEST(testHasMissingPiece);
@@ -31,32 +37,30 @@ class DefaultPieceStorageTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testCancelPiece);
   CPPUNIT_TEST(testMarkPiecesDone);
   CPPUNIT_TEST(testGetCompletedLength);
+  CPPUNIT_TEST(testGetNextUsedIndex);
   CPPUNIT_TEST_SUITE_END();
 private:
   SharedHandle<DownloadContext> dctx_;
   SharedHandle<Peer> peer;
-  Option* option;
+  SharedHandle<Option> option_;
   SharedHandle<PieceSelector> pieceSelector_;
 public:
   void setUp() {
+    option_.reset(new Option());
+    option_->put(PREF_DIR, ".");
     dctx_.reset(new DownloadContext());
-    bittorrent::load("test.torrent", dctx_);
+    bittorrent::load(A2_TEST_DIR"/test.torrent", dctx_, option_);
     peer.reset(new Peer("192.168.0.1", 6889));
     peer->allocateSessionResource(dctx_->getPieceLength(),
                                   dctx_->getTotalLength());
-    option = new Option();
     pieceSelector_.reset(new InOrderPieceSelector());
   }
 
-  void tearDown()
-  {
-    delete option;
-    option = 0;
-  }
-
   void testGetTotalLength();
   void testGetMissingPiece();
+  void testGetMissingPiece_many();
   void testGetMissingPiece_excludedIndexes();
+  void testGetMissingPiece_manyWithExcludedIndexes();
   void testGetMissingFastPiece();
   void testGetMissingFastPiece_excludedIndexes();
   void testHasMissingPiece();
@@ -67,22 +71,21 @@ public:
   void testCancelPiece();
   void testMarkPiecesDone();
   void testGetCompletedLength();
+  void testGetNextUsedIndex();
 };
 
 
 CPPUNIT_TEST_SUITE_REGISTRATION(DefaultPieceStorageTest);
 
 void DefaultPieceStorageTest::testGetTotalLength() {
-  DefaultPieceStorage pss(dctx_, option);
+  DefaultPieceStorage pss(dctx_, option_.get());
 
   CPPUNIT_ASSERT_EQUAL((uint64_t)384ULL, pss.getTotalLength());
 }
 
 void DefaultPieceStorageTest::testGetMissingPiece() {
-  DefaultPieceStorage pss(dctx_, option);
+  DefaultPieceStorage pss(dctx_, option_.get());
   pss.setPieceSelector(pieceSelector_);
-  pss.setEndGamePieceNum(0);
-
   peer->setAllBitfield();
 
   SharedHandle<Piece> piece = pss.getMissingPiece(peer);
@@ -95,12 +98,30 @@ void DefaultPieceStorageTest::testGetMissingPiece() {
   CPPUNIT_ASSERT_EQUAL(std::string("piece: index=2, length=128"),
                        piece->toString());
   piece = pss.getMissingPiece(peer);
-  CPPUNIT_ASSERT(piece.isNull());
+  CPPUNIT_ASSERT(!piece);
+}
+
+void DefaultPieceStorageTest::testGetMissingPiece_many() {
+  DefaultPieceStorage pss(dctx_, option_.get());
+  pss.setPieceSelector(pieceSelector_);
+  peer->setAllBitfield();
+  std::vector<SharedHandle<Piece> > pieces;
+  pss.getMissingPiece(pieces, 2, peer);
+  CPPUNIT_ASSERT_EQUAL((size_t)2, pieces.size());
+  CPPUNIT_ASSERT_EQUAL(std::string("piece: index=0, length=128"),
+                       pieces[0]->toString());
+  CPPUNIT_ASSERT_EQUAL(std::string("piece: index=1, length=128"),
+                       pieces[1]->toString());
+  pieces.clear();
+  pss.getMissingPiece(pieces, 2, peer);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, pieces.size());
+  CPPUNIT_ASSERT_EQUAL(std::string("piece: index=2, length=128"),
+                       pieces[0]->toString());
 }
 
 void DefaultPieceStorageTest::testGetMissingPiece_excludedIndexes()
 {
-  DefaultPieceStorage pss(dctx_, option);
+  DefaultPieceStorage pss(dctx_, option_.get());
   pss.setPieceSelector(pieceSelector_);
   pss.setEndGamePieceNum(0);
 
@@ -118,11 +139,29 @@ void DefaultPieceStorageTest::testGetMissingPiece_excludedIndexes()
                        piece->toString());
 
   piece = pss.getMissingPiece(peer, excludedIndexes);
-  CPPUNIT_ASSERT(piece.isNull());
+  CPPUNIT_ASSERT(!piece);
+}
+
+void DefaultPieceStorageTest::testGetMissingPiece_manyWithExcludedIndexes() {
+  DefaultPieceStorage pss(dctx_, option_.get());
+  pss.setPieceSelector(pieceSelector_);
+  peer->setAllBitfield();
+  std::vector<size_t> excludedIndexes;
+  excludedIndexes.push_back(1);
+  std::vector<SharedHandle<Piece> > pieces;
+  pss.getMissingPiece(pieces, 2, peer, excludedIndexes);
+  CPPUNIT_ASSERT_EQUAL((size_t)2, pieces.size());
+  CPPUNIT_ASSERT_EQUAL(std::string("piece: index=0, length=128"),
+                       pieces[0]->toString());
+  CPPUNIT_ASSERT_EQUAL(std::string("piece: index=2, length=128"),
+                       pieces[1]->toString());
+  pieces.clear();
+  pss.getMissingPiece(pieces, 2, peer, excludedIndexes);
+  CPPUNIT_ASSERT(pieces.empty());
 }
 
 void DefaultPieceStorageTest::testGetMissingFastPiece() {
-  DefaultPieceStorage pss(dctx_, option);
+  DefaultPieceStorage pss(dctx_, option_.get());
   pss.setPieceSelector(pieceSelector_);
   pss.setEndGamePieceNum(0);
 
@@ -134,12 +173,12 @@ void DefaultPieceStorageTest::testGetMissingFastPiece() {
   CPPUNIT_ASSERT_EQUAL(std::string("piece: index=2, length=128"),
                        piece->toString());
 
-  CPPUNIT_ASSERT(pss.getMissingFastPiece(peer).isNull());
+  CPPUNIT_ASSERT(!pss.getMissingFastPiece(peer));
 }
 
 void DefaultPieceStorageTest::testGetMissingFastPiece_excludedIndexes()
 {
-  DefaultPieceStorage pss(dctx_, option);
+  DefaultPieceStorage pss(dctx_, option_.get());
   pss.setPieceSelector(pieceSelector_);
   pss.setEndGamePieceNum(0);
 
@@ -155,11 +194,11 @@ void DefaultPieceStorageTest::testGetMissingFastPiece_excludedIndexes()
   CPPUNIT_ASSERT_EQUAL(std::string("piece: index=1, length=128"),
                        piece->toString());
   
-  CPPUNIT_ASSERT(pss.getMissingFastPiece(peer, excludedIndexes).isNull());
+  CPPUNIT_ASSERT(!pss.getMissingFastPiece(peer, excludedIndexes));
 }
 
 void DefaultPieceStorageTest::testHasMissingPiece() {
-  DefaultPieceStorage pss(dctx_, option);
+  DefaultPieceStorage pss(dctx_, option_.get());
 
   CPPUNIT_ASSERT(!pss.hasMissingPiece(peer));
   
@@ -169,7 +208,7 @@ void DefaultPieceStorageTest::testHasMissingPiece() {
 }
 
 void DefaultPieceStorageTest::testCompletePiece() {
-  DefaultPieceStorage pss(dctx_, option);
+  DefaultPieceStorage pss(dctx_, option_.get());
   pss.setPieceSelector(pieceSelector_);
   pss.setEndGamePieceNum(0);
 
@@ -191,7 +230,7 @@ void DefaultPieceStorageTest::testCompletePiece() {
 }
 
 void DefaultPieceStorageTest::testGetPiece() {
-  DefaultPieceStorage pss(dctx_, option);
+  DefaultPieceStorage pss(dctx_, option_.get());
   
   SharedHandle<Piece> pieceGot = pss.getPiece(0);
   CPPUNIT_ASSERT_EQUAL((size_t)0, pieceGot->getIndex());
@@ -200,7 +239,7 @@ void DefaultPieceStorageTest::testGetPiece() {
 }
 
 void DefaultPieceStorageTest::testGetPieceInUsedPieces() {
-  DefaultPieceStorage pss(dctx_, option);
+  DefaultPieceStorage pss(dctx_, option_.get());
   SharedHandle<Piece> piece = SharedHandle<Piece>(new Piece(0, 128));
   piece->completeBlock(0);
   pss.addUsedPiece(piece);
@@ -211,7 +250,7 @@ void DefaultPieceStorageTest::testGetPieceInUsedPieces() {
 }
 
 void DefaultPieceStorageTest::testGetPieceCompletedPiece() {
-  DefaultPieceStorage pss(dctx_, option);
+  DefaultPieceStorage pss(dctx_, option_.get());
   SharedHandle<Piece> piece = SharedHandle<Piece>(new Piece(0, 128));
   pss.completePiece(piece);
   SharedHandle<Piece> pieceGot = pss.getPiece(0);
@@ -231,7 +270,7 @@ void DefaultPieceStorageTest::testCancelPiece()
   SharedHandle<DownloadContext> dctx
     (new DownloadContext(pieceLength, totalLength, "src/file1.txt"));
 
-  SharedHandle<DefaultPieceStorage> ps(new DefaultPieceStorage(dctx, option));
+  SharedHandle<DefaultPieceStorage> ps(new DefaultPieceStorage(dctx, option_.get()));
 
   SharedHandle<Piece> p = ps->getMissingPiece(0);
   p->completeBlock(0);
@@ -250,7 +289,7 @@ void DefaultPieceStorageTest::testMarkPiecesDone()
   SharedHandle<DownloadContext> dctx
     (new DownloadContext(pieceLength, totalLength));
 
-  DefaultPieceStorage ps(dctx, option);
+  DefaultPieceStorage ps(dctx, option_.get());
 
   ps.markPiecesDone(pieceLength*10+16*1024*2+1);
 
@@ -277,7 +316,7 @@ void DefaultPieceStorageTest::testGetCompletedLength()
   SharedHandle<DownloadContext> dctx
     (new DownloadContext(1024*1024, 256*1024*1024));
   
-  DefaultPieceStorage ps(dctx, option);
+  DefaultPieceStorage ps(dctx, option_.get());
   
   CPPUNIT_ASSERT_EQUAL((uint64_t)0, ps.getCompletedLength());
 
@@ -302,4 +341,16 @@ void DefaultPieceStorageTest::testGetCompletedLength()
   CPPUNIT_ASSERT_EQUAL((uint64_t)256*1024*1024, ps.getCompletedLength());
 }
 
+void DefaultPieceStorageTest::testGetNextUsedIndex()
+{
+  DefaultPieceStorage pss(dctx_, option_.get());
+  CPPUNIT_ASSERT_EQUAL((size_t)3, pss.getNextUsedIndex(0));
+  SharedHandle<Piece> piece = pss.getMissingPiece(2);
+  CPPUNIT_ASSERT_EQUAL((size_t)2, pss.getNextUsedIndex(0));
+  pss.completePiece(piece);
+  CPPUNIT_ASSERT_EQUAL((size_t)2, pss.getNextUsedIndex(0));
+  piece = pss.getMissingPiece(0);
+  CPPUNIT_ASSERT_EQUAL((size_t)2, pss.getNextUsedIndex(0));
+}
+
 } // namespace aria2
