@@ -3,17 +3,18 @@
 #include <cppunit/extensions/HelperMacros.h>
 
 #include "InOrderURISelector.h"
+#include "util.h"
 
 namespace aria2 {
 
 class FileEntryTest : public CppUnit::TestFixture {
   
   CPPUNIT_TEST_SUITE(FileEntryTest);
-  CPPUNIT_TEST(testSetupDir);
   CPPUNIT_TEST(testRemoveURIWhoseHostnameIs);
   CPPUNIT_TEST(testExtractURIResult);
   CPPUNIT_TEST(testGetRequest);
-  CPPUNIT_TEST(testGetRequest_disableSingleHostMultiConnection);
+  CPPUNIT_TEST(testGetRequest_withoutUriReuse);
+  CPPUNIT_TEST(testGetRequest_withUniqueProtocol);
   CPPUNIT_TEST(testReuseUri);
   CPPUNIT_TEST(testAddUri);
   CPPUNIT_TEST(testAddUris);
@@ -23,11 +24,11 @@ class FileEntryTest : public CppUnit::TestFixture {
 public:
   void setUp() {}
   
-  void testSetupDir();
   void testRemoveURIWhoseHostnameIs();
   void testExtractURIResult();
   void testGetRequest();
-  void testGetRequest_disableSingleHostMultiConnection();
+  void testGetRequest_withoutUriReuse();
+  void testGetRequest_withUniqueProtocol();
   void testReuseUri();
   void testAddUri();
   void testAddUris();
@@ -38,7 +39,8 @@ public:
 
 CPPUNIT_TEST_SUITE_REGISTRATION( FileEntryTest );
 
-static SharedHandle<FileEntry> createFileEntry()
+namespace {
+SharedHandle<FileEntry> createFileEntry()
 {
   const char* uris[] = { "http://localhost/aria2.zip",
                          "ftp://localhost/aria2.zip",
@@ -47,23 +49,7 @@ static SharedHandle<FileEntry> createFileEntry()
   fileEntry->setUris(std::vector<std::string>(&uris[0], &uris[3]));
   return fileEntry;
 }
-
-void FileEntryTest::testSetupDir()
-{
-  std::string dir = "./aria2-FileEntryTest-testSetupDir";
-  std::string filename = "filename";
-  std::string path = dir+"/"+filename;
-  File d(dir);
-  if(d.exists()) {
-    CPPUNIT_ASSERT(d.remove());
-  }
-  CPPUNIT_ASSERT(!d.exists());
-  FileEntry fileEntry(path, 0, 0);
-  fileEntry.setupDir();
-  CPPUNIT_ASSERT(d.isDir());
-  File f(path);
-  CPPUNIT_ASSERT(!f.exists());
-}
+} // namespace
 
 void FileEntryTest::testRemoveURIWhoseHostnameIs()
 {
@@ -78,13 +64,13 @@ void FileEntryTest::testRemoveURIWhoseHostnameIs()
 void FileEntryTest::testExtractURIResult()
 {
   FileEntry fileEntry;
-  fileEntry.addURIResult("http://timeout/file", downloadresultcode::TIME_OUT);
-  fileEntry.addURIResult("http://finished/file", downloadresultcode::FINISHED);
-  fileEntry.addURIResult("http://timeout/file2", downloadresultcode::TIME_OUT);
-  fileEntry.addURIResult("http://unknownerror/file", downloadresultcode::UNKNOWN_ERROR);
+  fileEntry.addURIResult("http://timeout/file", error_code::TIME_OUT);
+  fileEntry.addURIResult("http://finished/file", error_code::FINISHED);
+  fileEntry.addURIResult("http://timeout/file2", error_code::TIME_OUT);
+  fileEntry.addURIResult("http://unknownerror/file", error_code::UNKNOWN_ERROR);
 
   std::deque<URIResult> res;
-  fileEntry.extractURIResult(res, downloadresultcode::TIME_OUT);
+  fileEntry.extractURIResult(res, error_code::TIME_OUT);
   CPPUNIT_ASSERT_EQUAL((size_t)2, res.size());
   CPPUNIT_ASSERT_EQUAL(std::string("http://timeout/file"), res[0].getURI());
   CPPUNIT_ASSERT_EQUAL(std::string("http://timeout/file2"), res[1].getURI());
@@ -97,7 +83,7 @@ void FileEntryTest::testExtractURIResult()
 
   res.clear();
 
-  fileEntry.extractURIResult(res, downloadresultcode::TIME_OUT);
+  fileEntry.extractURIResult(res, error_code::TIME_OUT);
   CPPUNIT_ASSERT(res.empty());
   CPPUNIT_ASSERT_EQUAL((size_t)2, fileEntry.getURIResults().size());
 }
@@ -106,55 +92,125 @@ void FileEntryTest::testGetRequest()
 {
   SharedHandle<FileEntry> fileEntry = createFileEntry();
   SharedHandle<InOrderURISelector> selector(new InOrderURISelector());
-  SharedHandle<Request> req = fileEntry->getRequest(selector);
+  std::vector<std::pair<size_t, std::string> > usedHosts;
+  SharedHandle<Request> req =
+    fileEntry->getRequest(selector, true, usedHosts);
   CPPUNIT_ASSERT_EQUAL(std::string("localhost"), req->getHost());
   CPPUNIT_ASSERT_EQUAL(std::string("http"), req->getProtocol());
-
   fileEntry->poolRequest(req);
 
-  SharedHandle<Request> req2nd = fileEntry->getRequest(selector);
+  SharedHandle<Request> req2nd =
+    fileEntry->getRequest(selector, true, usedHosts);
   CPPUNIT_ASSERT_EQUAL(std::string("localhost"), req2nd->getHost());
   CPPUNIT_ASSERT_EQUAL(std::string("http"), req2nd->getProtocol());
 
-  SharedHandle<Request> req3rd = fileEntry->getRequest(selector);
-  CPPUNIT_ASSERT_EQUAL(std::string("localhost"), req3rd->getHost());
-  CPPUNIT_ASSERT_EQUAL(std::string("ftp"), req3rd->getProtocol());
+  SharedHandle<Request> req3rd =
+    fileEntry->getRequest(selector, true, usedHosts);
+  CPPUNIT_ASSERT_EQUAL(std::string("mirror"), req3rd->getHost());
+  CPPUNIT_ASSERT_EQUAL(std::string("http"), req3rd->getProtocol());
+
+  SharedHandle<Request> req4th =
+    fileEntry->getRequest(selector, true, usedHosts);
+  CPPUNIT_ASSERT(!req4th);
+
+  fileEntry->setMaxConnectionPerServer(2);
+  
+  SharedHandle<Request> req5th =
+    fileEntry->getRequest(selector, true, usedHosts);
+  CPPUNIT_ASSERT_EQUAL(std::string("localhost"), req5th->getHost());
+  CPPUNIT_ASSERT_EQUAL(std::string("ftp"), req5th->getProtocol());
+
+  SharedHandle<Request> req6th =
+    fileEntry->getRequest(selector, true, usedHosts);
+  CPPUNIT_ASSERT_EQUAL(std::string("mirror"), req6th->getHost());
+  CPPUNIT_ASSERT_EQUAL(std::string("http"), req6th->getProtocol());
+
+  SharedHandle<Request> req7th =
+    fileEntry->getRequest(selector, true, usedHosts);
+  CPPUNIT_ASSERT(!req7th);
 }
 
-void FileEntryTest::testGetRequest_disableSingleHostMultiConnection()
+void FileEntryTest::testGetRequest_withoutUriReuse()
 {
+  std::vector<std::pair<size_t, std::string> > usedHosts;
   SharedHandle<FileEntry> fileEntry = createFileEntry();
-  fileEntry->disableSingleHostMultiConnection();
+  fileEntry->setMaxConnectionPerServer(2);
   SharedHandle<InOrderURISelector> selector(new InOrderURISelector());
-  SharedHandle<Request> req = fileEntry->getRequest(selector);
+  SharedHandle<Request> req = fileEntry->getRequest(selector, false, usedHosts);
   CPPUNIT_ASSERT_EQUAL(std::string("localhost"), req->getHost());
   CPPUNIT_ASSERT_EQUAL(std::string("http"), req->getProtocol());
 
-  SharedHandle<Request> req2nd = fileEntry->getRequest(selector);
+  SharedHandle<Request> req2nd =
+    fileEntry->getRequest(selector, false, usedHosts);
+  CPPUNIT_ASSERT_EQUAL(std::string("localhost"), req2nd->getHost());
+  CPPUNIT_ASSERT_EQUAL(std::string("ftp"), req2nd->getProtocol());
+
+  SharedHandle<Request> req3rd =
+    fileEntry->getRequest(selector, false, usedHosts);
+  CPPUNIT_ASSERT_EQUAL(std::string("mirror"), req3rd->getHost());
+  CPPUNIT_ASSERT_EQUAL(std::string("http"), req3rd->getProtocol());
+
+  SharedHandle<Request> req4th =
+    fileEntry->getRequest(selector, false, usedHosts);
+  CPPUNIT_ASSERT(!req4th);
+}
+
+void FileEntryTest::testGetRequest_withUniqueProtocol()
+{
+  std::vector<std::pair<size_t, std::string> > usedHosts;
+  SharedHandle<FileEntry> fileEntry = createFileEntry();
+  fileEntry->setUniqueProtocol(true);
+  SharedHandle<InOrderURISelector> selector(new InOrderURISelector());
+  SharedHandle<Request> req =
+    fileEntry->getRequest(selector, true, usedHosts);
+  CPPUNIT_ASSERT_EQUAL(std::string("localhost"), req->getHost());
+  CPPUNIT_ASSERT_EQUAL(std::string("http"), req->getProtocol());
+
+  SharedHandle<Request> req2nd =
+    fileEntry->getRequest(selector, true, usedHosts);
   CPPUNIT_ASSERT_EQUAL(std::string("mirror"), req2nd->getHost());
   CPPUNIT_ASSERT_EQUAL(std::string("http"), req2nd->getProtocol());
 
-  SharedHandle<Request> req3rd = fileEntry->getRequest(selector);
-  CPPUNIT_ASSERT(req3rd.isNull());
+  SharedHandle<Request> req3rd =
+    fileEntry->getRequest(selector, true, usedHosts);
+  CPPUNIT_ASSERT(!req3rd);
+
+  CPPUNIT_ASSERT_EQUAL((size_t)2, fileEntry->getRemainingUris().size());
+  CPPUNIT_ASSERT_EQUAL(std::string("ftp://localhost/aria2.zip"),
+                       fileEntry->getRemainingUris()[0]);
+  CPPUNIT_ASSERT_EQUAL(std::string("http://mirror/aria2.zip"),
+                       fileEntry->getRemainingUris()[1]);
 }
 
 void FileEntryTest::testReuseUri()
 {
   SharedHandle<InOrderURISelector> selector(new InOrderURISelector());
   SharedHandle<FileEntry> fileEntry = createFileEntry();
+  fileEntry->setMaxConnectionPerServer(3);
   size_t numUris = fileEntry->getRemainingUris().size();
+  std::vector<std::pair<size_t, std::string> > usedHosts;
   for(size_t i = 0; i < numUris; ++i) {
-    fileEntry->getRequest(selector);
+    fileEntry->getRequest(selector, false, usedHosts);
   }
   CPPUNIT_ASSERT_EQUAL((size_t)0, fileEntry->getRemainingUris().size());
   fileEntry->addURIResult("http://localhost/aria2.zip",
-                          downloadresultcode::UNKNOWN_ERROR);
-  fileEntry->reuseUri(3);
-  CPPUNIT_ASSERT_EQUAL((size_t)3, fileEntry->getRemainingUris().size());
-  const std::deque<std::string>& uris = fileEntry->getRemainingUris();
+                          error_code::UNKNOWN_ERROR);
+  std::vector<std::string> ignore;
+  fileEntry->reuseUri(ignore);
+  CPPUNIT_ASSERT_EQUAL((size_t)2, fileEntry->getRemainingUris().size());
+  std::deque<std::string> uris = fileEntry->getRemainingUris();
   CPPUNIT_ASSERT_EQUAL(std::string("ftp://localhost/aria2.zip"), uris[0]);
   CPPUNIT_ASSERT_EQUAL(std::string("http://mirror/aria2.zip"), uris[1]);
-  CPPUNIT_ASSERT_EQUAL(std::string("ftp://localhost/aria2.zip"), uris[2]);
+  for(size_t i = 0; i < 2; ++i) {
+    fileEntry->getRequest(selector, false, usedHosts);
+  }
+  CPPUNIT_ASSERT_EQUAL((size_t)0, fileEntry->getRemainingUris().size());
+  ignore.clear();
+  ignore.push_back("mirror");
+  fileEntry->reuseUri(ignore);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, fileEntry->getRemainingUris().size());
+  uris = fileEntry->getRemainingUris();
+  CPPUNIT_ASSERT_EQUAL(std::string("ftp://localhost/aria2.zip"), uris[0]);
 }
 
 void FileEntryTest::testAddUri()
@@ -187,6 +243,7 @@ void FileEntryTest::testInsertUri()
 
 void FileEntryTest::testRemoveUri()
 {
+  std::vector<std::pair<size_t, std::string> > usedHosts;
   SharedHandle<InOrderURISelector> selector(new InOrderURISelector());
   FileEntry file;
   file.addUri("http://example.org/");
@@ -195,7 +252,8 @@ void FileEntryTest::testRemoveUri()
   CPPUNIT_ASSERT(!file.removeUri("http://example.org/"));
 
   file.addUri("http://example.org/");
-  SharedHandle<Request> exampleOrgReq = file.getRequest(selector);
+  SharedHandle<Request> exampleOrgReq =
+    file.getRequest(selector, true, usedHosts);
   CPPUNIT_ASSERT(!exampleOrgReq->removalRequested());
   CPPUNIT_ASSERT_EQUAL((size_t)1, file.getSpentUris().size());
   CPPUNIT_ASSERT(file.removeUri("http://example.org/"));
@@ -205,7 +263,7 @@ void FileEntryTest::testRemoveUri()
   CPPUNIT_ASSERT_EQUAL((size_t)0, file.countPooledRequest());
 
   file.addUri("http://example.org/");
-  exampleOrgReq = file.getRequest(selector);
+  exampleOrgReq = file.getRequest(selector, true, usedHosts);
   file.poolRequest(exampleOrgReq);
   CPPUNIT_ASSERT_EQUAL((size_t)1, file.countPooledRequest());
   CPPUNIT_ASSERT(file.removeUri("http://example.org/"));
