@@ -1,12 +1,17 @@
 #include "GZipDecoder.h"
+
+#include <iostream>
+#include <fstream>
+
+#include <cppunit/extensions/HelperMacros.h>
+
+#include "TestUtil.h"
 #include "Exception.h"
 #include "util.h"
 #ifdef ENABLE_MESSAGE_DIGEST
+# include "MessageDigest.h"
 # include "MessageDigestHelper.h"
 #endif // ENABLE_MESSAGE_DIGEST
-#include <iostream>
-#include <fstream>
-#include <cppunit/extensions/HelperMacros.h>
 
 namespace aria2 {
 
@@ -31,10 +36,10 @@ void GZipDecoderTest::testDecode()
   GZipDecoder decoder;
   decoder.init();
 
-  std::string outfile("/tmp/aria2_GZipDecoderTest_testDecode");
+  std::string outfile(A2_TEST_OUT_DIR"/aria2_GZipDecoderTest_testDecode");
 
   char buf[4096];
-  std::ifstream in("gzip_decode_test.gz", std::ios::binary);
+  std::ifstream in(A2_TEST_DIR"/gzip_decode_test.gz", std::ios::binary);
   std::ofstream out(outfile.c_str(), std::ios::binary);
   while(in) {
     in.read(buf, sizeof(buf));
@@ -51,8 +56,7 @@ void GZipDecoderTest::testDecode()
 
 #ifdef ENABLE_MESSAGE_DIGEST
   CPPUNIT_ASSERT_EQUAL(std::string("8b577b33c0411b2be9d4fa74c7402d54a8d21f96"),
-                       MessageDigestHelper::digest(MessageDigestContext::SHA1,
-                                                   outfile));
+                       fileHexDigest(MessageDigest::sha1(), outfile));
 #endif // ENABLE_MESSAGE_DIGEST
 }
 
