@@ -6,6 +6,8 @@
 #include "Option.h"
 #include "DownloadContext.h"
 #include "FileEntry.h"
+#include "PieceStorage.h"
+#include "DiskAdaptor.h"
 
 namespace aria2 {
 
@@ -17,11 +19,11 @@ class MetalinkPostDownloadHandlerTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testGetNextRequestGroups);
   CPPUNIT_TEST_SUITE_END();
 private:
-  SharedHandle<Option> _option;
+  SharedHandle<Option> option_;
 public:
   void setUp()
   {
-    _option.reset(new Option());
+    option_.reset(new Option());
   }
 
   void testCanHandle_extension();
@@ -36,7 +38,7 @@ void MetalinkPostDownloadHandlerTest::testCanHandle_extension()
 {
   SharedHandle<DownloadContext> dctx
     (new DownloadContext(0, 0, "test.metalink"));
-  RequestGroup rg(_option);
+  RequestGroup rg(option_);
   rg.setDownloadContext(dctx);
 
   MetalinkPostDownloadHandler handler;
@@ -51,7 +53,7 @@ void MetalinkPostDownloadHandlerTest::testCanHandle_contentType()
 {
   SharedHandle<DownloadContext> dctx(new DownloadContext(0, 0, "test"));
   dctx->getFirstFileEntry()->setContentType("application/metalink+xml");
-  RequestGroup rg(_option);
+  RequestGroup rg(option_);
   rg.setDownloadContext(dctx);
 
   MetalinkPostDownloadHandler handler;
@@ -65,10 +67,11 @@ void MetalinkPostDownloadHandlerTest::testCanHandle_contentType()
 void MetalinkPostDownloadHandlerTest::testGetNextRequestGroups()
 {
   SharedHandle<DownloadContext> dctx
-    (new DownloadContext(1024, 0, "test.xml"));
-  RequestGroup rg(_option);
+    (new DownloadContext(1024, 0, A2_TEST_DIR"/test.xml"));
+  RequestGroup rg(option_);
   rg.setDownloadContext(dctx);
   rg.initPieceStorage();
+  rg.getPieceStorage()->getDiskAdaptor()->enableReadOnly();
 
   MetalinkPostDownloadHandler handler;
   std::vector<SharedHandle<RequestGroup> > groups;
