@@ -1,5 +1,5 @@
-#ifndef _D_MOCK_PEER_STORAGE_H_
-#define _D_MOCK_PEER_STORAGE_H_
+#ifndef D_MOCK_PEER_STORAGE_H
+#define D_MOCK_PEER_STORAGE_H
 
 #include "PeerStorage.h"
 
@@ -13,10 +13,11 @@ class MockPeerStorage : public PeerStorage {
 private:
   TransferStat stat;
   std::deque<SharedHandle<Peer> > peers;
-  std::deque<SharedHandle<Peer> > activePeers;
-  int _numChokeExecuted;
+  std::deque<SharedHandle<Peer> > droppedPeers;
+  std::vector<SharedHandle<Peer> > activePeers;
+  int numChokeExecuted_;
 public:
-  MockPeerStorage():_numChokeExecuted(0) {}
+  MockPeerStorage():numChokeExecuted_(0) {}
   virtual ~MockPeerStorage() {}
 
   virtual bool addPeer(const SharedHandle<Peer>& peer) {
@@ -24,7 +25,7 @@ public:
     return true;
   }
 
-  virtual void addPeer(const std::deque<SharedHandle<Peer> >& peers) {
+  virtual void addPeer(const std::vector<SharedHandle<Peer> >& peers) {
     std::copy(peers.begin(), peers.end(), back_inserter(this->peers));
   }
 
@@ -32,6 +33,14 @@ public:
     return peers;
   }
 
+  virtual const std::deque<SharedHandle<Peer> >& getDroppedPeers() {
+    return droppedPeers;
+  }
+
+  void addDroppedPeer(const SharedHandle<Peer>& peer) {
+    droppedPeers.push_back(peer);
+  }
+
   virtual SharedHandle<Peer> getUnusedPeer() {
     return SharedHandle<Peer>();
   }
@@ -40,12 +49,12 @@ public:
     return false;
   }
   
-  void setActivePeers(const std::deque<SharedHandle<Peer> >& activePeers)
+  void setActivePeers(const std::vector<SharedHandle<Peer> >& activePeers)
   {
     this->activePeers = activePeers;
   }
 
-  virtual void getActivePeers(std::deque<SharedHandle<Peer> >& peers) {
+  virtual void getActivePeers(std::vector<SharedHandle<Peer> >& peers) {
     peers.insert(peers.end(), activePeers.begin(), activePeers.end());
   }
 
@@ -68,7 +77,7 @@ public:
 
   virtual void executeChoke()
   {
-    ++_numChokeExecuted;
+    ++numChokeExecuted_;
   }
 
   virtual void updateTransferStatFor(const SharedHandle<Peer>& peer) {}
@@ -80,10 +89,10 @@ public:
 
   int getNumChokeExecuted() const
   {
-    return _numChokeExecuted;
+    return numChokeExecuted_;
   }
 };
 
-#endif // _D_MOCK_PEER_STORAGE_H_
+#endif // D_MOCK_PEER_STORAGE_H
 
 } // namespace aria2
